+++
tags = ["bash"]
zusammenfassung = "Dateien und Verzeichnisse suchen."
title = "find"
date = "2024-04-09T12:43:13+02:00"
type = "article"
+++

_find_ ist ein mächtiges Werkzeug zum Suchen von Dateien und Verzeichnissen. Im folgenden ein paar Beispiele.

#### Doppelte Dateien suchen

Aus dem [Debian Anwenderhandbuch][debianHandbuch] ist folgende praktische Codezeile.

```fish {linenos=false}

 find . -exec md5sum {} 2>/dev/null \; | sort | uniq -w 32 -D > doppelte.asc

```

#### Suchen nach Dateigröße und Zeit

```fish {linenos=false}
   
 #a) Dateien die in den letzten 10 Minuten geändert wurden
 find ./ -mmin -10
 
 #b) größer als 500 Mebibyte = 524,288 Megabyte
 find ./ -size +500M -print

 #c) kleine als 100 Byte
 find ./ -size -100c -print

 #d) Kombination c) und a) 
 find . -size -100c -and -mmin -2 -print
   
```
 
#### Verzeichnisse auslassen

```fish {linenos=false}
  
 #a) Verzeichnisse Programm\* und .wine\* ausschließen
 find ./ \( -type d -path ./.wine\* -o -path ./Programm\*  \) -prune -o -iname "*.asc" -print

 #b) wie a) mit egrep-Variante
 find ./ -iname "*.asc" | egrep -v "./.wine*|./Programm*"

 #c) wie a)  mit zwei Suchmustern
 find ./ \( -type d -path ./.wine\* -o -path ./Programm\*  \) -prune -o \( -iname "*.png" -o -iname "*.asc" \) -print 
 
 #d) Suche bis Verzeichnistiefe
 find ./ -maxdepth 2 -iname "*.asc" -print 
 
 #d) Suche ab Verzeichnistiefe 8 (=9-1)
 find ./ -mindepth 9 -iname "*.asc" -print 
   
```

#### Leerzeichen in Datei- und Verzeichnissnamen finden

```fish {linenos=false}

 find ./ -type d -iname '\* *' -print		# -type d für Verzeichnis
 find ./ -type f -iname '\* *' -print		# -type f für Datei
   
```

#### exec - das Ergebnis weiter verarbeiten

```fish {linenos=false}

 find ./ -iname '*' 	-exec file {} \;	# Filetype out
 find ./ -iname '*.txt' -exec cp   {} /temp/ \; # copy to /temp
   
```


[debianHandbuch]:	https://www.debiananwenderhandbuch.de/arbeitenmitdateien.html#find

