+++
tags = ["dev", "sed", "pattern", "muster", "regular expression"]
zusammenfassung = "Der Streameditor - sed -"
title = "sed"
submenu = "false"
date = "2020-08-28T10:59:51+02:00"
type = "article"
+++


Zum Suchen verwendet der Zeileneditor [reguläre Ausdrücke.][RegularExpressions] 
Es existieren auch Internetseiten um reguläre Ausdrücke zu [testen.][testregexp]


## Suchen und ersetzen

```awk {linenos=false}

 sed 's/ *//g'		 # Alle Leerzeichen entfernen
 sed 's/  */ /g'	 # Mehrfachleerzeichen ersetzen durch ein einzelnes Leerzeichen
 sed 's/ \+/\ /g'	 # Mehrfachleerzeichen ersetzen durch ein einzelnes Leerzeichen
 sed 's/^[[:space:]]*//' # Alle Leerzeichen und Tabulatoren zu Beginn einer Zeile löschen (Beachte ohne /g = global)
 sed '/meta/s/A/b/'	 # Sucht alle Zeilen mit "meta" und ersetzt in diesen Zeilen A mit b 
   
```
Hier gibt's weitere [Referenzen].


## Reguläre Ausdrücke und Wiederholungen

Ein kleiner aber vielleicht wichtiger Ausflug in die Welt der regulären Ausdrücke.
Ein regulärer Ausdruck (engl.: Regular expressions) ist die Beschreibung einer bestimmten Menge von Zeichen in einer Folge.
Wiederholungen von regulären Ausdrücken (kurz RE) werden mit den folgenden Zeichen (Platzhaltern) verarbeitet:

{{<mytable class="width80 greyhead small smallfont fontcourier captleft">}}
| Platzhalter | Beschreibung |
| :---:  | :--- |
| \* | der RE kommt null oder mehrfach vor |
| \\+ | der RE kommt mindestens ein oder mehrfach vor |
| \\? | der RE kommt null oder mindenstens einmal vor |
| . | ein beliebiges Zeichen |
{{</mytable>}}

__Hinweis:__ Die Platzhalter `+` und `?` müssen maskiert werden.

## Styles aus HTML-Seiten entfernen

In alten Html-Seiten sind Styles meisten direkt in einem Html-Element integriert. Zum Beispiel:

```html {linenos=false}

 <th style="border-bottom: 0.5pt solid ;  font-weight:normal;" rowspan="2" align="center" valign="middle" charoff="50">Text</th>
   
``` 
Das ist heute nicht mehr erwünscht und wird mit CSS gelöst.
Deshalb kann es notwendig sein, die entsprechenden Codezeilen zu entfernen. 

```awk {linenos=false}

 sed -re 's/style\=\"[[:alnum:][:space:]\:\.\;\-]*\"//g' input.html > output.html
   
```

__Erläuterung:__

Der regulare Ausdruck `style\=\"[[:alnum:][:space:]\:\.\;\-]*\"` beschreibt, dass alles zwischen der Zeichenfolge `style="` und dem darauffolgenden ersten Anführungszeichen `"` angesprochen wird. In der Tabelle sind nochmal alle regulären Ausdrücke aufgeführt, wobei einige mit einem Backslash `\` maskiert sind.


{{<mytable caption="Beschreibung der einzelnen Ausdrücke" class="width80 greyhead small smallfont fontcourier captleft vtop">}}
| RegExp | Characters |
| :---:  | :--- |
| [:alnum:] | alphanumeric [0-9A-Za-z] |
| [:space:] | whitespace [\t\n\v\f\r ] |
| \\: | Doppelpunkt (maskiert) |
| \\. | Punkt (maskiert) |
| \\; | Semikolon (maskiert) |
| \\- | Minuszeichen (maskiert) |
{{</mytable>}}

Das Ganze wird in eine eckige Klammer eingepackt und mit Sternchen versehen: `[[:alnum:][:space:]\:\.\;\-]*`. Das bedeutet, dass alles mehrfach vorkommen kann.



### Weitere Beispiele


{{<mytable class="greyhead small smallfont fontcourier vtop nowrap">}}
| RegExp | Beschreibung |
| :---:  | :--- |
| border-right:[[:alnum:][:space:].]\*\\;  | alle alphanummeric und whitespace zw. border-right  und ; |
| border-bottom:[[:alnum:][:space:].]\*;   | alles zw. border-bottom und ; |
| font-weight:[[:alnum:][:space:].]\*;     | alles zw. font-weight   und ; |
| style\=\"[[:space:]]\*\"		   | style\=\"   \" | 
{{</mytable>}}


Zum Abschluß ein paar Codezeilen um allen möglichen Käse aus HTML-Dateien zu entfernen.

```awk {linenos=false}

 sed 	\
	-re 's/ style\=\"[[:alnum:][:space:]\:\.\;\-]*\"//g' \
	-re 's/ align\=\"[[:alnum:][:space:]]*\"//'   	     \
	-re 's/ valign\=\"[[:alnum:][:space:]]*\"//'   	     \
	-re 's/ charoff\=\"[[:alnum:][:space:]]*\"//'        \
	-re 's/<t([[:alnum:]]) [[:space:]]*>/<t\1>/' 	     \   # entfernt whitespace in <t? >
	-re 's/<\/?span[[:space:]]*>//g' 		     \   # entfernt <span > aber auch <\span>
	\
	input.html > output.html

   
```

### cleanhtml

Nachfolgend ein Skript um die Struktur einer Html-Datei zu verändern. 
Das Skript strukturiert eine Html-Datei um, indem es:
1. HTML-Elemente in eine neue Zeile versetzt
2. HTML-Elemente teilweise nach rechts verschiebt
3. Leerraum (whitespace) am Beginn einer Zeile löscht
4. Das Html-Element `<span> </span>` löscht, aber nicht deren Inhalt.
5. Teilw. Eigenschaften innerhalb eines Elements löscht, wie z.B.: `style align valign charoff` 

{{<code lang="bash" file="/static/include_files/cleanhtml.sh" title="Bashscript: cleanhtml.sh">}}

{{</code>}}
  





[Referenzen]: 		https://nathansen.de/linux/sed
[RegularExpressions]: 	https://github.com/google/re2/wiki/Syntax
[testregexp]:		https://regex101.com/



