+++
tags = ["node", "npm", "javascript"]
zusammenfassung = "Javascript mit Node.js serverseitig verwenden."
title = "Node"
date = "2023-02-16T17:38:30+01:00"
type = "article"
+++

Vorweggenommen gleich mal ein paar Links.   
[Tutorial 1][tutorial01]   
[Tutorial 2][tutorial02]

### Installation

Gehe zu [nodejs.org,][nodejs.org] lade dir das entsprechende Binary herunter [node-v18.16](https://nodejs.org/dist/v18.16.0/) und entpacke es einfach in ein Verzeichnis z.B. `c:\dev\nodejs`. 
Öffne eine Windowskonsole `cmd.exe` und starte die Datei `c:\dev\nodejs\nodevars.bat` damit die Umgebungsvariablen temporär (also nur für die Windowskonsole) gesetzt werden. Das war's auch schon.
{{<code lang="fish" title="cmd.exe">}}
 # Umgebungsvariablen setzen, starte einfach nodevars.bat
 c:\\dev\\nodejs\\nodevars.bat

 # Check Version
 node --version

 # Version des Packetmanagers 
 npm -v 
{{</code>}}

### Ein einfaches Beispiel

Ein simples Beispiel ist schnell erstellt. Lege ein Projektverzeichnis an und initialisiere es mit `npm init -y`.
Erstelle die Javascript-Datei `hello.js` und starte es einfach mit `node hello.js`. 
In einem Browser deiner Wahl wird in der Adresszeile `http://127.0.0.1:3000` eingegeben und das Ergebnis angezeigt.

{{<code lang="javascript" title="hello.js">}}
 const http = require('http');

 const hostname = '127.0.0.1';
 const port = 3000;

 const server = http.createServer((req, res) => {
  res.statusCode = 200;
  res.setHeader('Content-Type', 'text/plain; charset=utf-8');
  res.write('\n\n');
  res.write('Hello, World!');
  res.write('\n\n');
  res.write('https://nodejs.org/de/');
  res.end();
 });

 server.listen(port, hostname, () => {
  	console.log(`\nServer running at http://${hostname}:${port}/`);
	console.log('Yeahh... alta!');
 });
{{</code>}}

Hier nochmal eine Zusammenfassung der Befehle.

{{<code lang="xorg" title="cmd.exe">}}
 # Erstelle ein Projektverzeichnis
 mkdir test-01
 cd test-01

 # Initialisiere node mittels Packetmanager
 npm init -y

 # Starte node mit Javascript
 node hello.js

 # Das Ergebnis ist im Browser
 firefox http://127.0.0.1:3000
{{</code>}}


### Node Package Manager - npm

Der mitgelieferte Packetmanager [npm][] ist wohl die wichtigste Abhängigkeit innerhalb von [nodejs.][nodejs.org] 
Mit ihm werden Packete installiert, das Projekt initialisiert und konfiguriert sowie Einstellungen vorgenommen.
   
Der Packetmanager lädt entsprechend unkontrolliert Daten nach. Es gibt ein kleines [Sicherheitstool][npm-secure] um dem entgegen zu wirken.



#### npm CLI

Das Kommandozeileninterface (CLI) bietet eine umfangreiche Auswahl an Kommandos. 
Die einzelnen Funktionen und dazu gehörigen Optionen sind in der [Dokumentation][npmcli] zu lesen.
Ein paar sind hier aufgeführt. 

```fish{linenos=false}

 npm ls --long		# listet Projektpackete auf
 	--global	# listet global installierte Packete auf
 	--all		# listet alle Packete ausführlich auf

 npm config ls	--long	# Konfiguration anzeigen
 npm config list	# nur geänderte Konfiguration anzeigen
 npm config set		# setzen eines Konfigurationswertes
 
 npm install	<packagename> # Packet installieren
 npm uninstall	<packagename> # Packet deinstallieren
   
```


Unter Umständen kann die Installation von Packeten mit `npm install <Packetname>` durch eine Firewall blockiert sein.
Dann könnte ein Proxy helfen.

{{<code lang="fish" title="Proxy einstellen">}}
 npm config set proxy=http://www-proxy.bybn.de:80
 npm config set https-proxy=http://www-proxy.bybn.de:80
{{</code>}}


### Node Monitor - nodemon

Mit _nodemon_ werden Node-Projektdateien überwacht. Bei Änderungen der Dateien wird _node_ neu gestartet. 
Installiert wird der Monitor mit Hilfe des Packetmanager _npm_. 

```fish{linenos=false}

 # nodemon global installieren
 npm install -g nodemon

 # Projekt mit nodemon ausführen
 nodemon hello.js
   
```

[tutorial01]:	https://webdeasy.de/node-js-tutorial/
[tutorial02]:	https://www.ionos.de/digitalguide/websites/web-entwicklung/einfuehrung-in-nodejs/
[nodejs.org]:	https://nodejs.org
[npm]:			https://docs.npmjs.com/
[npmcli]:		https://docs.npmjs.com/cli
[npm-secure]:	https://www.heise.de/news/Security-Neues-CLI-Tool-soll-npm-install-vor-Malware-schuetzen-7549005.html
