+++
tags = ["dev", "gohugo", "markdown"]
zusammenfassung = "Seitenweise Parameterübergabe über Gohugo Funktionen."
title = "Parameterübergabe in Gohugo"
submenu = "false"
date = "2020-10-19T08:48:53+02:00"
type = "article"
schalter = 1001
[company]
	name = "mycompany"
	addr = "my address"

+++

## Zugriff auf Seitenparameter in einer Markdowndatei `*.md`

Im Kopf einer Markdowndatei (\*.md) sind Parameter oder Variablen deklariert, auf die im Text mit `{{</*param xyz*/>}}` zugegriffen werden kann.

{{<code lang="md" title="Beispiel Markdowndatei *.md">}}
 +++
 date = "{{<param date>}}"
 thumbnail = "tumb.test.jpg"
 schalter = 1001
 [company]
	name = "mycompany"
	addr = "my address"
 +++
   
    
 Der Zugriff auf die Seitenparameter im Text der Mardowndatei erfolgt mit geschweiften Klammern.

 Parameter date = {{</*param date*/>}} 
 Parameter company.name = {{</*param "company.name"*/>}} Zugriff mit Anführungszeichen
 Parameter company.name = {{</*param company.name*/>}}   Zugriff ohne Anführungszeichen
 Parameter company.name = {{</*param company.addr*/>}}
 Parameter schalter = {{</*param schalter*/>}} 
{{</code>}}

__Ergebnis:__

{{<panel>}}   
 Der Zugriff auf die Seitenparameter im Text der Mardowndatei erfolgt mit geschweiften Klammern.

 Parameter date = {{<param date>}}   
 Parameter company.name = {{<param "company.name">}} Zugriff mit Anführungszeichen   
 Parameter company.name = {{<param company.name>}} Zugriff ohne Anführungszeichen   
 Parameter company.addr = {{<param company.addr>}}
 Parameter schalter = {{<param schalter>}}   
   
{{</panel>}}

Um in einer Shortcodedatei oder in einer anderen HTML-Datei unterhalb des Verzeichnisses `themes\...\layouts` auf die Parameter im Kopf der Markdowndatei zu zugreifen,
muss du folgenden Code anwenden:

```go-html-template {linenos=false}

 {{ if .Page.Params.company  }}
 	{{ $name := .Page.Param "company.name" }}
 	{{ $addr := .Page.Param "company.addr" }}
 	{{ $name }} {{ $addr }}
 {{ end }}


```

## Zugriff auf Parameter aus der Konfigurationsdatei `config.toml`
In der Konfigurationsdatei `config.toml` können global Parameter definiert werden.

{{<code lang="toml" title="Parameter in config.toml">}}
 [Params]
	param01 = true
{{</code>}}

{{<code lang="go-html-template" title="Beispiel *.html">}}
 <!-- Ist der Parameter param01 in der config.toml definiert -->
 {{- if .Site.Params.param01 -}}
 	dann mach dieses hier ...
 {{- end -}}
{{</code>}}

## Parameter&uuml;bergabe von Markdowndatei (\*.md) in eine shortcodesdatei (\*.html)
Parameter können aus einer Mardowndatei `*.md` in eine Shortcodesdatei `./shortcodes/sampleparameter.html` übergeben werden und verschiedene Funktionen ausführen.
Die Übergabe der Parameter kann in zwei verschiedenen Versionen erfolgen. Zum einen per Index (fortlaufender Nummer) und zum anderen per Name.


### Parameter&uuml;bergabe mittels fortlaufender Nummer (index)

{{<code lang="go-html-template" file="/themes/mab-3.0/layouts/shortcodes/sampleparameter.html" options="linenos=false" title="filename">}} {{</code>}}

Aufruf der Shortcodedatei `sampleparameter.html` in Markdown und Übergabe der Parameter als fortlaufende Nummer.

{{<code lang="md" title="Markdowndatei ./content/ *.md">}}
 {{</*sampleparameter huhu1 hahah2*/>}}
{{</code>}}

__Ergebnis:__ Das von Gohugo erzeugte statische Html sieht dann so aus:

```go-html-template {linenos=false}
 {{<sampleparameter huhu1 hahah2>}}

```

### Parameter&uuml;bergabe mit definiertem Namen


{{<code lang="go-html-template" title="./shortcodes/gallary.html">}}
 {{ $id1 := .Get "ParameterName01" }}  
 {{ $id2 := .Get "ParameterName02" }}
{{</code>}}

{{<code lang="go-html-template" title="./shortcodes/gallary.html mit Parameterprüfung">}}
 {{/* Mit vorhergehender Prüfung des Parameters */}}
 {{ with .Get "ParameterName01" }}
	{{ $id1 := . }}  
	Parameter 01 vorhanden: {{ $id1 }}
 {{ else }}
	Parameter Nicht vorhanden	
 {{ end }}
{{</code>}}

{{<code lang="go-html-template" title="./shortcodes/gallary.html mit Parameterprüfung und globaler Verfügbarkeit">}}
 {{/* Mit vorhergehender Prüfung des Parameters und globaler Verfügbarkeit */}}
 {{ with .Get "ParameterName01" }}
	{{ $.Scratch.Set "id" . }}  
	Parameter 01 vorhanden: {{ $.Scarch.Get "id" }}
 {{ else }}
	Parameter Nicht vorhanden	
 {{ end }}
 {{ $.Scarch.Get "id" }} {{/* verwenden außerhalb der Schleife */}}
{{</code>}}


{{<code lang="md" title="Markdowndatei ./content/ *.md">}}
 {{</*gallary ParameterName01="huhu1" ParameterName02="hahah2"*/>}}
{{</code>}}

Sinnvoll ist es vorher zu prüfen ob ein definierter Name als Parameter verwendet wird. Das kann mit der Funktion `.IsNamedParams` erfolgen.

{{<code lang="go-html-template" title="./shortcodes/gallary.html">}}
 {{ if .IsNamedParams }}
	yes - ein Parameter wurde per Name definiert
 {{ else }}
	no - ein Parameter kann vorhanden sein (z.B. per index), ist aber nicht als Parameter definiert
 {{ end }}
{{</code>}}

## Parameter&uuml;bergabe von \*.html zu \*.html

{{<code lang="go-html-template" file="/themes/mab-3.0/layouts/partials/sampleparameter.html" options="linenos=false" title="filename">}} {{</code>}}

Aufruf aus einer \*.html Datei z.B. partials/header.html mit:
```go-html-template {linenos=false}
   
 {{ $myparam := slice "hahahaha" "huhuhu" }}
 {{ partial "sampleparameter" $myparam }}
   
```

