+++
tags = ["edv", "dev", "gohugo", "markdown"]
zusammenfassung = "Bilder, Grafiken in Markdown."
title = "Bilder Fotos Grafiken"
date = "2022-09-16T10:53:21+02:00"
type = "article"
+++


## Bilder in Markdown einbinden

Bilder werden in Markdown standardmäßig mit folgender Syntax aufgerufen:

{{<code lang="apl">}}
 # Kurzform 
 ![](/path/to/image.jpg)

 # Optional mit Titel und alternativer Bezeichnung.
 ![alternative Bezeichnung](/path/to/image.jpg "Titel")
{{</code>}}


{{<code lang="apl" title="Beispiele">}}
 ![](/Inhalt/Bild1.jpg)
 ![](/images/Bild2.jpg)
 ![](/svg/Bild2.svg)
 ![Kein Bild geladen](/images/image.jpeg "Titel des Bildes")
{{</code>}}

Das Standardverzeichnis für Bilder ist `static` oder alles unterhalb von `content`. 

{{<code lang="shell" options="linenos=false,hl_lines=5 9 11">}}
 gohugo-work-directory
  ├── content
  │   └── Inhalt
  │       └── Bild1.jpg
  ├── data
  ├── static
  │   ├── images
  │   │   └── Bild2.jpg
  │   └── svg
  │       └── Bild2.svg
  └── themes
{{</code>}}


## Weitere Parameter 

Mit Hilfe von [render_hooks][] wurden weitere Parameter hinzugefügt. Diese Parameter sind Optionen für die Position und Rahmen, sowie Links in der Textzeile des Bildes und die Größendarstellung.   

{{<code lang="apl" title="Erweiterter Aufruf mit Parametern">}}
 ![](/path/to/image.jpg "Title {ClassOption01 ClassOption02}")
 ![](/path/to/image.jpg "Title {ClassOption01 ClassOption02}[[Linkname01=href...][Linkname02=href...][...]]")
 ![](/path/to/image.jpg "Title {ClassOption01 ClassOption02}[[Linkname01=href...][Linkname02=href...][...]] #width=80%")
{{</code>}}


#### 1. ClassOptionen

Mit `ClassOption` wird die Position des Bildes im Text und/oder ein Rahmen festgelegt. 

{{<code lang="apl" title="Aufruf mit ClassOptionen">}}
 ![](/images/Blume.jpg "Bild rechts mit Rahmen {right frame}" )
{{</code>}}

{{<mytable class="greyhead small smallfont fontcourier striped">}}
| Option   | Usage                                                                                                                               |
| -------- | ----------------------------------------------------------------------------------------------------------------------------------- |
 frame    | Rahmen
 left     | Bild links vom Text.
 right    | Bild rechts vom Text.
|         | Das Bild wird zentriert wenn keine Option zur Position übergeben wird.
{{</mytable>}}

Die Positionierung der Bilder sind mit dem entsprechenden [Responsive Design][responsive_design] ausgestattet und verhalten sich auf mobilen Endgeräten anders.
Das Bild wird zentriert.

{{<expand title="Beispiel mit ClassOption">}}
 ![Kein Bild geladen.](/images/Blume.jpg "Bild zentriert" ){{<mustertext>}}
 ![Kein Bild geladen.](/images/Blume.jpg "Bild links {left}" ){{<mustertext>}}
 ![Kein Bild geladen.](/images/Blume.jpg "Bild rechts mit Rahmen {right frame}" ){{<mustertext>}}
{{</expand>}}


#### 2. Links im Bildtitel

Im Bildtitel können Verweise zu anderen Seiten (zum Beispiel zu Quellen oder Copyright) mit gegeben werden.

{{<code lang="apl" title="Aufruf mit Links">}}
 ![](/images/Blume.jpg "Bild mit Link im Titel[[Home=https://www.vermessungsprogramme.de]]" )
{{</code>}}

{{<expand title="Beispiel mit Link zu eigenen Homepage im Bildtitel">}}
![Kein Bild geladen.](/images/Blume.jpg "Bild mit Link im Titel[[Home=https://www.vermessungsprogramme.de]]" )
{{</expand>}}

{{<expand title="Beispiel mit Link zu Copyright">}}
![altern. Text](/svg/Geodetic_latitude_and_the_length_of_Normal.svg "Ellipsoidische Breite {frame left}[[Kkddkkdd=https://commons.wikimedia.org/wiki/File:Geodetic_latitude_and_the_length_of_Normal.svg][CC BY-SA 3.0=https://creativecommons.org/licenses/by-sa/3.0/deed.de]]"){{<mustertext text="trapattoni">}}
{{</expand>}}

#### 3. Bildgr&ouml;&szlig;e mit #width anpassen

Der Parameter `#width=xx%` definiert die Breite des dargestellten Bildes. Damit können Anpassung insbesondere bei `*.svg` vorgenommen werden.

{{<code lang="apl" title="Aufruf mit #width">}}
 ![](/images/Blume.jpg "mit width #width=25%" )
{{</code>}}

{{<expand title="Beispiel mit #width">}}
 ![Kein Bild geladen.](/images/Blume.jpg "ohne width" )
 ![Kein Bild geladen.](/images/Blume.jpg "mit width #width=25%" )
{{</expand>}}


{{<expand title="Noch ein Beispiel mit allen Parametern">}}
![Kein Bild geladen.](/images/twitter.png "Bild zentriert" ){{<mustertext>}}
![Kein Bild geladen.](/images/twitter.png " rechts {right}" ){{<mustertext>}}
![Kein Bild geladen.](/images/twitter.png "Bild links {left}" ){{<mustertext>}}
![myImage](/images/Bild2.jpg "Bild mit Rahmen und verkleinert mit width {frame} #width=70%"){{<mustertext text="trapattoni">}}
{{</expand>}}


## Creative Commons, Lizenz

[Creative Comons][CC_wiki] sind vorgefertigte Standardlizenzvereinbarungen unter der ein Urheber sein Werk veröffentlichen kann.
Auf den Seiten der [Wikimedia Commons][commons_wikimedia] stehen bereits viele Bilder, Video's und auch Audioaufzeichnungen unter der [CC-lizenz][CC] 
zur Verfügung. Wichtig ist dabei die jeweiligen Bedinungen zur Verwendung des Materials einzuhalten.

{{<columns>}}


![altern. Text](/images/Altenburg_Epidemie_1865.jpg "Vogt, F.A.: Bericht über die Epidemieen..., Seite 1 {frame} [[Quelle BSB=https://www.digitale-sammlungen.de/view/bsb10380296?page=6,7][NC=https://rightsstatements.org/page/NoC-NC/1.0/]]")

<--->

![altern. Text](/images/CC-Birthday.jpg "Timothy Vollmer: CC 10th Birthday Celebration {frame} [[Quelle=https://www.flickr.com/photos/sixteenmilesofstring/8256206923/in/set-72157632200936657][CC BY 4.0=https://creativecommons.org/licenses/by/4.0/deed.de]]")

<--->

![altern. Text](/svg/Geodetic_latitude_and_the_length_of_Normal.svg "ellips. Breite {frame} [[Kkddkkdd=https://commons.wikimedia.org/wiki/File:Geodetic_latitude_and_the_length_of_Normal.svg][CC BY-SA 3.0=https://creativecommons.org/licenses/by-sa/3.0/deed.de]]")

<--->

   

{{</columns>}}

## Medienanbieter

Für die Suche nach Bildern, Clipart's, Video- und Audioaufzeichnungen stehen z.B. folgende Seiten zur Verfügung:
: [Wikimedia][commons_wikimedia] 
: [OpenClipArt][openclipart]  [(Wiki)][openclipart_wiki]
: [OpenVerse][openverse]
: [Bavarikon][bavarikon]
: [MDZ][] Münchener DigitalisierungsZentrum
: [flickr][] teilweise CC
: [Dresden Stadtbildfotografie][] Nach einem Zeitungsbericht (DNN 21.12.2023) unter CC


[CC]:					https://creativecommons.org/licenses/
[commons_wikimedia]:	https://commons.wikimedia.org/wiki/Hauptseite
[CC_wiki]:				https://de.wikipedia.org/wiki/Creative_Commons
[render_hooks]:	 		{{< relref "render-hooks" >}}
[responsive_design]: 	https://de.wikipedia.org/wiki/Responsive_Webdesign
[openverse]:			https://openverse.org
[bavarikon]:			https://www.bavarikon.de
[MDZ]:					https://www.digitale-sammlungen.de/
[openclipart_wiki]:		https://de.wikipedia.org/wiki/Open_Clip_Art_Library
[openclipart]:			https://openclipart.org/
[flickr]:			https://www.flickr.com/search/?text=
[Dresden Stadtbildfotografie]:	https://www.dresden.de/de/rathaus/aemter-und-einrichtungen/unternehmen/stadtarchiv/stadtbildfotografie.php
