+++
tags = ["dev", "gohugo", "funktion"]
zusammenfassung = "Zusammenstellung und Kurzinformation zu einigen ausgewählten Gohugo Funktionen, Methoden und Variablen."
title = "Gohugo Funktionen, Methoden und Variablen"
submenu = "false"
date = "2021-01-13T09:20:15+01:00"
type = "article"
+++

Eine vollständige Liste aller [Funktionen][] und [Methoden][] sind auf der Gohugo Seite zu finden.


## Eigene Funktion 

In Gohugo ist es möglich eigene Funktionen zu schreiben und sie in Markdowndateien `(*.md)` oder Shortcodes `(*.html)` zu verwenden.

### Zufallszahl generieren `{{</*random*/>}}`

Als Beispiel für eine eigene Funktion wird eine Funktion zum Generieren einer Zufallszahl `{{</*random*/>}}` eingerichtet.
Folgende Dateien mit gleichem Namen werden in unterschiedliche Verzeichnisse angelegt.

{{<code lang="go-html-template" title="Datei 1:  ./layouts/partials/random.html">}}
 {{ $seed := "foo" }}
 {{ $random := delimit (shuffle (split (md5 $seed) "" )) "" }}
 {{ $random }}
{{</code>}}

{{<code lang="go-html-template" title="Datei 2:  ./layouts/shortcodes/random.html">}}
 {{ partial "random" . }}
{{</code>}}

In der Shortcodesdatei wird einfach die Datei `./layouts/partials/random.html` aufgerufen. Damit ist die Funktion `random` für Markdown- und für Html-Dateien verfügbar und kann wie folgt aufgerufen werden.

```go-html-template {linenos=false}

 {{</*random*/>}} 			// Aufruf in Markdown
 {{ partial "random" . }}	// Aufruf in Html
   
```

Ergebnis:

{{<random>}}

#### Anwendungsbeispiel

Der Zufallsgenerator findet hervoragend Anwendung im automatischen generieren von eindeutigen Kennzeichen bei der Verwendung der Html-Elemente `<input>` und `<label>`.
Eine beispielhafte Anwendung ist: `./layouts/shortcodes/expand.html`


```go-html-template {linenos=false}

 {{ $zufall := partial "random" . }}
  ...
  <input id="expand.{{replaceRE "\\s" "" $zufall}}" ...  >
  <label for="expand.{{replaceRE "\\s" "" $zufall}}" ... >
 ...
   
```

__Hinweis:__ Die in der Variablen `$zufall` enthaltene Zahl wird mit einem Leerzeichen (whitespace) übergeben.   
Die Funktion ` {{replaceRE "\\s" "" $zufall}} ` ersetzt alle Leerzeichen `"\\s"` mit `""` - nichts -.  


## Zeit- und Datumsangaben

Gohugo bietet eine eigene [Time-Methode][Methods-Time] für Zeit- und Datumsangaben an. Insbesondere sind Datumsangaben der Seiten und Dateien interessant. 

{{<result type="Date">}}

Zur [Datumsformatierung][] siehe folgende Tabelle.

{{<result type="Date.Format">}}

## Gohugo Funktionen

__Hinweis:__   
Die aufgeführten Funktionen können in entsprechenden `*.html` Dateien angewendet und aufgerufen werden. In Markdowndateien `*.md` ist das nicht möglich, bzw. nur über den Umweg eines entsprechenden __Shortcodes__ (Stand: 01.2021):

### GetPage
[.GetPage][] liefert den Path einer Seite (`*.md`) zurück.

```go-html-template {linenos=false}

 {{ $variable01 := .Site.GetPage "funktion.md" }}
 {{ $variable01 }}     
   
```

### urls.Parse
[urls.Parse][] splitet eine [URL][] (Uniform Resource Locator) in seine einzelnen Bestandteile.

```go-html-template {linenos=false}

 {{ $url := "https://www.vermessungsprogramme.de/test/system/gohugo/#Ueberschrift" }}
 {{ $parse := urls.Parse $url }}

 {{ $parse.Scheme }}
 {{ $parse.Host }}
 {{ $parse.Path }}
 {{ $parse.Fragment }}
   
```

Ergebnis (tabellarisch):

{{<result type="urls.Parse" param="https://www.vermessungsprogramme.de/test/system/gohugo/#Ueberschrift">}}

### readDir

Die Funktion [readDir][] listet alle Dateien und Verzeichnisse auf.

```go-html-template {linenos=false}

 {{ $files := readDir "./content" }} 
 {{ range $files }} 
	{{ .Name }}
 {{ end }}
   
```

Ergebnis (tabellarisch):

{{<result type="readDir" param="./content">}}

### os.Stat

Für umfangreiche Datei- und Verzeichnisinformationen stehen weitere Funktionen von [os.Stat][] bereit.

```go-html-template {linenos=false}

 {{ $files := readDir "./content" }} 
 {{ range $files }} 
	{{ .Name }}
	{{ .IsDir }}
	{{ .Size }}
	{{ .ModTime }}
 {{ end }}
   
```

Ergebnis (tabellarisch):

{{<result type="os.Stat" param="./content">}}

Die Variable `.ModTime` der Funktion [os.Stat][] gibt die letzte Modifizierungszeit der Datei an. Diese ist identisch mit der im Dateimanager angegebenen Zeit.

{{<result type="os.Stat.ModTime">}}



### Scratch - newScratch

[.Scratch][] dient zum Speichern und Bearbeiten von Daten. Das folgende Beispiel zeigt die Verwendung von `.Scratch.Set` und `.Scratch.Add`. 
Durch die Funktion `.Scratch.Get` wird letztendlich die Variable `XXX` ausgegeben.

```go-html-template {linenos=false}

 {{ $var01 := path.Dir .Page.File }}
 {{ $.Scratch.Set "XXX" $var01 }}
 {{ $.Scratch.Get "XXX" }}
 {{ $.Scratch.Set "ZZZ" $var01 }}
 {{ $.Scratch.Add "ZZZ" "/image" }}
 {{ $.Scratch.Get "ZZZ" }}
   
```
Ergebnis:

{{<result type=".Scratch">}}

__Hinweis:__
Es kann vorkommen das [.Scratch][] nicht funktioniert und Gohugo mit einer Fehlermeldung den Dienst verweigert.

```cmd {linenos=false}

 execute of template failed at <$.Scratch.Set>: can’t evaluate field Scratch in type goldmark.linkContext
   
```
Verwende in diesem Fall die Funktion `newScratch`. Mit der Funktion `newScratch` kann jeder Variablen auch eine Scratch-Instanz zugewiesen werden. 

```go-html-template {linenos=false}

 {{ $var01 := path.Dir .Page.File }}
 {{ $storage := newScratch }}	
 {{ $storage.Set "XXX" $var01 }}
 {{ $storage.Get "XXX" }}
 {{ $storage.Add "XXX" "/image" }}
   
```

### Path Funktionen

Am Beispiel des Rückgabewertes der Methode [.Page.File][] werden die Ergebnisse der [Path-Funktion][] in der Tabelle gezeigt. 
Besonders interessant ist die Funktion [path.Clean][]. Diese ersetzt den in Windows verwendeten Backslash in ein Slash und löscht Doppelslash.

{{<result type="path.xxx">}}

Die Funktion [path.Split][] unterteilt in Verzeichnisnamen und Dateinamen.

{{<result type="path.Split">}}

### Strings

Beispiele um Strings zu verarbeiten.

{{<result type="strings">}}

### FindRE - Suchen und finden

Die Funktion [FindRE][] sucht eine Zeichenfolge mittels regulärer Ausdrücke in einer Datei oder einem String und gibt das Ergebnis als `range` zurück.
   
Ein [regulärer Ausdruck][RegularExpressions] (engl.: Regular expressions) ist die Beschreibung einer bestimmten Menge von Zeichen in einer Folge. 

#### Beispiel 1

Das Beispiel `<a href.*?>(.|\n)*?</a>` sucht alle Hyperlinks in einer Html-Datei. Also alles, was mit `<a href` beginnt und mit `</a>` endet.

```go-html-template {linenos=false}

 {{ $findReturn := findRE `<a href.*?>(.|\n)*?</a>` (readFile "./themes/mab-3.0/layouts/partials/header.html" ) }}

 <!-- Anzahl gefundener Übereinstimmungen -->
 {{ $count := len $findReturn }}

 <!-- Ausgabebeispiel 1 per index --> 
 {{ $out := index $findReturn 0 }} {{ $out }}
 {{ $out := index $findReturn 1 }} {{ $out }}
 {{ $out := index $findReturn 2 }} {{ $out }}

 <!-- Ausgabebeispiel 2 per range --> 
 {{ range $element, $findReturn }}
	{{ $element }}
 {{ end }}

 <!-- Ausgabebeispiel 3 per range und increment -->
 {{ range $i, $element := $findReturn }}
	{{ $i }} {{ $element }}
 {{ end }}		
   
```

{{<result type="findRE_Sample01">}}



#### Beispiel 2

In der Variablen `SuchString` wird nur der Teil in der geschweiften Klammer extrahiert. 
Der verwendete [reguläre Ausdruck][RegularExpressions] `{[[:word:][:space:]]*}` sucht ein oder mehrere der Zeichen `[0-9A-Za-z_] [\t\n\v\f\r ]`, die sich innerhalb der geschweiften Klammer befinden.

```go-html-template {linenos=false}

 {{- $SuchString := "Erster Teil des Strings {Zweiter Teil des Strings}" -}}
 {{- $step1 := findRE `{[[:word:][:space:]]*}` $SuchString  -}}
 {{- if ne (len $step1) 0 -}}
	{{- $step2 := index $step1 0 -}}
	{{- $step3 := trim $step2 "{}" -}}
		
	<br>SuchString = {{ $SuchString }}
	<br>
	<br>Teil1 = {{ $step1 }}
	<br>Teil2 = {{ $step2 }}
	<br>Teil3 = {{ $step3 }}
	<br>
	{{- range $index, $value := split $step3 " " -}}
		{{- if ne $value "" -}}
			<br>Wert {{ $index }} = {{ $value }}
		{{- end -}}
	{{- end -}}
 {{- end -}}
   
```
Ergebnis:

{{<result type="findRE_Sample02">}}


## Gohugo Methoden

Für die Verwendung in Webseiten stellt Gohugo eine Vielzahl von [Methoden][] zur Verfügung.

### Site

Mit dem englischen Begriff _Site_ ist im deutschen Sprachgebrauch eine Webseite gemeint.
Die [Site-Variable][.Site] dient dem Zugriff auf globale Variablen eines Webseitenprojektes.
 
{{<result type=".Site">}}

### Page 

Mit der Methode [.Page][] kann auf Eigenschaften einer Markdown-Inhaltsseite `(*.md)` zugegriffen werden. 

#### Page.File

Die Variable [.Page.File][] gibt Informationen über die Markdowndatei zurück.

{{<result type=".Page.File">}}

#### Page.GitInfo

Mit der Variablen [.GitInfo][] kann auf Information der [Git-Versionsverwaltung][] zugegriffen werden, sofern man Git in einem Gohugo-Projekt verwendet.
Die Information beziehen auf die angegebene Markdown-Inhaltseite `(*.md)`.

{{<result type=".Page.GitInfo">}}

Folgender Schalter muss in der Datei `config.toml` gesetzt sein.

{{<code lang="toml" title="config.toml" options="linenos=false">}}
 enableGitInfo          = true
{{</code>}}


#### Page.Params

Page.Params beinhaltet alle Variablen im Kopf einer Markdowndatei.

{{<code lang="apl" title="Kopf einer Markdowndatei ./content/../*.md">}}
 +++
 tags = ["dev", "gohugo", "funktion"]
 zusammenfassung = "Zusammenstellung und Kurzinformation zu einigen ausgewählten Gohugo Funktionen und Variablen."
 title = "Gohugo Funktionen und Variablen"
 submenu = "false"
 date = "2021-01-13T09:20:15+01:00"
 type = "article"
 +++
{{</code>}}

Der Zugriff kann per Einzelabruf, per Range oder zusammen erfolgen.
   
{{<result type=".Page.Params">}}



#### Weitere Page.Variablen

{{<result type=".Page.xxx">}}



[Funktionen]:	https://gohugo.io/functions/
[Methoden]:	https://gohugo.io/methods/
[Variablen]:	https://gohugo.io/methods/
[URL]:		https://pkg.go.dev/net/url?utm_source=godoc#URL
[urls.Parse]: 	https://gohugo.io/functions/urls.parse/
[readDir]:	https://gohugo.io/functions/readdir/
[os.Stat]:	https://gohugo.io/functions/os.stat/
[.GetPage]: 	https://gohugo.io/functions/getpage/
[Path-Funktion]:https://gohugo.io/functions/path/
[.Page]:	https://gohugo.io/methods/page/
[.Page.File]:	https://gohugo.io/methods/page/file/
[.Site]:	https://gohugo.io/methods/site/
[.Scratch]:	https://gohugo.io/functions/scratch/
[.GitInfo]:	https://gohugo.io/methods/page/gitinfo/
[path.Clean]:	https://gohugo.io/functions/path.clean/
[path.Split]:	https://gohugo.io/functions/path.split/
[FindRE]:	https://gohugo.io/functions/findre/
[Git-Versionsverwaltung]:  	{{< relref "edv/dev/git/git-befehle" >}}
[Datumsformatierung]:		https://gohugo.io/methods/time/format/
[Methods-Time]:			https://gohugo.io/methods/time/
[RegularExpressions]:		https://github.com/google/re2/wiki/Syntax
