+++
tags = ["dev", "gohugo", "markdown", "css"]
zusammenfassung = "Gohugo Markdownelemente mit CSS anpassen."
title = "Markdown anpassen"
submenu = "false"
date = "2021-08-24T14:54:58+02:00"
+++


## Anpassen einer &Uuml;berschrift an ein eigenes Style.

In Markdown wird eine Überschrift eingeleitet mit den Hashzeichen `#`. Das Style der Überschrift kann in einer CSS-Datei angepasst werden.

{{<code lang="scss" title="Ueberschrift.scss">}}
 h4 {
	margin-top: 1em;
	color: red;
 }
{{</code>}}

### Aufruft &uuml;ber CSS/Selector class

Um nun neben diesem Style ein anderes (zweites) Style für die Überschrift `<h4>` in Markdown anzuwenden, wird einfach eine Elementklasse `custom` für das Html-Element `<h4>` angelegt.


{{<code lang="scss" title="Ueberschrift.scss">}}
 h4 {
	margin-top: 1em;	/* Abstand */
	color: 	    red;	/* Textfarbe */

	&.custom {
		margin-top: 5em;
		color:	    gray;		
	}
 } 
{{</code>}}

In Markdown wird diese spezielle Überschrift wie folgt aufgerufen:

```sass {linenos=false}

 #### Überschrift {class=custom}
   
```


### Aufruft &uuml;ber CSS/Selector ID

Anstatt eines Klasseselectors kann auch eine ID verwendet werden. Ein ID-Selector wird mit dem Hashzeichen `#` gefolgt von einer eindeutigen Bezeichnung eingeleitet `(z.B #customID)`.


{{<code lang="scss" title="Ueberschrift.scss ">}}
 h4#customID {
	margin-top: 5em;
	color: 	    gray;
 }
{{</code>}}

Ein Aufruf in Markdown erfolgt dann so:

```sass {linenos=false}

 #### Überschrift {#customID}
   
```

__Hinweis:__ Es wird zwischen Groß- und Kleinschreibung unterschieden.


## Entfernen der Symbole bei Aufz&auml;hlungslisten

Manchmal ist es wünschenswert das Aufzählungslisten ohne Aufzählungszeichen darzustellen. 
Dieses Symbol wird mit Hilfe von Shortcodes und CSS entfernt.

Lege folgende Dateien an.

{{<code lang="go-html-template" title="Shortcode: layouts/shortcodes/nolistsymbol.html">}}
 <span class="nolistsymbol"></span>
{{</code>}}

{{<code lang="scss" title="CSS: layouts/assets/sass/listen.scss">}}
 span.nolistsymbol + ul {
    list-style: none;
 }
{{</code>}}

Die Anwendung in Markdown (`*.md`) erfolgt so:

{{<code lang="apl" title="Markdownfile (*.md)">}}
 ... mit unerwünschtem Symbol 

 + [x] something is DONE.
 + [ ] something is NOT DONE.

 Anwendung ohne Symbol (Wichtig: Leerzeile vor {{</*nolistsymbol*/>}})

 {{</*nolistsymbol*/>}}
 + [x] something is DONE.
 + [ ] something is NOT DONE.
{{</code>}}

Ergebnis:

... mit unerwünschtem Symbol 

+ [x] something is DONE.
+ [ ] something is NOT DONE.


Anwendung ohne Symbol 

{{<nolistsymbol>}}
+ [x] something is DONE.
+ [ ] something is NOT DONE.

## &Uuml;berschriften mit Kapitelnummerierung

Mit Hilfe eines CSS-Zählers (counter) können Überschriften und Unterüberschriften mit einer fortlaufenden Nummerierung dargestellt werden. 
Die Nummerierung erfolgt automatisch. 
Und wie das immer so ist, die hier dargelegten Erkenntnisse stammen aus dem [Internet](https://www.mediaevent.de/css/counter-reset.html).
   
Das folgenden Beispiel zeigen zwei Arten der Umsetzung. 


{{<tabs>}}
{{<tab "Umsetzung mit Custom-ID">}}

Ansprechen mittels Custom-ID = counter in einer Markdowndatei (*.md)

```scss {linenos=false}"

 ## Überschrift {#count}
   
```

Folgende Eigenschaften der Überschriften werden in einer *.scss Datei festlegt.


```scss {linenos=false}
 h2 {
    counter-increment: KapNum2;
    counter-reset:     KapNum3 0;
 }
 h3 {
    counter-increment: KapNum3;
    counter-reset:     KapNum4 0;
 }
 h4 {
    counter-increment: KapNum4;
 }
 h2#count:before { content: counter(KapNum2) '\00A0\00A0\00A0\00A0'; }	
 h3#count:before { content: counter(KapNum2) "." counter(KapNum3) '\00A0\00A0'; }	
 h4#count:before { content: counter(KapNum2) "." counter(KapNum3) "." counter(KapNum4) '\00A0'; }	
```

{{</tab>}}
{{<tab "Umsetzung mit Class-ID">}}

Ansprechen mittels Class-ID = counter in einer Markdowndatei (*.md)

```scss {linenos=false}"

 ## Überschrift {class=counter}
   
```

Folgende Eigenschaften der Überschriften werden in einer *.scss Datei festlegt.
   
```scss {linenos=false}
 h2 {
    counter-increment: KapNum2;
    counter-reset:     KapNum3 0;
    &.counter::before {
       content: counter(KabNum2) '\00A0\00A0\00A0\00A0';
    }	
 }

 h3 {
    counter-increment: KabNum3;
    counter-reset:     KabNum4 0;
    &.counter::before {
       content: counter(KabNum2) "." counter(KabNum3) '\00A0\00A0';
    }
 }	

 h4 {
    counter-increment: KabNum4;
    &.counter::before {
       content: counter(KabNum2) "." counter(KabNum3) "." counter(KabNum4) '\00A0';
    }
 }

```

Im Unterschied zur Verwendung einer "Custom-ID" ist die "Class-ID" übersichtlicher.


{{</tab>}}
{{</tabs>}}


{{<expand title="Beispiel 1 Kapitelnummerierung in Überschriften">}}

__Mardownfile:__

```scss {linenos=false}"

# &Uuml;berschrift h1 (ohne Zähler) {class=counter}
## &Uuml;berschrift h2 {class=counter}
### &Uuml;berschrift h3 {class=counter}
#### &Uuml;berschrift h4 {class=counter}
#### &Uuml;berschrift h4 {class=counter}
##### &Uuml;berschrift h5 {class=counter}
### &Uuml;berschrift h3 {class=counter}
## &Uuml;berschrift h2 {class=counter}
#### &Uuml;berschrift h4 {class=counter}
#### &Uuml;berschrift h4 {class=counter}
### &Uuml;berschrift h3 {class=counter}
### &Uuml;berschrift h3 {class=counter}
### &Uuml;berschrift h3 {class=counter}
#### &Uuml;berschrift h4 {class=counter}
#### &Uuml;berschrift h4 {class=counter}
#### &Uuml;berschrift h4 mit customID {#customID}
   
```


__Ergebnis:__
# &Uuml;berschrift h1 (ohne Zähler) {class=counter}
## &Uuml;berschrift h2 {class=counter}
### &Uuml;berschrift h3 {class=counter}
#### &Uuml;berschrift h4 {class=counter}
#### &Uuml;berschrift h4 {class=counter}
##### &Uuml;berschrift h5 {class=counter}
### &Uuml;berschrift h3 {class=counter}
## &Uuml;berschrift h2 {class=counter}
#### &Uuml;berschrift h4 {class=counter}
#### &Uuml;berschrift h4 {class=counter}
### &Uuml;berschrift h3 {class=counter}
### &Uuml;berschrift h3 {class=counter}
### &Uuml;berschrift h3 {class=counter}
#### &Uuml;berschrift h4 {class=counter}
#### &Uuml;berschrift h4 {class=counter}
#### &Uuml;berschrift h4 mit customID {#customID}
{{</expand>}}

{{<expand title="Beispiel 2 Kapitelnummerierung in Überschriften">}}

Mit der CSS-Klasse `counter2` wird die Kapitelnummerierung ab der Überschriftsebene __h3__ gestaltet. Damit entfällt die Kapitelnummerierung der Überschriftsebene __h2__ und __h1__.

__Mardownfile:__

```scss {linenos=false}"

### Kapitel &Uuml;berschrift h3 {class=counter2}
#### Kapitel &Uuml;berschrift h4 {class=counter2}
#### Kapitel &Uuml;berschrift h4 {class=counter2}
##### Kapitel &Uuml;berschrift h5 {class=counter2}
##### Kapitel &Uuml;berschrift h5 {class=counter2}
   
```


__Ergebnis:__
### Kapitel &Uuml;berschrift h3 {class=counter2}
#### Kapitel &Uuml;berschrift h4 {class=counter2}
#### Kapitel &Uuml;berschrift h4 {class=counter2}
##### Kapitel &Uuml;berschrift h5 {class=counter2}
##### Kapitel &Uuml;berschrift h5 {class=counter2}
{{</expand>}}

## Letzten Textblock ändern

Ein normaler Text in Markdown wird letztendlich in Html als Absatztext innerhalb des Html-Elements `<p> ... <\p>` generiert. 
Der letzte Textabsatz kann mittels <abbr title="Cascading Style Sheets">CSS</abbr> und dem Aufruf von `{class="myclass"}`, bzw. `{.myclass}` anders gestalten werden.
Dazu muss in der Konfigurationsdatei `config.toml` das Block-Attribut eingeschaltet werden.

{{<code lang="toml" title="config.toml" options="linenos=false,hl_lines=6">}}
[markup]
  defaultMarkdownHandler = "goldmark" 
  [markup.goldmark]
	[markup.goldmark.parser.attibute]
	  block = true
{{</code>}}

### Beispiel 1 - Textblock mit Rahmen

Das folgende Stylesheet umrandet den letzten Textblock mit einem grünen Rahmen. 

{{<code lang="scss" title="*.scss ">}}
 p {
	&.TestChangeBlock {
		border: 1px solid green;
		border-radius: 3px;
		padding: 1em 1em 1em 1em;
	}
 }
{{</code>}}

Die Anwendung in Markdown (`*.md`) erfolgt so:

{{<code lang="css" title="Markdownfile (*.md)" options="linenos=false,hl_lines=6 11">}}
Text im ersten Absatz. 
Ein Absatz endet immer mit einer Leerzeile.

Der zweite Absatz wird mit CSS angepasst.
{class="TestChangeBlock"}

Die Gestaltung des dritten Absatzes ist wie der Erste.

Der vierte Absatz ist wie der Zweite. 
{.TestChangeBlock}
{{</code>}}

__Ergebnis:__
   
Text im ersten Absatz. 
Ein Absatz endet immer mit einer Leerzeile.

Der zweite Absatz wird mit CSS angepasst.
{class="TestChangeBlock"}

Die Gestaltung des dritten Absatzes ist wie der Erste.

Der vierte Absatz ist wie der Zweite. 
{.TestChangeBlock}



### Beispiel 2 - Textblock in Spalten

Mit ein paar wenigen CSS-Eigenschaften wird ein Textblock spaltenweise angezeigt und die Darstellung wirkt wie ein Zeitungsartikel. Aufgrund des [Responsive Design][responsive_design] wird je nach Endgerät auch nur eine Spalte angezeigt.

{{<code lang="scss" title="*.scss ">}}
 p {
	&.col2 {
		column-count: 	2;
		column-rule: 	1px solid;
		column-width:	15em;
		gap: 		2em;
	}
 }
{{</code>}}


{{<code lang="css" title="Markdownfile (*.md)">}}
Text Text ...
{.col2}
{{</code>}}

__Ergebnis:__

{{<mustertext text="trapattoni">}}
{.col2}




[responsive_design]: 	https://de.wikipedia.org/wiki/Responsive_Webdesign
