+++
tags = ["dev", "gohugo", "markdown"]
zusammenfassung ="Markdown - Text mit einfachen Formatierungselementen gestalten. "
submenu = "false"
title = "Markdown mit gohugo."
date = "2020-12-14"
type = "article"
+++

## Was ist Markdown?

Markdown  ist eine in Textdateien angewendete Formatierungssprache, mit der durch einfache Formatierungselemente/-befehle ein Text gestaltet werden kann. 
Zum Beispiel erzeugt das Formatierungselement `##` eine Überschrift. 

```md {linenos=false}

## Was ist Markdown?
   
```

[Gohugo][Gohugo_Configure] verwendet standardmäßig die Bibliothek [Goldmark][] für das Übersetzten von Markdown in Html.
Es ist schnell, flexibel und konform mit [CommonMark.][CommonMark]

## Formatierungselemente in Markdown

Formatierungselemente sind einfache Symbole oder Sonderzeichen im Text die letztendlich mit einer Formatierungsfunktion belegt sind. 

{{<mytable caption="Einfach Formatierungselemente/-funktionen in Markdown" class="captleft small smallfont noborder fontcourier striped greyhead">}}
|Formatierungssymbol|Umsetzung in Html | Output|
|:--|:--|:--|
| # | \<h1\>` Überschrift 1. Kategorie `\<\/h1\>| |
| ## | \<h2\>` Überschrift 2. Kategorie `\<\/h2\>| |
| \_Text\_ | \<em\>`Text kursive`\<\/em\> | _Text_ |
| \*Text\* | \<em\>`Text kursive`\<\/em\> | *Text* |
| \_\_Text\_\_ | \<strong\>`Text fett`\<\/strong\> | __Text__ |
| \*\*Text\*\* | \<strong\>`Text fett`\<\/strong\> | __Text__ |

{{</mytable>}}

Weitere einfache Formatierungselemente sind [Listen][markdownListen] und Elemente zur [Textgestaltung.][markdownText]


### URL's (Links) f&uuml;r https, Bilder, Dateien, etc.

Url's werden im Text direkt als Link interpretiert. Allgemein können URL's am Ende der Markdowndatei (`*.md`) mit einer Kurzbezeichnung definiert und im Text verwendet werden [(&#8599;Gohugo Links and Cross Reference).](https://gohugo.io/content-management/cross-references/)
   
+ Url-Link direkt innerhalb eines Textes verwenden oder eingeschlossen mit spitzen Klammern `<...>`.

{{<code lang="md">}}
 https://www...
 <https://www...>
 <mail@www...>
{{</code>}}

+ Url-Link direkt innerhalb eines Textes mit anderer Bezeichnung.

{{<code lang="md">}}
 [Bezeichnung](http: www...de)
 [Bezeichnung](http: www...de "Title")
{{</code>}}
   
+ Url-Link am Ende der Markdowndatei

{{<code lang="go-html-template" options="linenos=false,linenostart=1,hl_lines=4-5 10">}}
 Text Text Text Text Text Text 
 Text Text Text Text Text Text 
 [LinkName01][]
 [anderer Text][LinkName01]
   
 Text Text Text Text Text Text 
 
 
 [LinkName01]:	https://de.wikipedia.org
{{</code>}}

   
+ Url-Link auf eigene Projektseite verlinken

```md {linenos=false}

 [Bezeichnung]:	({{</* relref "/path/path/markdownfile#ueberschrift" */>}} "Title")
 [code.html]:	 {{</* relref "/dev/gohugo/hilfe/shortcodes#codehtml" */>}}
 [git add]:	 {{</* relref "git-befehle#33-git-add" */>}}
   
```


>__Hinweis:__ Verwende ein Bindestrich bei Überschriften mit Leerzeichen und Nummerierung für die Leerzeichenüberbrückung. 


#### Bilder verwenden

Erzeuge im Arbeitsverzeichnis das Verzeichnis `static/images` und speicher deine Bilder darin. In Markdowndatei (`*.md`) kann wie folgt die Bilddatei eingebunden werden.


>{{<code lang="apl">}}
 ![Alternativer Bezeichnung](/images/twitter.png)
 ![](/images/twitter.png)
 ![No Image loaded](/images/image.jpeg#border)
 ![No Image loaded](/path/to/images/image.jpeg#border)
 ![No Image loaded](/path/to/images/image.jpeg "Titel des Bildes")
 ![No Image loaded](/path/to/images/image.jpeg "Titel des Bildes {CSS Selectoren}")
{{</code>}}


Für mehr Details siehe Artikel: [Bilder, Fotos, Grafiken.][Bilder_in_markdown]

#### Dateien als Download anbieten, bzw. statisch verlinken
Im Verzeichnis `static/pdf` kann eine Datei (`*.pdf, *.txt, etc`) abgelegt und wie folgt verwendet werden.

```html {linenos=false}

 [Download file](/pdf/sample.pdf)

``` 

Ergebnis:&nbsp;&nbsp;	[Download file](/pdf/sample.pdf)



### Aufz&auml;hlungslisten

Das Html-Element `<li>` erzeugt geordnete oder ungeordnete Listen.

#### Unordered Lists

{{<code lang="go-html-template" title="Unordere Lists in Markdown *.md">}}
 Listen können mit folgenden Aufzählungszeichen markiert werden:
 * Unordered list item 1.
 + Unordered list item 2.
 - Unordered list item 3.
{{</code>}}

Ergebnis:
* Unordered list item 1.
+ Unordered list item 2.
- Unordered list item 3.

#### Ordered Lists

{{<code lang="go-html-template" title="Ordered Lists in Markdown *.md">}}
 1. ordered list item 1.
 2. ordered list item 2.
   + sub-unordered Liste beginnen mit 3 Leerzeichen gefolgt von einem + Zeichen.
   + sub-unordered list item 2.
     + [x] something is DONE.
     + [ ] something is NOT DONE.
       + sub-sub liste mit 6 Leerzeichen gefolgt von einem + Zeichen
{{</code>}}

Ergebnis:
1. ordered list item 1.
2. ordered list item 2.
   + sub-unordered Liste beginnen mit 3 Leerzeichen gefolgt von einem + Zeichen.
   + sub-unordered list item 2.   
   [x] something is DONE.   
   [ ] something is NOT DONE.
       + sub-sub liste mit 6 Leerzeichen gefolgt von einem + Zeichen

#### Definition Lists

{{<code lang="go-html-template" title="Definition Lists in Markdown *.md">}}
 Zur besseren Differenzierung zwischen Text und Definitionsliste sollte eine Leerzeile (drei Leerzeichen in Markdown) vor der Definitionsliste eingefügt werden.
   
 First Term
 : This is the definition of the first term.

 Second Term
 : This is one definition of the second term.
 : This is another definition of the second term.
 : This is another definition of the second term.
{{</code>}}

Ergebnis:

Zur besseren Differenzierung zwischen Text und Definitionsliste sollte eine Leerzeile (drei Leerzeichen in Markdown) vor der Definitionsliste eingefügt werden.
   
First Term
: This is the definition of the first term.

Second Term
: This is one definition of the second term.
: This is another definition of the second term.
: This is another definition of the second term.


### Textgestaltung mit Markdown

#### Textbetonung (Emphasis), Schriftstil in Markdown

{{<code lang="go-html-template" title="Textbetonung">}}
 _kursiv 1_   *kursiv 2*

 __bold 1__  **bold 2**

 ___fett und kusiv 1___  ***fett und kursiv 2***

 ~~durchgestrichen~~
{{</code>}}

__Hinweis:__ Verwende vorrangig Unterstriche \(\_\) statt Asteriskszeichen \(\*\).

Ergebnis:
>
>_kursiv 1_   *kursiv 2*
>
>__bold 1__  **bold 2**
>
>___fett und kusiv 1___  ***fett und kursiv 2***
>
>~~durchgestrichen~~

#### Einfaches Texteinr&uuml;cken mit Blockquotes

{{<code lang="apl" title="Beispiel für Blockquotes in Markdown">}}
 > Einfaches ...
 >> und doppeltes Einruecken ...
 >>> und dreifaches Einruecken ...
 > > > oder mit Raum zwischen den Pfeilen (Arrows) ...
{{</code>}}

Ergebnis:
> Einfaches ...
>> und doppeltes Einruecken ...
>>> und dreifaches Einruecken ...
> > > oder mit Raum zwischen den Pfeilen (Arrows) ...

#### Zeilenumbruch

Ein einfacher Zeilenumbruch `<br>` wird in Markdown mit drei Leerzeichen in Html gerendert. Das Gleiche passiert auch wenn ein Text mit zwei Leerzeichen beginnt und endet.

Zum Beispiel:   
  Das ist die 1. Zeile mit zwei Leerzeichen am Beginn und am Ende  
  Das ist die 2. Zeile mit zwei Leerzeichen am Beginn und am Ende  
  Das ist die 3. Zeile mit zwei Leerzeichen am Beginn und am Ende  

### Textgestaltung mit HTML-Elementen

Für die Textgestaltung mit HTML-Elementen muss in der Konfigurationsdatei `config.toml` der Schalter `unsafe` gesetzt werden.

{{<code lang="toml" title="config.toml" options="linenos=false,hl_lines=6">}}
[markup]
  defaultMarkdownHandler = "goldmark" 
  [markup.goldmark]
	[markup.goldmark.renderer]
	  unsafe = true
{{</code>}}



#### Text hoch-, tiefgestellt

Mit dem Html-Element `<sup> ... </sup>` kann Text <sup>hochgestellt</sup> werden.   
Mit dem Html-Element `<sub> ... </sub>` kann Text <sub>tiefgestellt</sub> werden.   

#### Texthilfe verwenden

Mit dem Html-Element `<abbr title="Hilfetext"> ... </abbr>` (abbreviation = Abkürzung) wird ein Schriftzug mit einem kleinen Hilfetext versehen wenn der Mauszeiger über den Text fährt. 
Zum Beispiel:  
   
<abbr title="Hypertext Markup Language">Html</abbr> Seiten werden mit <abbr title="Cascading Style Sheets">CSS</abbr> gestaltet.

#### Schrift verkleinern mit \<small\>

Mit Hilfe des Html-Elements `<small> ... </small>` kann der Text in Markdown <small>verkleinert werden</small>.

#### Text für Keybord mit \<kbd\>

Press <kbd>Enter</kbd> to continue

### Textumbruch 

Mit der CSS-Eigenschaft `hyphens` wird das Verhalten für die automatische Silbentrennung festgelegt. Als Defaultwert hat die Eigenschaft `hyphens: manual;`. 
Damit kann jedes Wort, welches zu lang ist, mit dem Sonderzeichen `&shy;` an der Stelle markiert werden, an dem eine Worttrennung erfolgen soll.


{{<mytable class=" width30 nohead noborder captleft tableleft small smallfont fontcourier vtop">}}
  | Spalte 1  | Spalte 2 |
  |:----|:--|
  | Kreisgarten&shy;fachberaterbevollmächtigen&shy;zulassungsverordnung | Kreisgarten<b>\&shy;</b>fachberaterbevollmächtigen<b>\&shy;</b>zulassungsverordnung |
{{</mytable>}}




### Textgestaltung mit eigenem Shortcode

#### Menus im Text dargestellen

Siehe dazu im [Artikel Shortcodes.]({{< relref "shortcodes/#menuhtml" >}})


### Überschriften

Überschriften werden in Markdown mit dem Formatierungselement `#` erzeugt.

{{<mytable class="width50 tableleft small smallfont noborder fontcourier striped greyhead">}}
|Markdown|Umsetzung in Html |
|:--|:--|
| # | \<h1\>` Überschrift 1. Kategorie `\<\/h1\>|
| ## | \<h2\>` Überschrift 2. Kategorie `\<\/h2\>|
| ### | \<h3\>` Überschrift 3. Kategorie `\<\/h3\>|
{{</mytable>}}

{{<expand title="Beispiel Überschriften">}}
# Überschrift 1
{{<mustertext>}}
## Überschrift 2
{{<mustertext>}}
### Überschrift 3
{{<mustertext>}}
#### Überschrift 4
{{<mustertext>}}
##### Überschrift 5
{{<mustertext>}}
###### Überschrift 6
{{<mustertext>}}

{{</expand>}}



## Syntax Highlights
Gohugo bietet vorbereitete [Syntaxhighlights][Syntax Highlighting] und verwendet Chroma als Code-Textmarker. 
Es ist in Go gebaut und sehr, sehr schnell. 
Für eine Demo schau mal [hier][Pygments] und [da.](https://swapoff.org/chroma/playground/) 

### Chroma Styles
In der Konfigurationsdatei (config.toml) kann ein [Chroma Style][] zur Darstellung der Syntaxhightlight hinterlegt werden.

```go {linenos=false}

 pygmentsCodefences	= true
 pygmentsStyle     	= "emacs"

 # Weitere Styles sind 
 # pygmentsStyle		= "pygments"
 # pygmentsStyle		= "perldoc"
 # pygmentsStyle		= "dracule"

```

Global kann folgende Option mitgeben werden:

```go {linenos=false}

 pygmentsOptions = "linenos=table,linenostart=10"

```
Das ist jedoch nicht ratsam außer man verwendet eigene geänderte Styles (siehe unten). Besser ist es aber diese Option direkt vor der entsprechenden Syntax in der Markdowndatei zu setzen (siehe Beispiele Backtick's).

### Chrome Styles ver&auml;ndern

Auslesen eines entsprechenden Styles.

```html {linenos=false}

 hugo gen chromastyles --style=emacs > ./static/emacs.css 

```

Ergänzen der Datei: ./layouts/partials/header.html

```html {linenos=false}

 <link href="/emacs.css" type="text/css" rel="stylesheet" /> 

```

In der Konfigurationsdatei (config.toml) sind nun folgende Einstellungen notwendig:

```go {linenos=false}

 pygmentsCodefences = true
 # pygmentsStyle    = "emacs" # Abschalten
 pygmentsUseClasses = true
 pygmentsOptions    = "linenos=true"

```

### Backtick 

Chroma Syntaxhighlight's werden mit Backtick's eingeleitet oder als Shortcode `{{</*highlight*/>}}`. Es kann auch das Interpunktionszeichen ([Tilde][]  '`~`') verwendet werden.
In der Sprache wird ein Backtick als Akzent ([Gravis][]) zur Kennzeichnung einer besonderen Aussprache, Betonnung oder Bedeutung eines Buchstaben verwendet. Ein Backtick wird in der Informatik als alleinstehendes Zeichen bezeichnet. Syntaxhighlights mit Backticks beginnen mit drei aufeinanderfolgenden Backticks und enden mit drei aufeinanderfolgenden Backticks.
Alle Codezäune können in einem eigenen Shortcode [code.html][] ergänzt werden. 

{{<code lang="shell" title="Allgemeine Syntax für Codezäune">}}
```highlight

	[content]

```
{{</code>}}

{{<mytable class="small width80 fontcourier striped greyhead smallfont">}}
| Highlight | Anwendungsbeispiel |
|:--|:--|
|```c++|  |
|```c++ {linenos=false}|  |
|```c#|  |
|```tpl|   |
|```r|  |
|```r {hl_lines=[1,"4-5"],linenos=table,linenostart=3}|  |
|```go-html-template|  |
|```javascript|  |
|```go {linenos=table,hl_lines=[8,"15-17"],linenostart=199}|  |
|```yaml|  |
|```bash|  |
|```batchfile|  |
|```powershell|  |
|```coffeescript|  |
|```csharp|  |
|```java|  |
|```scss| Stylesheets  |
{{</mytable>}}


#### Beispiele für Markdown (*.md)

{{<expand title="```md">}}
```md {linenos=false}

  | Spalte 1 | Spalte 2 | Spalte 3 |
  |:----:|:--|----:|
  |Zelle 1.1| Zelle 1.2 | Zelle 1.3 |
  |Zelle 2.1| Zelle 2.2 | Zelle 2.3 |
   
```
{{</expand>}}


{{<expand title="```APL  -  sieht teilweise besser aus" >}}
```APL {linenos=false}

  | Spalte 1 | Spalte 2 | Spalte 3 |
  |:----:|:--|----:|
  |Zelle 1.1| Zelle 1.2 | Zelle 1.3 |
  |Zelle 2.1| Zelle 2.2 | Zelle 2.3 |
   
```
{{</expand>}}


{{<expand title="```APL  mit Text">}}
```APL {linenos=false}

  Text Text Text [^3]
  Text Text Text
  Text Text Text
  Text Text[^2] Text Text 
  Beispiel Literaturangabe[^4]

  [^3]: Fussnote werden automatisch sortiert
  [^2]: Fussnote werden automatisch sortiert
  [^4]: Kleiber: Verkehrswertermittlung von Grundstuecken, 9. Auflage 2020, S. 3091, Teil: VIII, RgNr. 412 
   
```

{{</expand>}}



#### Andere Backticksbeispiele

{{<expand title="```fish - eignet sich für bash-Befehle und deren Parameter">}}
```fish{linenos=false}
  gpg --import signature_key.asc
  odbc-connect --database exceltable.xls --version --help

  cmake.exe 	--build .\\build	^
		--verbose		^ 
		--clean-first		^
		--config Release 	^
		--target install

```
{{</expand>}}


{{<expand title="```c++">}}
```c#
 int     a=1, b=8;
 int funktion(int x, int y){ 
     return x+y;
 }
```
{{</expand>}}


{{<expand title="```c++ {linenos=false}  ">}}

Ist der Konfigurationsdatei `config.toml` die Zeilennummerierung eingschalten `lineNos=true`, dann kann sie durch den Aufruf `{lineos=false}` temporär abgeschaltet werden.

```c# {linenos=false}
 int     a=1, b=8;
 int funktion(int x, int y){ 
     return x+y;
 }
```

{{</expand>}}


{{<expand title="```r {hl_lines=[1,\"4-5\"],linenostart=3,linenos=table}">}}
```r {hl_lines=[1,"4-5"],linenostart=3,linenos=table}
a <- c(1:7, NA)
mean(a, na.rm = TRUE)

library("dplyr")
df %>%
  mutate(date = lubridate::ymd(date_string)) %>%
  select(- date_string)
str(df)
nrow(df)
```
{{</expand>}}


{{<expand title="```r {hl_lines=[1,\"4-5\"],linenostart=3,linenos=false}">}}
```r {hl_lines=[1,"4-5"],linenostart=3,linenos=false}
a <- c(1:7, NA)
mean(a, na.rm = TRUE)

library("dplyr")
df %>%
  mutate(date = lubridate::ymd(date_string)) %>%
  select(- date_string)
str(df)
nrow(df)
```
{{</expand>}}


{{<expand title="```go-html-template">}}
```go-html-template
{{ partial "header.html" . }}

  <h1>posts</h1>
  {{ range first 10 .Data.Pages }}
    {{ if eq .Type "post"}}
      <h2><a href="{{ .Permalink }}">{{ .Title }}</a></h2>
    {{ end }}
  {{ end }}

  <h1>pages</h1>
  {{ range .Data.Pages }}
    {{ if or (eq .Type "page") (eq .Type "about") }}
      <h2><a href="{{ .Permalink }}">{{ .Type }} - {{ .Title }} - {{ .RelPermalink }}</a></h2>
    {{ end }}
  {{ end }}

{{ partial "footer.html" . }}
```
{{</expand>}}


{{<expand title="```go">}}
```go
package main
import fmt "fmt"

func main() 
{
   fmt.Printf("Hello, World!\n");
}
```
{{</expand>}}


{{<expand title="```go {hl_lines=[2,\"5-8\"],linenostart=165,linenos=table}">}}
```go {hl_lines=[2,"5-8"],linenostart=165,linenos=table}
package main
import fmt "fmt"

func main() 
{
   fmt.Printf("Hello, World!\n");
}
```
{{</expand>}}


{{<expand title="```go {hl_lines=[2,\"5-8\"],linenostart=165,linenos=false}">}}
```go {hl_lines=[2,"5-8"],linenostart=165,linenos=false}
package main
import fmt "fmt"

func main() 
{
   fmt.Printf("Hello, World!\n");
}
```
{{</expand>}}


{{<expand title="```bash aus der Datei render-codeblocks-bash.html">}}
```bash {linenos=false,name="huhuhu"}
 #!/bin/bash
 ###### CONFIG
 ACCEPTED_HOSTS="/root/.hag_accepted.conf"
 BE_VERBOSE=false

 if [ "$UID" -ne 0 ]
 then
  echo "Superuser rights required"
  exit 2
 fi

 genApacheConf(){
  echo -e "# Host ${HOME_DIR}$1/$2 :"
 }
```
{{</expand>}}


{{<expand title="```shell">}}
```shell
 #!/bin/bash
 ###### CONFIG
 ACCEPTED_HOSTS="/root/.hag_accepted.conf"
 BE_VERBOSE=false

 if [ "$UID" -ne 0 ]
 then
  echo "Superuser rights required"
  exit 2
 fi

 genApacheConf(){
  echo -e "# Host ${HOME_DIR}$1/$2 :"
 }
```
{{</expand>}}


{{<expand title="```batchfile">}}
```batchfile
 #!/bin/bash
 ###### CONFIG
 ACCEPTED_HOSTS="/root/.hag_accepted.conf"
 BE_VERBOSE=false

 if [ "$UID" -ne 0 ]
 then
  echo "Superuser rights required"
  exit 2
 fi

 genApacheConf(){
  echo -e "# Host ${HOME_DIR}$1/$2 :"
 }
```
{{</expand>}}


{{<expand title="```VB.net">}}
```VB.Net
 Sub Vorlagenordner_Word()
  
  MsgBox _ 
  "Programm    - Application.Path"                         & vbNewLine & Application.Path            & vbNewLine & vbNewLine & _
  "Startordner - Application.StartupPath"                  & vbNewLine & Application.StartupPath     & vbNewLine & vbNewLine & _
  "Vorlagen    - ActiveDocument.AttachedTemplate.FullName" & vbNewLine & ActiveDocument.AttachedTemplate.FullName
 
 End Sub
```
{{</expand>}}


{{<expand title="```cmd {linenos=false}">}}
```cmd {linenos=false}
 @echo off

 set PATH_CODEBLOCKS=C:\dev\codeblocks\codeblocks-current\
 set PATH_USERPROFIL=M:\Projekte\Programmierung\Codeblocks-IDE\profile

 start /D %PATH_CODEBLOCKS% codeblocks.exe --user-data-dir=%PATH_USERPROFIL%
```
{{</expand>}}


{{<expand title="```javascript">}}
```javascript
 function $initHighlight(block, cls) {
   try {
     if (cls.search(/\bno\-highlight\b/) != -1)
       return process(block, true, 0x0F) +
              ` class="${cls}"`;
   } catch (e) {
     /* handle exception */
   }
   for (var i = 0 / 2; i < classes.length; i++) {
     if (checkCondition(classes[i]) === undefined)
       console.log('undefined');
   }
 }
 export  $initHighlight;
```
{{</expand>}}


#### Beispiel mit Shortcode `{{</*highlight*/>}}`

{{<code lang="html" title="Markdown mit {{<highlight>}}">}}
 {{</*highlight go-html-template "linenos=table,hl_lines=1 3-6 8,linenostart=199"*/>}}
	[content] 
 {{</*/highlight*/>}}
{{</code>}}
   
Ergebnis:    
Der Parameter `hl_lines=1 3-6 8` belegt die Zeilen 1, 3 bis 6 und 8 mit einer anderen Hintergrundfarbe.

{{<highlight go-html-template "linenos=table,hl_lines=1 3-6 8,linenostart=199">}}
 <section id="main">
   <div>
    <h1 id="title">{{ .Title }}</h1>
     {{ range .Data.Pages }}
         {{ .Render "summary"}}
     {{ end }}
   </div>
 </section>
{{</highlight>}}



#### Beispiel zum anzeigen einer Verzeichnisstruktur

{{<expand title="```Shell {linenos=false}">}}
````
```Shell {linenos=false}

 includes/
  ├── include-page.md
  └── index.md

```
````
{{</expand>}}


__Ergebnis:__

```Shell {linenos=false}

 includes/
  ├── include-page.md
  │   └── wx
  │       └── setup.h
  └── index.md
   
```
Weiter Beispiele zum anzeigen von Verzeichnisstrukturen.

{{<expand title="```Caddyfile {linenos=false}">}}
```Caddyfile {linenos=false}
 .\lib\gcc920TDM_custom
      ├── libwx_baseu-3.1.dll.a
      ├── libwx_mswu_core-3.1.dll.a
      ├── ...
      ├── wxbase314u_gcc_custom.dll
      ├── wxmsw314u_core_gcc_custom.dll
      ├── ...
      ├── // und die Dateien fuer den Debugger ...
      ├── ...
      ├── libwx_baseud-3.1.dll.a
      ├── libwx_mswud_core-3.1.dll.a
      ├── ...
      ├── wxbase314ud_gcc_custom.dll
      ├── wxmsw314ud_core_gcc_custom.dll
      └── ...

 includes/
  ├── include-page.md
  │   └── wx
  │       └── setup.h
  └── index.md

```
{{</expand>}}

{{<expand title="```BlitzBasic {linenos=false}">}}
```BlitzBasic {linenos=false}
 .\lib\gcc920TDM_custom
      ├── libwx_baseu-3.1.dll.a
      ├── libwx_mswu_core-3.1.dll.a
      ├── ...
      ├── wxbase314u_gcc_custom.dll
      ├── wxmsw314u_core_gcc_custom.dll
      ├── ...
      ├── // und die Dateien fuer den Debugger ...
      ├── ...
      ├── libwx_baseud-3.1.dll.a
      ├── libwx_mswud_core-3.1.dll.a
      ├── ...
      ├── wxbase314ud_gcc_custom.dll
      ├── wxmsw314ud_core_gcc_custom.dll
      └── ...

 includes/
  ├── include-page.md
  │   └── wx
  │       └── setup.h
  └── index.md

```
{{</expand>}}

{{<expand title="```AppleScript {linenos=false}">}}
```AppleScript {linenos=false}
 .\lib\gcc920TDM_custom
      ├── libwx_baseu-3.1.dll.a
      ├── libwx_mswu_core-3.1.dll.a
      ├── ...
      ├── wxbase314u_gcc_custom.dll
      ├── wxmsw314u_core_gcc_custom.dll
      ├── ...
      ├── // und die Dateien fuer den Debugger ...
      ├── ...
      ├── libwx_baseud-3.1.dll.a
      ├── libwx_mswud_core-3.1.dll.a
      ├── ...
      ├── wxbase314ud_gcc_custom.dll
      ├── wxmsw314ud_core_gcc_custom.dll
      └── ...

 includes/
  ├── include-page.md
  │   └── wx
  │       └── setup.h
  └── index.md

```
{{</expand>}}

{{<expand title="```Ceylon {linenos=false}">}}
```Ceylon {linenos=false}
 .\lib\gcc920TDM_custom
      ├── libwx_baseu-3.1.dll.a
      ├── libwx_mswu_core-3.1.dll.a
      ├── ...
      ├── wxbase314u_gcc_custom.dll
      ├── wxmsw314u_core_gcc_custom.dll
      ├── ...
      ├── // und die Dateien fuer den Debugger ...
      ├── ...
      ├── libwx_baseud-3.1.dll.a
      ├── libwx_mswud_core-3.1.dll.a
      ├── ...
      ├── wxbase314ud_gcc_custom.dll
      ├── wxmsw314ud_core_gcc_custom.dll
      └── ...

 includes/
  ├── include-page.md
  │   └── wx
  │       └── setup.h
  └── index.md

```
{{</expand>}}

{{<expand title="```PSL {linenos=false}">}}
```PSL {linenos=false}
 .\lib\gcc920TDM_custom
      ├── libwx_baseu-3.1.dll.a
      ├── libwx_mswu_core-3.1.dll.a
      ├── ...
      ├── wxbase314u_gcc_custom.dll
      ├── wxmsw314u_core_gcc_custom.dll
      ├── ...
      ├── // und die Dateien fuer den Debugger ...
      ├── ...
      ├── libwx_baseud-3.1.dll.a
      ├── libwx_mswud_core-3.1.dll.a
      ├── ...
      ├── wxbase314ud_gcc_custom.dll
      ├── wxmsw314ud_core_gcc_custom.dll
      └── ...

 includes/
  ├── include-page.md
  │   └── wx
  │       └── setup.h
  └── index.md

```
{{</expand>}}

{{<expand title="```Scala {linenos=false}">}}
```Scala {linenos=false}
 .\lib\gcc920TDM_custom
      ├── libwx_baseu-3.1.dll.a
      ├── libwx_mswu_core-3.1.dll.a
      ├── ...
      ├── wxbase314u_gcc_custom.dll
      ├── wxmsw314u_core_gcc_custom.dll
      ├── ...
      ├── // und die Dateien fuer den Debugger ...
      ├── ...
      ├── libwx_baseud-3.1.dll.a
      ├── libwx_mswud_core-3.1.dll.a
      ├── ...
      ├── wxbase314ud_gcc_custom.dll
      ├── wxmsw314ud_core_gcc_custom.dll
      └── ...

 includes/
  ├── include-page.md
  │   └── wx
  │       └── setup.h
  └── index.md

```
{{</expand>}}

{{<expand title="```V {linenos=false}">}}
```V {linenos=false}
 .\lib\gcc920TDM_custom
      ├── libwx_baseu-3.1.dll.a
      ├── libwx_mswu_core-3.1.dll.a
      ├── ...
      ├── wxbase314u_gcc_custom.dll
      ├── wxmsw314u_core_gcc_custom.dll
      ├── ...
      ├── // und die Dateien fuer den Debugger ...
      ├── ...
      ├── libwx_baseud-3.1.dll.a
      ├── libwx_mswud_core-3.1.dll.a
      ├── ...
      ├── wxbase314ud_gcc_custom.dll
      ├── wxmsw314ud_core_gcc_custom.dll
      └── ...

 includes/
  ├── include-page.md
  │   └── wx
  │       └── setup.h
  └── index.md

```
{{</expand>}}



#### Beispiel Verkn&uuml;pfungen

{{<expand title="```antlr {linenos=false}">}}
```antlr {linenos=false}

 \\GIS\akdbprg\w3GIS.kom\w3GIS\client\w3GEOportal.exe http://GIS/w3GEOportal/default.asp?AutoStart=1&OpenAppWindow=0
   
```
{{</expand>}}

{{<expand title="```arduino {linenos=false}">}}
```arduino {linenos=false}

 \\GIS\akdbprg\w3GIS.kom\w3GIS\client\w3GEOportal.exe http://GIS/w3GEOportal/default.asp?AutoStart=1&OpenAppWindow=0
   
```
{{</expand>}}

{{<expand title="```c {linenos=false}">}}
```c {linenos=false}

 \\GIS\akdbprg\w3GIS.kom\w3GIS\client\w3GEOportal.exe http://GIS/w3GEOportal/default.asp?AutoStart=1&OpenAppWindow=0
   
```
{{</expand>}}

{{<expand title="```cfengine3 {linenos=false}">}}
```cfengine3 {linenos=false}

 \\GIS\akdbprg\w3GIS.kom\w3GIS\client\w3GEOportal.exe http://GIS/w3GEOportal/default.asp?AutoStart=1&OpenAppWindow=0
   
```
{{</expand>}}

{{<expand title="```glsl {linenos=false}">}}
```glsl {linenos=false}

 \\GIS\akdbprg\w3GIS.kom\w3GIS\client\w3GEOportal.exe http://GIS/w3GEOportal/default.asp?AutoStart=1&OpenAppWindow=0
   
```
{{</expand>}}

{{<expand title="```metal {linenos=false}">}}
```metal {linenos=false}

 \\GIS\akdbprg\w3GIS.kom\w3GIS\client\w3GEOportal.exe http://GIS/w3GEOportal/default.asp?AutoStart=1&OpenAppWindow=0
   
```
{{</expand>}}

{{<expand title="```prolog {linenos=false}">}}
```prolog {linenos=false}

 \\GIS\akdbprg\w3GIS.kom\w3GIS\client\w3GEOportal.exe http://GIS/w3GEOportal/default.asp?AutoStart=1&OpenAppWindow=0
   
```
{{</expand>}}

{{<expand title="```qml {linenos=false}">}}
```qml {linenos=false}

 \\GIS\akdbprg\w3GIS.kom\w3GIS\client\w3GEOportal.exe http://GIS/w3GEOportal/default.asp?AutoStart=1&OpenAppWindow=0
   
```
{{</expand>}}

{{<expand title="```ReasonMl {linenos=false}">}}
```reasonml {linenos=false}

 \\GIS\akdbprg\w3GIS.kom\w3GIS\client\w3GEOportal.exe http://GIS/w3GEOportal/default.asp?AutoStart=1&OpenAppWindow=0
   
```
{{</expand>}}

{{<expand title="```Ruby {linenos=false}">}}
```ruby {linenos=false}

 \\GIS\akdbprg\w3GIS.kom\w3GIS\client\w3GEOportal.exe http://GIS/w3GEOportal/default.asp?AutoStart=1&OpenAppWindow=0
   
```
{{</expand>}}

{{<expand title="```Rust {linenos=false}">}}
```rust {linenos=false}

 \\GIS\akdbprg\w3GIS.kom\w3GIS\client\w3GEOportal.exe http://GIS/w3GEOportal/default.asp?AutoStart=1&OpenAppWindow=0
   
```
{{</expand>}}

{{<expand title="```Scala {linenos=false}">}}
```scala {linenos=false}

 \\GIS\akdbprg\w3GIS.kom\w3GIS\client\w3GEOportal.exe http://GIS/w3GEOportal/default.asp?AutoStart=1&OpenAppWindow=0
   
```
{{</expand>}}

{{<expand title="```Smalltalk {linenos=false}">}}
```smalltalk {linenos=false}

 \\GIS\akdbprg\w3GIS.kom\w3GIS\client\w3GEOportal.exe http://GIS/w3GEOportal/default.asp?AutoStart=1&OpenAppWindow=0
   
```
{{</expand>}}






















## Funktionszeichen deaktivieren (maskieren)

### In Markdown (`*.md`)

Die in Markdowndateien für eine besonderen Formatierung belegten Funktionszeichen (z.B. `##` für Überschriften, oder `>` für Blockquotes) können mit einem __Backslash (\\)__ [maskiert][] und somit deaktiviert werden um so das entsprechende Literalzeichen zu generieren.

{{<mytable caption="Funktionszeichen in Markdown (*.md) deaktivieren." class=" noborder captleft fontcourier smallfont small greyhead striped">}}
|Funktionszeichen| deaktiviert mit| Beschreibung|
|:--:|:--:|:--|
| \# | \\\# |hash mark |
| \> | \\\> |arrow, Vergleichszeichen |
| \< | \\\< |arrow, Vergleichszeichen |
| \\ | \\\\ |backslash |
| \` | \\\` | backtick |
| \* | \\\* | asterisk |
| \_ | \\\_ |  underscore |
| \{ \} | \\\{ \\\} |  curly braces |
| \[ \] | \\\[ \\\]| square brackets |
| \( \) | \\\( \\\) | parentheses |
| \+ | \\\+ |  plus sign |
| \- | \\\- |  minus sign (hyphen) |
| \& | \\\& |  and sign |
{{</mytable>}}


Um in Markdowndateien Shortcode-Anweisung zu deaktivieren und stattdessen anzuzeigen oder zu kommentieren, verwende die Zeichen:
: \/&zwj;\*&nbsp;...&nbsp;\*&zwj;\/ 

oder setze die geschweifte Klammer in Hochkommas
: "{{"&nbsp;...&nbsp;"}}" 

{{<mytable class="width50 tableleft noborder striped fontcourier smallfont small captleft" caption="Beispiele zum Deaktivieren">}}
|Shortcode| deaktiviert|
|:--:|:--:|
| \{\{\<param date\>\}\} | \{\{\<\/\*param date\*\/\>\}\} |
| \{\{\<code lang=...\>\}\} | \{\{\<\/\*code lang=...\*\/\>\}\} |
| \{\{\<mytable\>\}\} | \{\{\<\/\*mytable*/>\}\} |
| \{\{\<\/mytable\>\}\} | \{\{\<\/\*/mytable\*\/\>\}\} |
| \{\{\<form\>\}\} | \"{{\"\<form\>"\}\}" |
{{</mytable>}}

### In Shortcode oder Templates (`*.html`)

Gohugo verwendet die geschweifte Klammer in Shortcodes oder in Html-Dateien für Funktionsaufrufe und Variablen. 
Um die geschweifte Klammer selbst zu maskieren und anzuzeigen nimm folgende Syntax:

{{<code lang="go-html-template" title="Geschweifte Klammer maskieren in *.html" options="linenos=false">}}
 {{"{{"}} .Page.Date {{"}}"}}
{{</code>}}


## Adressen mit hexadezimale Entit&auml;tscodierung verstecken

Um dieses Future zu verwenden muss in der Datei `config.toml` der Schalter `unsafe` auf `true` gesetzt werden.

{{<code lang="go" title="config.toml">}}
 [markup]
   sefaultMarkdownHandler = "goldmark" 
   [markup.goldmark]
      [markup.goldmark.renderer]
         unsafe = true
{{</code>}}

Zum Beispiel das Verstecken eines Link's mit hexadezimaler Entit&auml;tscodierung.

```go-html-template {linenos=false}

 <a href="&#x6D;&#x61;i&#x6C;&#x74;&#x6F;:&#x61;&#x64;&#x64;&#x72;&#x65;&#115;&#115;&#64;&#101;&#120;&#x61;&#109;&#x70;&#x6C;e&#x2E;&#99;&#111;&#109;">&#x61;&#x64;&#x64;&#x72;&#x65;&#115;&#115;&#64;&#101;&#120;&#x61;&#109;&#x70;&#x6C;e&#x2E;&#99;&#111;&#109;</a>
  
```

Ergebnis:

><a href="&#x6D;&#x61;i&#x6C;&#x74;&#x6F;:&#x61;&#x64;&#x64;&#x72;&#x65;&#115;&#115;&#64;&#101;&#120;&#x61;&#109;&#x70;&#x6C;e&#x2E;&#99;&#111;&#109;">&#x61;&#x64;&#x64;&#x72;&#x65;&#115;&#115;&#64;&#101;&#120;&#x61;&#109;&#x70;&#x6C;e&#x2E;&#99;&#111;&#109;</a>

## Emojies verwenden

Emojies sind standardisierte Symbole zur Darstellung von Emotionen (bzw. Gef&uuml;hlen), Objekte, Aktivit&auml;ten, Tieren und Natur usw.
In Markdown werden Emojies durch Wörter symbolisiert, die mit einem Doppelpunkt am Wortanfang und am Wortende eingegrenzt sind. 

Eine umfangreiche Seite bietet [Emoji cheat sheet][].

{{<code lang="toml" title="config.toml">}}
 enableEmoji = true
{{</code>}}

{{<mytable caption="Emojie Code in Markdown (*.md)" class="width80 noborder small nohead captleft">}}
| Emojie | Emojie | Code |
|:--|:--|:--|
| :wink: \:wink\: | :cry: \:cry\: | :rage: \:rage\: |
| :zzz: \:zzz\: | :one:  \:one\:  | :two: \:two\: |
| :cl:  \:cl\:   | :top: \:top\: | :yum:  \:yum\: |
|:frog: \:frog\:| :cat:  \:cat\:  |:dog:  \:dog\: |
|:a: \:a\:|:phone: \:phone\:| :iphone: \:iphone\:|
|:m: \:m\:|:x: \:x\:|:o: \:o\:|
|:+1: \:+1\:|:-1: \:-1\:|:mag: \:mag\:|
|:id: \:id\:|:de: \:de\:|:ru: \:ru\:|
{{</mytable>}}

{{<mytable class="width80 noborder small nohead">}}
|   |
|:--|
|:clock1030: \:clock1030\:|
|:arrow_forward: \:arrow_forward\:|
|:white_check_mark: \:white_check_mark\:|
|:copyright: \:copyright\:|
|:registered: \:registered\:|
|:1234: \:1234\:|
|:information_source: \:information_source\: |
|:information: \:information\: |
|:sparkles: \:sparkles\: |
{{</mytable>}}


[Syntax Highlighting]: 	https://gohugo.io/content-management/syntax-highlighting/#list-of-chroma-highlighting-languages
[Chroma Style]: 		https://xyproto.github.io/splash/docs/all.html
[Pygments]: 			https://pygments.org/demo
[Caretzeichen]:			https://de.wikipedia.org/wiki/Zirkumflex
[Tilde]: 				https://de.wikipedia.org/wiki/Tilde
[Gravis]:				https://de.wikipedia.org/wiki/Gravis&#95;(Typografie)
[Emoji cheat sheet]:	https://www.webfx.com/tools/emoji-cheat-sheet/
[code.html]:    		{{< relref "shortcodes#codehtml" >}}
[markdownListen]:  		{{< relref "markdown-mit-hugo#listen" >}}
[markdownText]:  		{{< relref "markdown-mit-hugo#textgestaltung-mit-markdown" >}}
[maskiert]: 			https://de.wikipedia.org/wiki/Maskierungszeichen
[Gohugo_Configure]:		https://gohugo.io/getting-started/configuration-markup/
[CommonMark]:			https://spec.commonmark.org
[Goldmark]:				https://github.com/yuin/goldmark/#goldmark
[Bilder_in_markdown]:  	{{< relref "bilder" >}}


