+++
tags = ["dev", "gohugo", "math", "LaTeX"]
zusammenfassung = "Rendern von Formeln mit mathjax."
title = "Mathematische Formeln in gohugo"
submenu = "false"
date = "2020-09-09T16:47:25+02:00"
type = "article"
[mathjax]
    align = "right"
    scale = "1.1"
    cnumb = "all"
+++

## Vorwort
Für die Umwandlung von vereinfachten Markdowntext in eine mathematische HTML-Formel wird eine externe Online-Bibliothek (z.B. [mathjax][]) benötigt. Die Verwendung ist frei unter der [Apache Lizenz][] Version 2.0 verfügbar. 

## Formeln mit LaTeX 

Seit der Hugoversion 0.122.0 verfügt der statische Webgenerator über die in LaTeX verwendete Standardsyntax für mathematische Formeln in Markdown. 
Im Prinzip das Gleiche wie hier beschrieben, nur mit einem anderen Weg.

## Die mathjax Engine

### Bibliothek einbinden

Als erstes muss die mathjax-Bibliothek als Javascript in der Datei `./layouts/partials/header.html` eingebunden werden. Damit steht die Bibliothek jeder gerenderten Seite des Projekts zur Verfügung.

```go-html-template {linenos=false}
   
 <!-- mathjax Version 2.7.5 mit Subresourceintegritätstest -->
 <script async
         src="https://cdn.jsdelivr.net/npm/mathjax@2.7.5/MathJax.js?config=TeX-MML-AM_CHTML"  
         integrity="sha256-nvJJv9wWKEm88qvoQl9ekL2J+k/RWIsaSScxxlsrv8k=" 
         crossorigin="anonymous">
 </script>


 <!-- mathjax Version 2.7.9 ohne Integritätstest -->
 <script async
         src="https://cdn.jsdelivr.net/npm/mathjax@2.7.9/MathJax.js?config=TeX-MML-AM_CHTML">
 </script>


 <!-- mathjax Version 3.0.0 mit Subresourceintegritätstest -->
 <script async
        src="https://cdn.jsdelivr.net/npm/mathjax@3.0.0/es5/tex-chtml.js"
        integrity="sha256-3Fdoa5wQb+JYfEmTpQHx9sc/GuwpfC/0R9EpBki+mf8=" 
        crossorigin="anonymous">
 </script>


 <!-- mathjax Version 3.1.2 ohne Integritätstest -->
 <script async 
         src="https://cdn.jsdelivr.net/npm/mathjax@3.1.2/es5/tex-chtml-full.js">
 </script>
   
```

Um nur einzelnen Seiten mit der Bibliothek zu erfreuen, kann im Kopf der Markdowndatei ein Schalter gesetzt werden.
Der Schalter kann auch mit weiteren Parametern belegt werden.





{{<tabs>}}
{{<tab "mit weiteren Parametern">}}

```go-html-template {linenos=false}
 +++
 ...
 ...
 [mathjax]
     scale = 0.5
     align = "left"
     autonumber = "all"
 +++
   
```

{{</tab>}}
{{<tab "ohne weitere Parameter">}}

```go-html-template {linenos=false}
 +++
 ...
 ...
 mathjax = "true"
 +++
   
```
{{</tab>}}
{{</tabs>}}

Der in der Markdowndatei bereit gestellte Seitenparameter kann nunmehr abgefragt und die Bibliothek hinzugefügt werden.


```go-html-template {linenos=false}

 {{ if .Page.Params.mathjax  }} 
    <script async 
            src="https://cdn.jsdelivr.net/npm/mathjax@2.7.5/MathJax.js?config=TeX-MML-AM_CHTML"  
            integrity="sha256-nvJJv9wWKEm88qvoQl9ekL2J+k/RWIsaSScxxlsrv8k=" 
            crossorigin="anonymous">
    </script>
 {{ end }}
   
```

### Dürfen es ein paar Optionen sein?

Optional wird die Darstellung mit ein paar Parametern gesteuert. Dabei gibt es unterschiede zwischen den Optionen der mathjax-Versionen [2.7][] und [3.1][].


{{<tabs>}}
{{<tab "Syntax 3.1">}}

```go-html-template {linenos=false}

 <!-- mit Parameterabfrage und -übergabe aus der Markdowndatei -->
 {{- if .Page.Params.mathjax  -}}
    <script async
            src="https://cdn.jsdelivr.net/npm/mathjax@3.0.0/es5/tex-chtml.js"
            integrity="sha256-3Fdoa5wQb+JYfEmTpQHx9sc/GuwpfC/0R9EpBki+mf8=" 
            crossorigin="anonymous">
    </script>
    <script>
            MathJax = {
                      chtml: {
                              scale:        {{ .Page.Param "mathjax.scale" }},
                              displayAlign: {{ .Page.Param "mathjax.align" }},
                      },
                      tex: {
                              tags:         {{ .Page.Param "mathjax.cnumb" }},	 
                      },
            };
    </script>
 {{- end -}}
   
```

{{</tab>}}
{{<tab "Syntax 2.7">}}

```go-html-template {linenos=false}
   
 <!-- Version 2.7 ist anders -->
 {{- if .Page.Params.mathjax  -}}
    <script async
            src="https://cdn.jsdelivr.net/npm/mathjax@2.7.5/MathJax.js?config=TeX-MML-AM_CHTML"  
            integrity="sha256-nvJJv9wWKEm88qvoQl9ekL2J+k/RWIsaSScxxlsrv8k=" 
            crossorigin="anonymous">
            MathJax.Hub.Config({
                   CommonHTML: {	
                      scale: 90,
                      linebreaks: { automatic: true },
                      mtextFontInherit: true,
                   },
                   TeX: { 
                      equationNumbers: { autoNumber: "AMS" } //fuer fortlaufende Nummerierung der Formel bei LateX
                   },
            };
    </script>
 {{- end -}}
   
```
{{</tab>}}
{{</tabs>}}

### Anwendungsbeispiele

{{<columns>}}

```matlab {linenos=false}

 $$ evidence\_{i}=\sum\_{j}W\_{ij}x\_{j}+b\_{i} $$
   
```

<--->
   
{{<panel theme="default" header="So sieht's dann aus:">}}
$$ evidence\_{i}=\sum\_{j}W\_{ij}x\_{j}+b\_{i} $$
{{</panel>}}


<--->

```html {linenos=false}

 \\[3 < 4\\]
 \\[alpha =1 \\]
 $$\alpha = 1 $$
   
```

<--->

{{<panel theme="default" header="So sieht's dann aus:">}}
\\[3 < 4\\]
\\[alpha =1 \\]
$$\alpha = 1 $$
{{</panel>}}

<--->


```tex {linenos=false}

 \begin{align}
	p(v_i=1|\mathbf{h}) & = \\
	\sigma\left(\sum_j w_{ij}h_j + b_i\right)
 \end{align}
   
```

<--->

{{<panel theme="default" header="So sieht's dann aus:">}}
\begin{align}
    p(v_i=1|\mathbf{h}) & = \\
	\sigma\left(\sum_j w_{ij}h_j + b_i\right)
\end{align}
{{</panel>}}

<--->

```matlab {linenos=false}

 $$ x = \frac{-b \pm \sqrt{b^2 - 4ac}}{2a} $$
   
```

<--->

{{<panel theme="default" header="So sieht's dann aus:">}}
$$ x = \frac{-b \pm \sqrt{b^2 - 4ac}}{2a} $$
{{</panel>}}


<--->

```matlab {linenos=false}

 $$C_p[\ce{H2O(l)}] = \pu{75.3 J // mol K}$$
   
```
<--->

{{<panel theme="default" header="So sieht's dann aus:">}}
$$C_p[\ce{H2O(l)}] = \pu{75.3 J // mol K}$$
{{</panel>}}

{{</columns>}}

------------------------------------------------------------

```mathematica {linenos=false}

 $$ E(\mathbf{v}, \mathbf{h}) = -\sum_{i,j}w_{ij}v_i h_j - \sum_i b_i v_i $$
   
```


{{<panel theme="default" header="So sieht's dann aus:">}}
$$ E(\mathbf{v}, \mathbf{h}) = -\sum_{i,j}w_{ij}v_i h_j - \sum_i b_i v_i $$
{{</panel>}}


------------------------------------------------------------

```tex {linenos=false}

 \begin{equation}
 \bcancel{
  E_{\color{green}Grünland} \color{black} = 
  \frac{ Fläche\ (m^2) \cdot \color{green}Grünlandzahl}{\color{black}100 }
 }
 \end{equation}
   
```

{{<panel theme="default" header="So sieht's dann aus:">}}
\begin{equation}
\bcancel{
 E_{\color{green}Grünland} \color{black} = 
 \frac{ Fläche\ (m^2) \cdot \color{green}Grünlandzahl}{\color{black}100 }
}
\end{equation}
{{</panel>}}


------------------------------------------------------------

{{<panel>}}
Weitere Beispiele: siehe im Html-Seitenquelltext
\begin{aligned}
\begin{pmatrix}
q_{0} \\\\\\ 
q_{1} \\\\\\ 
q_{2} 
\end{pmatrix} 
\=
\begin{pmatrix}
a_{00} &amp; a_{01} &amp; a_{02} \\\\\\ 
a_{10} &amp; a_{11} &amp; a_{12} \\\\\\ 
a_{20} &amp; a_{21} &amp; a_{22}
\end{pmatrix}
\end{aligned}
{{</panel>}}

{{<panel>}}
\begin{align}
\dot{x} &amp; = \sigma(y-x) \nonumber \\\\\\
\dot{y} &amp; = \rho x - y - xz \\\\\\
\dot{z} &amp; = -\beta z + xy \nonumber 
\end{align}
{{</panel>}}

{{<panel>}}
\begin{eqnarray} 
y &=& x^4 + 4      \nonumber \\\\\\
  &=& (x^2+2)^2 -4x^2  \\\\\\
  &\le&(x^2+2)^2    \nonumber
\end{eqnarray} 
{{</panel>}}

{{<panel>}}
\begin{equation}
\begin{aligned}
  & \frac{dy}{dt} = f(t, y) \\
  & y(t_0) = y_0
\end{aligned}
\end{equation}
{{</panel>}}

{{<panel>}}
\begin{aligned}
\int I(t) \, dt
\end{aligned}
{{</panel>}}

{{<panel>}}
\begin{aligned}
\mathrm{Und~Text~mit~K\ddot{a}se~geht~auch.}
\end{aligned}
{{</panel>}}

{{<panel>}}
\begin{aligned}
\mathsf{Und~auch~serifenloser~Text.}
\end{aligned}
{{</panel>}}

{{<panel>}}
\begin{aligned}
\mathsf{\pi \approx 3{,}141592\ldots}
\end{aligned}
{{</panel>}}

{{<panel>}}
\begin{aligned}
\circ \frac{\qquad}{\qquad} \bullet \nonumber
\end{aligned}
{{</panel>}}

{{<panel>}}
\begin{array}{c|c|c|}
  a & b & S\\\\\\hline
  1 & 0 & 1\\\\\\
  1 & 1 & 0\nonumber
\end{array}
{{</panel>}}

{{<panel>}}
\begin{array}{c|c|c|}
  a & b & S\\\\\\hline
  1 & 1 & 0
\end{array}
{{</panel>}}

{{<panel>}}
\begin{align}
\mathsf{Beispiele~für~Trennlinien.}\nonumber\\\\\\
\mathrm{--------Type~1-------------------\nonumber}
\end{align}
$$--------Type~2-----------------------\nonumber$$
{{</panel>}}

Weitere Beispiele und interaktiven [Demos][].   
Einen kleinen Überblick gibt's [hier][] und noch mehr [da][].


[Apache Lizenz]: 	https://de.wikipedia.org/wiki/Apache-Lizenz
[mathjax]: 			https://cdn.jsdelivr.net/npm/mathjax@2.7.5/
[2.7]:				https://docs.mathjax.org/en/v2.7-latest/options/output-processors/CommonHTML.html
[3.1]:				http://docs.mathjax.org/en/v3.1-latest/options/output/index.html
[Demos]:			https://mathjax.github.io/MathJax-demos-web/
[hier]:				https://de.wikipedia.org/wiki/Hilfe:TeX#%C3%9Cberblick_%C3%BCber_LaTeX-Befehle
[da]:				https://www.physikerboard.de/topic,128,-latex-und-der-formelsatz-im-board.html
