+++
tags = ["edv", "gohugo", "markdown", "render-hooks"]
zusammenfassung = "Markdown Funktionselemente umgestalten."
title = "Render Hooks"
date = "2022-08-31T16:24:43+02:00"
type = "article"
+++

## Warum Render Hooks?

Mit [Render-Hooks][Renderhooks] können Markdown-Formatierungselemente anders gestaltet werden. 
Dazu bedarf es nur einer Datei im Verzeichnis `_markup`.

```shell {hl_lines=[6],linenostart=10,linenos=false}

  └── themes
      └── dein-theme
         └── layouts
            └── _default
               └── _markup
                  ├── render-link.html
                  ├── render-heading.html
                  ├── render-image.html
                  ├── render-codeblocks.html
                  ├── render-codeblocks-bash.html
                  └── render-codeblocks-mermaid.html
   
```

## Überschrift ändern

Um das vordefinierte Formatierungselement für Überschriften in Markdown zu ändern (also `#`), erzeuge die Datei `render-heading.html` im Verzeichnis `layouts\_default\_markup` mit folgendem Inhalt:


{{<code lang="go-html-template" title="layouts\_default\_markup\render-heading.html" >}}
 <h{{ .Level }} id="{{ .Anchor | safeURL }}">{{ .Text | safeHTML }}
	{{- if and (ge .Level 2) (le .Level 6) }}{{" " -}}
		<a href="#top">
			<abbr style="text-decoration: none" title="Zum Seitenanfang">&boxbox;</abbr>
		</a>
	{{- end -}}
 </h{{ .Level }}>
{{</code>}}

Der Code setzt am Ende einer Überschrift das Symbol &boxbox; mit einem Link zum Seitenanfang (`href="#top"`). Außerdem wird ein kleiner Hilfetext angezeigt wenn der Mauszeiger auf das Symbol zeigt (`<abbr ...`).

## Links ändern \<a\> ...\</a\>

Um Links zu externen Seiten in einem neuen Browsertabulator zu öffnen, ist folgender Render-Hook nützlich.

{{<code lang="go-html-template" title="layouts\_default\_markup\render-link.html" >}}
 <a href="{{ .Destination | safeURL }}"{{ with .Title}} title="{{ . }}"{{ end }}{{ if strings.HasPrefix .Destination "http" }} target="_blank" rel="noopener"{{ end }}>
	{{- .Text | safeHTML -}}
 </a>
{{</code>}}

## Bilder ändern

Mittels Render-Hooks kann die Darstellung von Bildern beeinflußt werden. Es ist auch möglich, den Standardaufruf mit Parametern zu ergänzen, so wie im Codefeld angezeigt.

{{<code lang="apl" title="Bilder in Markdown aufrufen">}}
 # Standardaufruf in Markdown
 ![](/path/to/image.jpg "Title")

 # Eweiterter Aufruf mit Parametern
 ![](/path/to/image.jpg "Title {ClassOption01 ClassOption02}")
 ![](/path/to/image.jpg "Title {ClassOption01 ClassOption02}[[Linkname01=href...][Linkname02=href...][...]]")
 ![](/path/to/image.jpg "Title {ClassOption01 ClassOption02}[[Linkname01=href...][Linkname02=href...][...]] #width=80%")
{{</code>}}

### Beispiel 1

Die Datei `render-image.html` wurde erweitert um weitere Parameter zur Formatierung von Markdown in Html zu übergeben.
Die Parameter sind innerhalb der Anführungszeichen im Titel festgelegt und folgende: 

{{<mytable class="width100 small smallfont fontcourier greyhead">}}
| Parameter | Beschreibung | Werte/Beispiel | 
|:---|:---|:---|
|{ClassOption01 ClassOption02}| Stylesoptionen | frame, left, right |
|[[Linkname01=href...][Linkname02=href...][...]]| Links übergeben | [[CC=https://www...]]| 
|#width | Bildbreite in % | #width=60% |
{{</mytable>}}


Die Datei `render-image.html` und die entsprechende <abbr title="Cascading Style Sheets">CSS</abbr>-Datei wurden geändert. 


{{<code lang="go-html-template" file="/static/include_files/render-image.html" title="layouts\_default\_markup\render-image.html" >}}

{{</code>}}

### Beispiel 2

{{<expand title="layouts\_default\_markup\render-image.html" >}}
```go-html-template {linenos=false}
 {{- $storage := newScratch -}}
 {{- $storage.Set "ImgClass" "" -}}
 {{- $storage.Set "ImgTitle" "" -}}

 {{- /*  Parse class attributes  */ -}}
 {{- $SuchString := .Title -}}
 {{- $step1 := findRE `{[[:word:][:space:]]*}` $SuchString  -}}
 {{- if ne (len $step1) 0 -}}
	{{- $step2 := index $step1 0 -}}
	{{- $step3 := trim $step2 "{}" -}}
	<!-- save Image class -->
	{{- $storage.Add "ImgClass" $step3 -}}
	<!-- save Image title -->
	{{- $storage.Add "ImgTitle" (index (split $SuchString "{") 0) -}}
 {{- else -}}
	{{- $storage.Add "ImgTitle" .Title -}}
 {{- end -}}

 <a href="{{ .Destination | safeURL }}" >
	<img 	src="{{ .Destination | safeURL }}" 
			alt="{{ .Text }}" 
			{{ with $storage.Get "ImgTitle"}} title="{{ $storage.Get "ImgTitle" }}"{{ end }} 
			{{ with $storage.Get "ImgClass"}} class="{{ $storage.Get "ImgClass" }}"{{ end }}/>
 </a>
```
{{</expand>}}


{{<expand title="work-directory\themes\<themename>\assets\sass\_image.scss">}}
```scss {linenos=false}
 img {
	border: 0;
	max-width: 80%;
	height: auto;
	margin: 1em auto;
	display: block;
	
	&.frame {
		border: 1px solid $color_Code_border;
		border-radius: 0.3em;
		padding: 0px;
		box-shadow: 2px 2px 5px $color_Shadow;
	}
	&.left  { float: none; display: block;} 
	&.right { float: none; display: block;} 
 }

 /* Ansich bei Flexaufteilung 2 - Sidebarleft, Main */
 @media only screen and (min-width: $MinWidthFlex2) {
	img {		
		&.left  { float: inline-start;  margin: 1em 1em 1em 0em;} 
		&.right { float: inline-end; 	margin: 1em 0.5em 1em 1em;} 
	}
 }

 /* Ansich bei Flexaufteilung 1 - Sidebarleft, Main, SidebarRight */
 @media only screen and (min-width: $MinWidthFlex1) {
	img {		
		&.left  { float: inline-start;  margin: 1em 1em 1em 0em;} 
		&.right { float: inline-end; 	margin: 1em 0.5em 1em 1em;} 
	}
 }

 /* Desktop-Ansicht */
 @media only screen and (min-width: $MinWidth) {
	img {		
		&.left  { float: inline-start;  margin: 1em 1em 1em 0em;} 
		&.right { float: inline-end; 	margin: 1em 0.5em 1em 1em;} 
	}
 }
```
{{</expand>}}





[artikel_bilder]:	 {{< relref "bilder" >}}



[Renderhooks]:	https://gohugo.io/templates/render-hooks/
