+++
tags = ["dev", "gohugo", "markdown", "resources", "image"]
zusammenfassung = "Umgang mit globalen und lokalen Ressourcen in Gohugo."
title = "Ressources und Seitenorganisation (Bundletype)"
date = "2022-05-24T11:33:03+02:00"
type = "article"
+++

Ressourcen sind Bilder, Dokumente, Scriptdateien, usw. Ressourcen werden zum einen lokal unterhalb des Inhaltsverzeichnisses `content\...` abgelegt. 
Zum anderen werden Ressourcen auch global im Verzeichnis `themes\...` zur Verfügung gestellt.
   

## Bundletype

Der Umgang mit Ressource ist abhängig von der verwendeten Seitenorganisation dem sog. [BundleType.][Bundletype]
In einem Gohugo-Projekt werden Webseiten durch Seitenpakete [(Bundle)][Bundle] organisiert. Ein Seitenpaket ist ein Verzeichnis, das Inhalte und Ressourcen einkapselt. 
Es gibt zwei Arten der Seitenorganisation, Leaf (Blatt) und Branch (Zweig). 
Die Seitenvariable `{{ .Page.BundleType }}` liefert die Art der Seitenorganisation zurück oder nichts, wenn die Seite kein Bundle ist.
Hauptmerkmal eines [Bundle][Bundle] ist die index-Datei im Verzeichnis. 

## Globale Theme-Ressourcen 

Themenressourcen werden im Themenverzeichnis `themes\<themes-name>\assets\` gespeichert. Diese [Resourcen][] stehen global zur Verfügung und können einzelne Dateien oder ganze Verzeichnisse sein.

```Shell {linenos=false}
 themes/
  └── <themesname>
      └── assets
          ├── Foto01.jpg
          ├── Foto02.jpg
          ├── sass
          │   ├── main.scss
          │   └── base.sass
          └── images
              ├── FotoX.jpg
              ├── FotoY.jpg
              └── FotoZ.jpg

```

Der Zugriff auf die Ressourcen in Html-Dateien erfolgt mit folgenden Funktionen:

>* __resources.Get__ - findet den Dateinamen, der in Hugos Assets-Dateisystem angegeben ist und erstellt ein Ressourcenobjekt, das für weitere Transformationen verwendet werden kann.
>* __resources.GetRemote__ - wie resources.Get nur für URL's
>* __resources.Match__ - ruft alle Ressourcen ab, die mit dem angegebenen Basispfad übereinstimmen. 
>* __resources.GetMatch__ - findet die erste Ressource, die mit dem angegebenen Muster übereinstimmt, oder nil, wenn keine gefunden wird.

Hier ein paar Beispiele.

```go-html-template {linenos=false}

 // Beispiel Match **.jpg findet alle jpg-Files unterhalb von assets
 // ================================================================
 {{ with resources.Match "**.jpg" }}
	{{ range . }}
		{{ .Permalink }} {{ .Width }} {{ .Height }}
		<img src={{ .Permalink }}>
	{{ end }}	
 {{ end }}
   
   
   
 // Beispiel Get für Einzeldatei
 // ============================
 {{ $image := resources.Get "images/FotoX.jpg" }}
 {{ $image := $image.Fit "300x400" }}
 <img src={{ $image.Permalink }} >

 {{ $image := $image.Filter (images.GaussianBlur 6) (images.Pixelate 8) }}
 <img src={{ $image.Permalink }}>
   
```





## Lokale Resources

Lokale Ressourcen bzw. [Seitenressourcen][PageResources] werden im Seitenverzeichnis `content\...` abgelegt. 

```Shell {linenos=false}
 content/
  └── category
      ├── thema-1
      │   ├── index.md
      │   ├── article01.md
      │   ├── article02.md
      │   ├── info.pdf
      │   ├── Blume.jpg
      │   ├── FotoX.jpg
      │   └── FotoZ.jpg
      └── thema-2

```

Um lokale Ressourcen einzubinden wird die [Seitenvariable][] _.Page.Parent_ voran gestellt.

### Methoden 

Mit der Methode _Resources.Get_ wird eine Ressource angesprochen.

```go-html-template {linenos=false}

 {{ $image := .Page.Parent.Resources.Get "Blume.jpg" }}
 {{ with $image }}
    	{{ $image.RelPermalink }}">
 {{ end }}
   
```
Die Methode _Resources.Match_ hingegen spricht alle Ressourcen im Seitenverzeichnis an.
   
```go-html-template {linenos=false}

 {{ with .Page.Parent.Resources.Match "**.jpg" }}
 	{{ range . }}
		{{ .RelPermalink }}
	{{ end }}
 {{- end -}}
   
```

### Eigenschaften (Properties)

Globale wie lokale Ressourcen haben die gleichen Befehle für die Abfrage von Eigenschaften.

{{<resourcesproperties "sass\shortcodes\tabs.scss" global>}}

Bei einem _ResourceType=image_ werden noch Exifdaten ausgegeben.

{{<resourcesproperties "Blume.jpg">}}

#### Eigenschaft Content

Der Inhalt einer Ressource kann mit der Content-Eigenschaft direkt in Html integriert werden. 
Am Beispiel einer Bilddatei aus dem Ressourcenverzeichnis `assets` demonstriert der folgende Code wie eine Grafiken mittels einer [Daten-URI][]
direkt in statisches Html transformiert wird. Dazu müssen [Hugo-Pipes][] genutzt werden.

```go-html-template {linenos=false}

 {{ with resources.GetMatch "images/**.jpg" }}
	<img src="data:{{ .MediaType }};base64,{{ .Content | base64Encode }}">
 {{ end }}
   
```

Als Ergebnis steht im Html-Seitenquelltext die Zeile:

```html {linenos=false}

  <img alt="Beispiel_Daten_URI" src="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAMgAAABxCAYAAACQnewjAACAAElEQVR4nLT9d5 .....
   
```

Und natürlich das entsprechende Bild.

{{<result type="resources.content">}}

[Resourcen]:	  https://gohugo.io/hugo-pipes/introduction/#find-resources-in-assets
[Hugo-Pipes]:	  https://gohugo.io/hugo-pipes/introduction/
[Daten-URI]:	  https://wiki.selfhtml.org/wiki/Grafik/Grafiken_mit_Data-URI
[Seitenvariable]: {{< relref "/edv/gohugo/hilfe/funktion#page-variable" >}}
[Bundletype]:	  https://gohugo.io/methods/page/bundletype
[Bundle]:	  https://gohugo.io/content-management/page-bundles/	
[PageResources]:  https://gohugo.io/content-management/page-resources
