+++
tags = ["dev", "gohugo", "shortcodes"]
zusammenfassung = "Vorlagen mit Shortcodes erstellen."
title = "Shortcodes"
submenu = "false"
date = "2021-03-16T13:38:03+01:00"
type = "article"
+++

Shortcodes sind benutzerdefinierte Vorlagen die im Verzeichnis: `<themename>/layout/shortcodes` hinterlegt werden. 
Die dazu benötigten Compact Style Sheets können als Sass-Dateien abgespeichert werden in: `<themename/assets/sass/shortcodes/`.
Einige der folgenden Shortcodes stammen aus dem Thema [docport][].

## Vorabinfo zum Trennzeichen %

Shortcodes werden aufgerufen in der Form mit  `{{</* shortcodename */>}}` oder mit `{{%/* shortcodename */%}}`.
Das Trennzeichen `%` teilt Gohugo mit, dass der gerenderte Shortcode weiter verarbeitet wird. Sie können dann Teil des generierten Inhaltsverzeichnisses, der Fussnoten usw. sein. Das Trennzeichen `< >` teilt Gohugo mit, dass der gerenderte Shortcode keiner weiteren Verarbeitung bedarf.

Am Beispiel des Shortcodes `dummy.html` wird die Funktionsweise der Trennzeichen demonstriert.

{{<code lang="markdown" title="dummy.html">}}
 {{- .Inner -}}
{{</code>}}

#### Beispiel mit Trennzeichen %

```apl{linenos=false}

 {{%/*dummy*/%}}
	Der __Inhalt__ mit dem `Trennzeichen %` wird ___nochmal___ `gerendet`.
 {{%/*/dummy*/%}}
   
```     
{{% dummy %}} Der __Inhalt__ mit dem `Trennzeichen %` wird ___nochmal___ `gerendet`. {{% /dummy %}}

#### Beispiel mit Trennzeichen <

```apl{linenos=false}

 {{</*dummy*/>}}
	Der __Inhalt__ mit dem `Trennzeichen >` wird nicht ___nochmal___ `gerendet`. 
 {{</*/dummy*/>}}
   
```

{{<dummy>}}Der __Inhalt__ mit dem `Trennzeichen >` wird nicht ___nochmal___ `gerendet`.{{</dummy>}}

#### Die Funktion markdownify

Mit der Funktion [markdownify][] wird der Inhalt mit Trennzeichen `<` doch gerendert.

{{<code lang="markdown" title="dummy.html">}}
 {{- .Inner | markdownify -}}
{{</code>}}

{{% dummy %}} Der __Inhalt__ mit dem Trennzeichen `<` und der Funktion `markdonify` wird ___doch___ `gerendet`. {{% /dummy %}}

#### Verhalten vor Version 0.55

In einigen Shortcodes wie z.B. [Notice][] und [Tabs][] findet man folgende Codezeile:

```go-html-template {linenos=false}
   
 {{ $_hugo_config := `{ "version": 1 }` }}
   
```

Die Funktionsweise des Trennzeichen `%` beim Aufruf von Shortcodes der Form `{{%/* shortcodename */%}}` wurde ab der [Gohugo Version 0.55][gohugo_v0.55] geändert.
Mit der o.g. Codezeile wird das alte Verhalten vor Version 0.55 generiert. Mittlerweile hat dieser Eintrag keine Auswirkung mehr und kann deshalb entfallen.  




## Menu.html

Das Shortcode `menu.html` verdeutlicht Menus im Textfluss, indem es in einer anderen Farbe und in einem anderen Stil dargestellt wird.
Als Trennzeichen zwischen den einzelnen Menupunkten wird ein Schrägstrich (Slash) `/` verwendet. Standardmäßig wird der Prefix `Menu:` verwendet. Optional kann ein anderer Prefix vorangestellt werden.

{{<code lang="apl" title="Anwendung in Markdown">}}
 {{</*menu "Datei/Einstellungen/..."*/>}}			-> im Text erscheint: «Menu: Datei → Einstellungen»
 {{</*menu "Datei/Einstellungen/..." "prefix:"*/>}}		-> im Text erscheint: «prefix: Datei → Einstellungen»
{{</code>}}

{{<expand title="Beispiel von Menuangaben im Text">}}
{{<mustertext>}}{{<menu "Datei/Einstellungen/Textoptionen/Informationen/...und so weiter...">}}{{<mustertext>}}
{{<menu "Datei/Einstellungen" "prefix:">}}{{<mustertext>}}
{{</expand>}}


## Code.html
Die in Gohugo vorbereiteten [Chroma-Syntaxhighlights][] können in einer eigenen Shortcodedatei `./layouts/shortcodes/code.html` ergänzt und das
weitere Aussehen definiert werden. 

{{<code lang="apl" title="Anwendung in Markdown">}}
 {{</*code lang="required" file="optional" title="optional" options="optional" */>}}

	[content]
	
 {{</*/code*/>}}
{{</code>}}

### Optionen

Folgende Optionen stehen für Code.html zur Verfügung:

{{<mytable class="greyhead small smallfont fontcourier striped">}}
| Option   | Usage                                                                                                                               |
| -------- | ----------------------------------------------------------------------------------------------------------------------------------- |
| lang     | Language for [syntax highlighting](https://gohugo.io/content-management/syntax-highlighting/#list-of-chroma-highlighting-languages) |
| title    | Shows Title as Banner. Is `title="filename"` shows filename as banner.                                                                  |
| file     | Path to the included file relative to the Hugo root.                                                                                 |
| options  | Highlighting [options](https://gohugo.io/content-management/syntax-highlighting/#highlight-shortcode)                               |
{{</mytable>}}

Beispielanwendung insbesondere mit `options` für das Hervorheben von Zeilen.

{{<code lang="apl" title="Beispiele" options="linenos=false,hl_lines=7 8 13-15">}}
 # Standardanwendung
 {{</*code lang="c++"*/>}}
 {{</*code lang="c++" title="Text im Banner"*/>}}
	
 # Options
 {{</*code lang="c++" options="linenos=table,linenostart=12,hl_lines=3 6 9-15"*/>}}
 {{</*code lang="c++" options="linenos=false,linenostart=12,hl_lines=1 5 8 12-15"*/>}}

 # Beispiel mit Integration einer Datei 	
 {{</*code lang="c++" file="./path/to/file.cpp" title="filename"*/>}}
 {{</*code lang="c++" file="./path/to/file.cpp" title="Irgendein Titel"*/>}}
 {{</*code lang="c++" file="./path/to/file.cpp" options="linenos=table,linenostart=12,hl_lines=3 6 9-15"*/>}}
 {{</*code lang="c++" file="./path/to/file.cpp" options="hl_lines=1 5 6 7,linenostart=1,linenos=table" */>}} 
 {{</*code lang="cpp" file="/static/include_files/main.cpp" options="linenos=true" */>}}
{{</code>}}

### Weitere Hinweise

Um Shortcode-Anweisung in Syntaxhighlight's zu deaktivieren und stattdessen anzuzeigen, verwende die Zeichen: \/\*  ...  \*\/ 

{{<mytable class="width50 tableleft noborder striped fontcourier smallfont small">}}
|Shortcode| deaktiviert|
|:--:|:--:|
| \{\{\<param date\>\}\} | \{\{\<\/\*param date\*\/\>\}\} |
| \{\{\<code lang=...\>\}\} | \{\{\<\/\*code lang=...\*\/\>\}\} |
| \{\{\<mytable\>\}\} | \{\{\<\/\*mytable\*\/\>\}\} |
| \{\{\<\/mytable\>\}\} | \{\{\<\/\*/mytable\*\/\>\}\} |
{{</mytable>}}

Mit dem verbesserten Shortcode `{{</*code*/>}}` können nunmehr ganze Dateien eingelesen und mit einem entsprechenden [Syntaxhighlight][] gerendert werden. 
Im Weiteren ist es kein Problem [Backticks][] als Syntaxhighlight anzuzeigen.

{{<code lang="shell" title="Beispiel mit Backticks (Codezäune)">}}  
```bash
	[content]
```
{{</code>}}

### Anwendungsbeispiele

#### Beispiel C++ File included

{{<code lang="apl" title="Beispiel mit Integration einer C++ Datei">}}
 {{</*code lang="cpp" file="/static/include_files/main.cpp" options="linenos=true" title="Beispiel C++ File included"*/>}}

 {{</*/code*/>}}
{{</code>}}

__Ergebnis:__

{{<code lang="cpp" file="/static/include_files/main.cpp" options="linenos=true" title="Beispiel C++ File included">}}

{{</code>}}


#### Beispiel Sass File included

{{<code lang="apl" title="Beispiel mit Integration einer Sass Datei">}}
 {{</*code lang="sass" file="/themes/mab-3.0/assets/sass/main.sass" options="linenos=true" title="Beispiel Sass"*/>}}

 {{</*/code*/>}}
{{</code>}}

__Ergebnis:__

{{<code lang="sass" file="/themes/mab-3.0/assets/sass/main.sass" options="linenos=true" title="Beispiel Sass">}}

{{</code>}}


#### Beispiel Shortcode Html File included

{{<code lang="html" title="Beispiel mit Integration einer Html Datei">}}
 {{</*code lang="go-html-template" file="/themes/mab-3.0/layouts/_default/baseof.html" options="linenos=true" title="Beispiel _default/baseof.html"*/>}}

 {{</*/code*/>}}
{{</code>}}

__Ergebnis:__


{{<code lang="go-html-template" file="/themes/mab-3.0/layouts/_default/baseof.html" options="linenos=true" title="Beispiel _default/baseof.html">}}

{{</code>}}




## CSV-Datei mit viewcsv.html anzeigen

Eine CSV-Datei kann mittels Shortcodes in einer Tabelle dargestellt werden.  

{{<code lang="go-html-template" title="Anwendung in Markdown">}} 
 {{</* viewcsv url="required" sep="optional" caption="optional" class="optional" */>}}
{{</code>}}

Folgende Optionen stehen für viewcsv.html zur Verfügung:

{{<mytable class="greyhead small smallfont fontcourier striped">}}
| Option   | Usage                                                                                                                               |
| -------- | ----------------------------------------------------------------------------------------------------------------------------------- |
| url     | Path zur CSV-Datei |
| sep     | Spaltentrennzeichen (Seperator, Delimiter) Standard ist Komma                                                                    | 
| caption | Tabellentitel                                                                                 |
| class   | Eigenschaften zur Darstellung der Tabelle ([Tabellen-Styles]({{< relref "table_mytable/#styles-option" >}}))                            |
{{</mytable>}}

### Anwendungsbeispiel

{{<code lang="go-html-template" title="Beispiel csv-Datei als Delimiter">}} 
 {{</* viewcsv url="csv/SalesJan2009.csv" caption="SalesJan2009.csv" */>}}
 {{</* viewcsv url="csv/Baupreisindex.csv" sep=";" */>}}
{{</code>}}

Ergebnis:

{{<viewcsv url="csv/SalesJan2009.csv" caption="SalesJan2009.csv" >}}

Weitere Beispiele für Tabellen in gohugo bei [zwbetz.com][].







## Expand Text 

Zusammenklappbare Abschnitte mit `{{</*expand*/>}}` erstellen (engl. collapsible).

{{<code lang="go-html-template" file="/themes/mab-3.0/layouts/shortcodes/expand.html" options="linenos=true" title="Shortcodefile: expand.html">}}

{{</code>}}





{{<code lang="go-html-template" title="Expand - Beispielanwendung in Markdown (*.md)">}} 
 {{</*expand title="Expand Shortcode Sample"*/>}}
 In einer Expansionsvorlage können insoweit alle markdowntypischen Elemente verwendet werden.  
 ...
 ...
 ...
 {{</*/expand*/>}}
{{</code>}}

{{% expand title="Expand Shortcode Sample" %}}
In einer Expansionsvorlage können insoweit alle markdowntypischen Elemente verwendet werden.  
    
Zum Beispiel:   
   
Schriftstile: **Fett** *Cursive* ***Fett und Cursive***   
* __Aufzählung__   
Text Text Text Text
* Aufzählung 2   
Text Text Text Text
   
__Nummerierung__
1. Text
2. Text


__Tabellen__
| Spalte 1 | Spalte 2|
|:--------:|:-------:|
| wert 1 | wert 2|
| wert 1 | wert 2|

__Codehighligths__ sind ebenfalls anwendbar. Jedoch werden nur die mit Backticks (\`\`\`bash ... \`\`\`) eingeleiteten Codehighliths erkannt. Shortcodes wie  `{{</*code*/>}}` oder `{{</*highlight*/>}}` werden innerhalb von `{{</*expand*/>}}` nicht erkannt. 

```bash
 #!/bin/bash
 ###### CONFIG
 ACCEPTED_HOSTS="/root/.hag_accepted.conf"
 BE_VERBOSE=false
```


>Und sogar __Blockqoutes__ (Text einrücken) ist möglich   
Text Text Text Text

{{%/ expand %}}

>__Hinweis:__ Die Höhe der Expansionsvorlage ist begrenzt auf:  __max-height: 1000em;__   
Siehe in der entsprechenden Stylesheetsdatei.

## Columns
Die Vorlage `{{</*columns*/>}}` zeigt Inhalte spaltenweise nebeneinander an. Die Spaltenüberschriften werden mit einem Doppelkreuz `#` eingeleitet. 

{{<code lang="go-html-template" file="/themes/mab-3.0/layouts/shortcodes/columns.html" options="linenos=true" title="Shortcodefile: columns.html">}}

{{</code>}}





{{<code lang="go-html-template" title="Columns - Beispielanwendung in Markdown (*.md)">}} 
 {{</*columns class="Option1 Option2"*/>}} 
 ## Title Left
 Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod
 tempor incididunt ut labore et dolore magna aliqua. 

 <---> <!-- magic separator, between columns -->

 ### Title Mid 
 Ut enim ad minim veniam,
 quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo
 consequat. 

 <---> <!-- magic separator, between columns -->

 #### Title Right
 Duis aute irure dolor in reprehenderit in voluptate velit esse
 cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non
 {{</*/columns*/>}}
{{</code>}} 

__Ergebnis:__

{{<expand title="Columns Beispiel mit Zwei Spalten">}}

{{<columns>}} <!-- begin columns block -->
## Title Left
Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod
tempor incididunt ut labore et dolore magna aliqua. 

<---> <!-- magic separator, between columns -->
#### Title Mid 
Duis aute irure dolor in reprehenderit in voluptate velit esse
cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non
{{</columns>}}

>__Hinweis:__ Die unterschiedlichen Höhen der Spalten sind das Ergebnis der unterschiedlichen Spaltenüberschriften (h2 - h4).

{{</expand>}}

{{<expand title="Columns Beispiel mit Zwei Spalten und class=\"growlast\"">}}

{{<columns class="growlast">}} <!-- begin columns block -->
## Title Left
Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod
tempor incididunt ut labore et dolore magna aliqua. 

<---> <!-- magic separator, between columns -->
#### Title Mid 
Duis aute irure dolor in reprehenderit in voluptate velit esse
cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non
{{</columns>}}

>__Hinweis:__ Die unterschiedlichen Höhen der Spalten sind das Ergebnis der unterschiedlichen Spaltenüberschriften (h2 - h4).

{{</expand>}}

{{<expand title="Columns Beispiel mit drei Spalten und class=\"growfirst color\" ">}}

{{<columns class="color growfirst" >}} <!-- begin columns block -->
## Title Left X
Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod
tempor incididunt ut labore et dolore magna aliqua. 

<---> <!-- magic separator, between columns -->
### Title Mid X
Ut enim ad minim veniam,
quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo
consequat. 

<---> <!-- magic separator, between columns -->
#### Title Right X
Duis aute irure dolor in reprehenderit in voluptate velit esse
cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non
{{</columns>}}

{{</expand>}}


{{<expand title="Columns Beispiel mit Vier Spalten und class=\"color\"">}}

__Mit mehr als 3-Spalten macht columns keinen Sinn__

{{<columns class="color" >}} <!-- begin columns block -->
## Title Left Content
Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod
tempor incididunt ut labore et dolore magna aliqua. 

<---> <!-- magic separator, between columns -->
### Mid Content 1
Ut enim ad minim veniam,
quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo
consequat. 

<---> <!-- magic separator, between columns -->
### Mid Content 2
Ut enim ad minim veniam,
quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo
consequat. 

<---> <!-- magic separator, between columns -->
#### Title Right Content
Duis aute irure dolor in reprehenderit in voluptate velit esse
cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non
{{</columns>}}


{{</expand>}}


#### Styles Option

Folgende Optionen für `{{</*columns*/>}}` stehen zur Verfügung:

{{<mytable caption="Columns Optionen" class="width50 smallfont fontcourier captleft greyhead striped noborder">}}
| class Option | Effekt |
|:--|:--|
| center | Textausrichtung zentriert |
| left | Textausrichtung links (standard) |
| right | Textausrichtung rechts |
| color | Einfärben des Frames für Testzwecke. |
| growlast  | Vergrößert das letzte Frame um den Faktor 2. Ist nur für zwei Spalten geeignet. |
| growfirst  | Vergrößert das erste Frame um den Faktor 2. Ist nur für zwei Spalten geeignet. |
{{</mytable>}}

Eine symetrische Darstellung ergibt sich mit der Option `class="center"` wenn nur zwei Spalten benötigt werden und eine Spalte eine Tabelle enthält und die andere Spalte ein Bild.


## Panel
Ein Panel ist eine Tafel (oder Board) mit dem Informationen besonders hervorgehoben werden (Farbe, Überschrift, Fußraum).

{{<code lang="go-html-template" title="Shortcodefile: panel.html">}} 
 <div class="card ">
  {{- with .Get "header" -}}
  <div class="card-header {{with $.Get "theme" }}{{.}}{{else}}primary{{end}}">
    {{- htmlUnescape . | markdownify -}}
  </div>
  {{- end -}}
  <div class="card-body">
    <p class="card-text">{{- .Inner -}}</p>
  </div>
  {{- with .Get "footer" -}}
  <div class="card-footer text-muted">
    {{- htmlUnescape . | markdownify -}}
  </div>
  {{- end -}}
 </div>
{{</code>}} 



{{<code lang="go-html-template" title="Panel - Beispielanwendung in Markdown (*.md)">}} 
 {{</*panel theme="success" header="Überschrift" footer="Fußraum"*/>}}
 Text Text Text text.
 {{</*/panel*/>}}

 {{</*panel*/>}}this is a simple panel{{</*/panel*/>}}
{{</code>}} 

Ergebnis:

{{<panel theme="success" header="Überschrift" footer="Text im Fußraum">}}
Text Text Text text.
{{</panel>}}

{{<panel>}}this is a simple panel{{</panel>}}

>{{<panel theme="info" header="Hinweis Blockquotes">}}Ein Panel kann mit Blockquotes eingerückt werden.{{</panel>}}

### Panel-Themes

{{<panel theme="success" header="success theme">}}this is a panel text{{</panel>}}

{{<panel theme="default" header="default theme">}}this is a panel text{{</panel>}}

{{<panel theme="primary" header="primary theme">}}this is a panel text{{</panel>}}

{{<panel theme="info" header="info theme">}}this is a panel text{{</panel>}}

{{<panel theme="warning" header="warning theme">}}this is a panel text{{</panel>}}

{{<panel theme="danger" header="danger theme">}}this is a panel text{{</panel>}}


## Tabs - Registrierkarten

Mithilfe von Registrierkarten `{{</*tabs*/>}}` können Inhalte organisiert werden. Z.B. HelloWorld-Anweisung für verschiedene Sprachen.

{{<code lang="md" title="Tabs - Beispielanwendung in Markdown (*.md)">}} 
 {{</*tabs*/>}}
 {{</*tab "PHP"*/>}} 
 Text Text Text Text 

	Codeblock 1 mit Backticks einschließen

 {{</*/tab*/>}}
 {{</*tab "Golang"*/>}} 
 Text Text Text Text 

	Codeblock 2 mit Backticks einschließen

 {{</*/tab*/>}}
 {{</*/tabs*/>}}
{{</code>}} 

Ergebnis:

{{<tabs>}}
{{<tab "PHP">}} 
    Beschreibung Text Text Text Text 
```php
	<?php 
	Print "Hello, World!";
	?>
```
{{</tab>}}
{{<tab "Golang">}} 
Beschreibung Text Text Text Text 
```go
	package main
	import "fmt"
	func main() {
	    fmt.Println("hello world")
	}	
```
{{</tab>}}
{{</tabs>}}

>__Hinweis:__ Die Schrift der Beschreibung wird kleiner wenn vier Leerzeichen vorangestellt werden.

## Alert - Warnung

Die benutzerdefinierte Vorlage `{{%/* alert */%}}` wird verwendet, um kurze Informationen hervorzuheben. Der Text kann auch mit dem Schriftstil `**FETT**` besonders betont  werden. 

{{<code lang="go-html-template" title="Shortcodes: alert.html">}}
 <div class="alert{{- " " -}}
 {{- if .IsNamedParams -}}{{- with .Get "theme" -}}{{.}}{{- else -}}info{{- end -}}
 {{- else -}}
	{{- with .Get 0 -}}{{.}}{{- else -}}info{{- end -}}
 {{- end -}} " role="alert">
 {{- .Inner | safeHTML | markdownify  -}}
 </div>
{{</code>}}

{{<code lang="apl" title="Alert - Beispielanwendung in Markdown (*.md)">}} 
 {{%/* alert */%}}**this** is a simple alert{{%/* /alert */%}}
 {{%/* alert primary */%}}**this** is a primary{{%/* /alert */%}}
 {{%/* alert theme="info" */%}}**this** is a text with theme "info"{{%/* /alert */%}}
 {{%/* alert theme="success" */%}}**Yeahhh !** is a text with theme "success"{{%/* /alert */%}}
 {{%/* alert theme="warning" */%}}**Be carefull** is a text{{%/* /alert */%}}
 {{%/* alert danger */%}}**Beware !** is a text{{%/* /alert */%}}
 {{%/* alert dark */%}}**Dark !** is a dark{{%/* /alert */%}}
 {{%/* alert light */%}}**oooh !** is a light{{%/* /alert */%}}
 {{%/* alert secondary */%}} **Wait** is a secondary{{%/* /alert */%}}
{{</code>}} 

Ergebnis:

{{<alert>}}**this** is a simple alert{{</alert>}}

{{<alert primary>}}**this** is an primary{{</alert>}}

{{<alert theme="info">}}**this** is a text with theme "info"{{</alert>}}

{{<alert theme="success">}}**Yeahhh !** is a text with theme "success"{{</alert>}}

{{<alert theme="warning">}}**Be carefull** is a warning{{</alert>}}

{{<alert danger>}}**Beware !** is a danger{{</alert>}}

{{<alert dark>}}**Dark !** is a dark{{</alert>}}

{{<alert light>}}**oooh !** is a light{{</alert>}}

{{<alert secondary>}}**Wait !** is a secondary{{</alert>}}

>>{{<alert theme="info">}}**Hinweis:** Mit Blockquotes kann ein `alert` eingerückt werden.{{</alert>}}

## Notice

Notizen sind ähnlich wie Alert-Vorlagen eine Möglichkeit Informationen, in diesem Fall umfangreicher, darzustellen. 

{{<code lang="apl" title="Notice - Beispielanwendung in Markdown (*.md)">}} 
 {{%/* notice $color $label */%}}
 Text Text Text
 \   <-- neuer Absatz -->
 Text Text Text
 {{%/* /notice */%}}
{{</code>}}

### Example

Beispiele für Notice-Vorlagen.

{{% notice primary Textbetonung %}}
\
Im Shortcode **notice** können auch Textbetonungen mit führenden und nachfolgenden Unterstrich verwendet werden.
\
\
\_Kursive\_ = _Kursive_
\
\
\_\_Fett\_\_ = __Fett__
\
\
\_\_\_Fett und Kursive\_\_\_ = ___Fett und Kursive___
\
\
\~\~Durchgestrichen\~\~ = ~~Durchgestrichen~~ 
{{% /notice %}}
   
{{% notice info Absatzmarkierung %}}
\
\
Absätze werden mit einem Backslash \\ eingeleitet.
\
\
Die letzte Zeile einer innerhalb eines **notice**-Bereiches muss ein Text beinhalten.
{{% /notice %}}

{{% notice success %}}Lorem ipsum dolor sit amet, consectetur.{{% /notice %}}

{{% notice %}} Lorem ipsum dolor sit amet, consectetur.{{% /notice %}}

{{% notice warning %}} Lorem ipsum dolor sit amet, consectetur{{% /notice %}}

{{% notice danger Attention %}}
Lorem ipsum dolor sit amet, consectetur
{{% /notice %}}



### Colors

Farbgestaltung in Notice-Vorlagen.

| Type | Code |
|:--|:--|
| {{% notice %}}This is the default notice.{{% /notice %}} | {{</* notice */>}} ... {{</* /notice */>}} |
| {{% notice primary %}}This is a primary notice.{{% /notice %}} | {{</* notice **primary** */>}} ... {{</* /notice */>}} |
| {{% notice secondary %}}This is a secondary notice.{{% /notice %}} |  {{</* notice **secondary** */>}} ... {{</* /notice */>}} |
| {{% notice success %}}This is a success notice.{{% /notice %}} | {{</* notice **success** */>}} ... {{</* /notice */>}} |
| {{% notice danger %}}This is a danger notice.{{% /notice %}} |  {{</* notice **danger** */>}} ... {{</* /notice */>}} |
| {{% notice warning %}}This is a warning notice.{{% /notice %}} | {{</* notice **warning** */>}} ... {{</* /notice */>}} |
| {{% notice info %}}This is a info notice.{{% /notice %}} | {{</* notice **info** */>}} ... {{</* /notice */>}} |
| {{% notice light %}}This is a light notice.{{% /notice %}} |  {{</* notice **light** */>}} ... {{</* /notice */>}} |
| {{% notice dark %}}This is a dark notice.{{% /notice %}} | {{</* notice **dark** */>}} ... {{</* /notice */>}} |


### Labels (Etiketten)

Notizen mit einem Etikett (Label) versehen.

| Type | code |
|:--|:--|
| {{% notice primary %}}This is a notice without label.{{% /notice %}} | {{</* notice primary */>}} ... {{</* /notice */>}} |
| {{% notice primary toto %}}This is a notice with "toto" label.{{% /notice %}} | {{</* notice primary **toto** */>}} ... {{</* /notice */>}} |
| {{% notice primary "my label" %}}This is a with "my label".{{% /notice %}} | {{</* notice primary **"my label"** */>}} ... {{</* /notice */>}} |








[docport]:		https://themes.gohugo.io/hugo-theme-docport/
[zwbetz.com]:	https://zwbetz.com/create-an-html-table-from-a-toml-data-file-in-hugo

[Chroma-Syntaxhighlights]:    	{{< relref "markdown-mit-hugo#syntax-highlights" >}}
[Backticks]:					{{< relref "markdown-mit-hugo/#backtick" >}}
[Syntaxhighlight]:				{{< relref "markdown-mit-hugo/#syntax-highlights" >}}
[Notice]:						{{< relref "shortcodes/#notice" >}}
[Tabs]:							{{< relref "shortcodes/#tabs---registrierkarten" >}}
[Tabellenstyles]:				{{< relref "table_mytable/#styles-option" >}}


[diffdelimiter]:		https://gohugo.io/content-management/shortcodes/#shortcodes-with-markdown
[gohugo_v0.55]:			https://github.com/gohugoio/hugo/releases/tag/v0.55.0
[markdownify]:			https://gohugo.io/functions/markdownify/

