+++
tags = ["video", "ffmpeg"]
zusammenfassung = "FFMPEG - Programm zum bearbeiten, streamen, konvertieren von Video und Audiomaterial."
title = "FFMPEG - Video, Audio, Streaming, Codecs, Konvertierung."
date = "2020-12-09T14:21:00+01:00"
type = "article"
+++


## Bildschirmaufnahme mit ffmpeg 


{{<code lang="bash" title="ffmpeg als Bildschirmaufnahmegerät in Linux">}}
 # Bildschirmauflösung ermitteln
 current=`xrandr -q 2>/dev/null | grep "*" | awk '{ print $1}'`;

 # Desktopaufnahme mit Audio 
 ffmpeg -hide_banner \
        -f alsa \
        -i default \
        -video_size $current \
        -f x11grab \
        -framerate 30 \
        -probesize 42M \
        -i :0.0 \
 	/tmp/output.mp4
{{</code>}}

Um bei einer Desktopaufnahme den Audiostream anstatt vom Mikrofon direkt vom Lautsprecher in ffmpeg zu transportieren, ist der Lautstärkekontroller von PulsAudio __pavucontrol__ notwendig.

![](/edv/media/pavucontrol-aufnahme.png "#width=75% {frame}" )


## Bildschirmaufnahme mit ffmpeg unter Windows

Lade dir die Windowsbinarys von der [ffmpeg-Seite][ffmpeg.org] runter. Die unten aufgeführten Beispiele nutzen die Releaseversion 5.1.2 von [gyan.dev.][gyan.dev]


### Desktopaufnahme mit ffmpeg ohne Audio.

{{<expand title="Bildschirmaufnahme in Windows Codebeispiel 1">}}
{{<code lang="cmd" options="linenos=false" file="/static/include_files/ffmpeg-desktop-aufnahme-01.cmd" >}}
{{</code>}}
{{</expand>}}


{{<expand title="Bildschirmaufnahme in Windows Codebeispiel 2">}}
{{<code lang="cmd" options="linenos=false" file="/static/include_files/ffmpeg-desktop-aufnahme-02.cmd" >}}
{{</code>}}
{{</expand>}}




### Desktopaufnahme mit ffmpeg mit Audioton.

Um den Audioton bei Streamingdiensten wie Youtube aufzunehmen, muss bei Windows 10 erst das Mikrofon eingeschaltet werden.

{{<code lang="cmd" options="linenos=false">}}
 start ms-settings:privacy-microphone
{{</code>}}

Im Weiteren muss das Audioausgabegerät ermittelt werden.

{{<code lang="cmd" options="linenos=false">}}
 ffmpeg.exe -list_devices true -f dshow -i dummy -hide_banner

 [dshow @ 000002c2e5602580] DirectShow video devices (some may be both video and audio devices)
 [dshow @ 000002c2e5602580] Could not enumerate video devices (or none found).
 [dshow @ 000002c2e5602580] DirectShow audio devices
 [dshow @ 000002c2e5602580]  "Stereomix (Realtek High Definition Audio)"
 [dshow @ 000002c2e5602580]     Alternative name "@device_cm_{33D9A762-90C8-11D0-BD43-00A0C911CE86}\wave_{CB94CC19-6B83-4657-B22A-8FCE4F13E0AD}"
 dummy: Immediate exit requested
{{</code>}}

Das Audioausgabegerät ist demnach:

{{<code lang="cmd" options="linenos=false">}}
 Stereomix (Realtek High Definition Audio)   
 Alternative name "@device_cm_{33D9A762-90C8-11D0-BD43-00A0C911CE86}\wave_{CB94CC19-6B83-4657-B22A-8FCE4F13E0AD}"
{{</code>}}

Das Audiogerät wird mit seinem __alternativen__ Namen der ffmpeg-Option: `-i audio` übergeben.

{{<code lang="cmd" options="linenos=false">}}
 -i audio="@device_cm_{33D9A762-90C8-11D0-BD43-00A0C911CE86}\wave_{CB94CC19-6B83-4657-B22A-8FCE4F13E0AD}"
{{</code>}}


Hier nochmal der Code für Desktopaufnahme mit ffmpeg und Audio.

{{<code lang="cmd" title="ffmpeg als Bildschirmaufnahmegerät in Windows mit Audioton" options="linenos=false">}}
 @echo off
 set PATH_FFMPEG=%~dp0
 echo %PATH%  | find /C /I "%PATH_FFMPEG%"   || @echo 'Das Verzeichnis: %PATH_FFMPEG% wird in die PATH-Umgebungsvariable aufgenommen.' && set PATH=%PATH%;%PATH_FFMPEG%


 rem ffmpeg.exe -list_devices true -f dshow -i dummy -hide_banner

 cmd.exe /C		^
   ffmpeg.exe		^
 	-f gdigrab 	^
 	-draw_mouse 1	^
 	-framerate 25	^
 	-i desktop 	^
 	-f dshow 	^
 	-i audio="@device_cm_{33D9A762-90C8-11D0-BD43-00A0C911CE86}\wave_{CB94CC19-6B83-4657-B22A-8FCE4F13E0AD}" ^
 	output.mp4
{{</code>}}

Nach mehrmaligen herum probieren ist letztendlich folgendes Windowsscript entstanden.

{{<code lang="cmd" title="Bildschirmaufnahmegerät mit Audio und Dateispliting" options="linenos=false" file="/static/include_files/ffmpeg-desktop-aufnahme-audio.cmd" >}}
{{</code>}}

## Links

[Link1](http://www.astro-electronic.de/Vortrag_FFmpeg_2.pdf)


[ffmpeg.org]:	https://ffmpeg.org/download.html
[gyan.dev]:		https://www.gyan.dev/ffmpeg/builds/
