+++
tags = ["radicale", "htpasswd"]
zusammenfassung = "Ein eigener Kalender und Adressbuchserver."
title = "Radicale"
date = "2024-08-21T14:31:55+02:00"
type = "article"
+++


Erfolgreich getestet mit folgender Version:
: radicale 3.1.8
: Debian 12 Bookworm 64bit

## Grundkonfiguration

In der Datei `/etc/radicale/config` werden Einstellungen vorgenommen. Die wichtigsten sind die IP-Adresse und der Port des Servers im Abschnitt [server] 
und das Authentifizierungsverfahren im Abschnitt [auth].

{{<code lang="fish" title="Datei: /etc/radicale/config">}}
 [server]
 hosts = xx.xxx.xxx.xx:5232

 [auth]
 type = htpasswd
 htpasswd_filename = /etc/radicale/users
 htpasswd_encryption = bcrypt 
{{</code>}}


{{<expand title="radicale config">}}
{{<code lang="bash" file="/static/include_files/radicale.config">}}
{{</code>}}
{{</expand>}}


## Benutzerkonfiguration

Das Anlegen und löschen eines Benutzers erfolgt durch das Programm `htpasswd` aus dem Debianpaket `apache2-utils`. 
Der Benutzer muss nicht auf dem System mit einem eigenen Home-Verzeichnis existieren.

{{<code lang="fish" title="Benutzer anlegen oder löschen">}}
 # Benutzer und Dateien löschen
 htpasswd -D  /etc/radicale/users <UserName>
 rm       -rf /var/lib/radicale/collections/collection-root/<UserName>

 # Benutzer anlegen und Passwortdatei erzeugen
 htpasswd -B -C10 -c /etc/radicale/users <UserName01>
 
 # Weiteren Benutzer anlegen oder Passwort ändern
 htpasswd -B -C10    /etc/radicale/users <UserName02>
{{</code>}}

{{<mytable caption="htpasswd Options" class="greyhead small smallfont fontcourier captleft nohead">}}
| Option   | Usage                                             |
| -------- | ------------------------------------------------- |
 -B | erzeugt Hashwert durch bcrypt-Algorithmus
 -c | Passwortdatei anlegen oder überschreiben
 -C \<number\> | Rundenanzahl für bcrypt-Algorithums - max. 17 
 -D \<UserName\> | löscht den Benutzers 
{{</mytable>}}

Und letztlich müssen Dateibenutzer, Gruppen (chown) und Dateizugriffsbit (chmod) geändert werden.


{{<code lang="fish" title="chown, chmod">}}
 chown    radicale:radicale /etc/radicale/users
 chown -R     root:radicale /var/lib/radicale
 chmod -R g=rwx             /var/lib/radicale
{{</code>}}

## Server starten und Test

Debiantypisch wird der Server gestartet mit dem Befehl: `systemctl restart radicale`. 
In einem beliebigen Browser wird in der Adresszeile die IP-Adresse des radicale-Servers wie folgt eingegeben: `http//:xxx.xxx.xxx.xxx:5232`.
Auf der Konsole kann getestet werden ob der Server gestartet ist und auf dem Port 5232 lauscht, mit:

{{<code lang="fish">}}
 netstat -tulpen | grep 5232
{{</code>}}

## Datenübertragung absichern mit TLS

Für eine verschlüsselte Übertragung wird TLS [(OpenSSL)][OpenSSL] verwendet. Zur Vereinfachung verwenden wir das mit dem Packet `ssl-cert` installierte Zertifikat und den Schlüssel.

{{<code lang="fish" title="Datei: /etc/radicale/config">}}
 [server]
 ssl = true
 certificate = /etc/ssl/certs/ssl-cert-snakeoil.pem
 key = /etc/ssl/private/ssl-cert-snakeoil.key
{{</code>}}

Der Nutzer _radicale_ muss der Gruppe _ssl-cert_ hinzugefügt werden.

{{<code lang="fish">}}
 sudo usermod -aG ssl-cert radicale
{{</code>}}

Nach einem Neustart des _radicale_-Servers kann die Bereitstellung des Zertifikats auf dem Client mit [OpenSSL][] getestet werden.

{{<code lang="fish">}}
 openssl s_client -connect <IP-Adresse>:5232 -tls1_3
{{</code>}}

Unter Umständen kann es sein, das das Zertifikat nicht automatisch von einem Client geladen wird. Gegebenenfalls muss es dann von Hand integriert werden.
Zum Beispiel in Thunderbird unter {{<menu "Einstellungen/Datenschutz & Sicherheit/Zertifikate verwalten/Ausnahme hinzufügen">}}, dann IP-Adresse eingeben und Zertifikat herunterladen.

Zur Sicherheit sollte man den Fingerabdruck des heruntergeladenen Zertifkats mit dem auf dem _radicale_-Server vergleichen. Auf dem Server wird der Fingerabdruck des Zertifkat mit folgendem Befehl angezeigt:

{{<code lang="fish">}}
 openssl x509 -in ssl-cert-snakeoil.pem -noout -fingerprint -sha256
{{</code>}}

## Weblinks

[Radicale Wiki by Ubuntu][radicale-wiki]   
[raspberry][]

[radicale-wiki]:	https://wiki.ubuntuusers.de/Radicale_2/
[raspberry]:		https://www.codingblatt.de/raspberry-pi-radicale-caldav-carddav-server-einrichten/
[OpenSSL]:		{{< relref "/edv/system/openssl" >}}

