+++
tags = ["system", "Administration", "apt", "dpkg"]
zusammenfassung = "Die Paketverwaltung von Debian und dessen Derivate."
title = "Apt, dpkg, etc."
date = "2023-04-13T11:24:42+02:00"
type = "article"
+++

### Eine bestimmte Programmversion installieren

Um zu erfahren welche verfügbare Version eines Programms in einem Repository vorliegt, nimm folgenden Befehl:

{{<code lang="fish">}}
 # Prüfen welche Versionen zu einem Paket vorliegen
 apt        policy    <package name>
 apt-cache  policy    <package name>
 apt-cache  madison   <package name>
 aptitude   versions  <package name>

 # Version installieren
 apt-get install <package name>=<version>
{{</code>}}

Willst du wissen, welche Programmpakete innerhalb eines Repository in unterschiedlichen Versionen vorliegt, nimm folgenden Befehl:

{{<code lang="fish">}}
 # alle Pakete ausgeben (inkl. Versionen)
 apt list --all-versions

 # Pakete mit mehreren Versionen ausgeben
 apt list --all-versions 2>/dev/null | cut -d "/" -f 1 | sort | uniq -d

{{</code>}}

### Entfernen der i386 Architektur

Ein 64bit-System (`amd64`) ermöglicht die Installation von Paketen eines 32bit-Systems (`i386`), sog. `multiarch`. 
Die Paketverwaltung bietet entsprechend die Installation der Pakete beider Versionen an.    
Um die 32-bit Architekture zu entfernen, nutzte den Debian Paketmanager [dpkg][dpkg_help] und mache folgendes als root:  

{{<code lang="fish">}}
 # Gibt die Architektur aus, die dpkg installiert hat
 dpkg --print-architecture

 # Gibt alle zusätzlichen Architekturen aus, die zur Verfügung stehen
 dpkg --print-foreign-architectures

 # i386 Architekture entfernen oder hinzufügen
 dpkg --remove-architecture i386
 dpkg --add-architecture i386

{{</code>}}

### Paket in einer Version halten -hold-

Um eine Aktualisierung von Programmen/Paketen zu verhindern, muss das Paket auf _hold_ gesetzt werden. 

{{<code lang="fish">}}
 #Paket anzeigen die im Moment auf hold sind
 dpkg --get-selections |awk '$2 == "hold" { print $1 }' 
 dpkg --get-selections | grep hold     

 #Paket auf hold setzen
 echo <package name> hold    | dpkg --set-selections  
 apt-mark hold <package name>

 # mehrere Pakete auf hold setzen.
 apt-mark hold $(dpkg -l| grep -i firefox | cut -d " " -f 3 )

 #Paket auf unhold setzen
 apt-mark unhold <package name>
{{</code>}}

### Paketabhängigkeiten anzeigen

{{<code lang="fish">}}
 apt-cache depends  <Package name> 	# Paket hängt ab von ... (werden benötigt um das Paket zu installieren)
 apt-cache rdepends <Package name>      # Pakete die von diesen Paket abhängen
{{</code>}}

### Weblinks

[Apt Hilfe im Ubuntu Wiki][apt_help]   
[dpkg Hilfe][dpkg_help]   
[Das Debian Paketmanagement ausführlich][debianPM]   
Siehe auch im [Debian Anwenderhandbuch][debianHandbuch] für apt-xxx, dpkg usw. 



[apt_help]:		https://wiki.ubuntuusers.de/APT/
[dpkg_help]:		https://wiki.ubuntuusers.de/dpkg/
[debianPM]:		https://book.dpmb.org/debian-paketmanagement.chunked/index.html
[debianHandbuch]:	https://www.debiananwenderhandbuch.de/arbeitenmitdateien.html#find
