+++
tags = ["system", "gpg", "gnupg"]
zusammenfassung = "Der GNU-Privatsphärenschutz"
title = "GNU Privacy Guard"
submenu = "false"
date = "2021-03-04T16:59:41+01:00"
type = "article"
+++




GnuPG dient zum Ver- und Entschlüsseln von Daten sowie zum Erzeugen und Prüfen von digitalen Signaturen.

![Text](/svg/Orange_blue_digital_signature_de.svg "Digitale Signatur mit GnuPG[[Quelle=https://commons.wikimedia.org/wiki/Special:ListFiles/Bananenfalter][CC0=https://creativecommons.org/publicdomain/zero/1.0/deed.en] #width=50%")

## Signatur pr&uuml;fen

Mit der Option `--verify` wird ein Dokument oder eine Datei mithilfe der digitalen Unterschrift auf seine Echtheit geprüft.

{{<code lang="fish">}}
 gpg --verify <digitale-Unterschrift> <Programm/Dokument>
{{</code>}}

Als Ausgabe sollte mindesten die _korrekte Signatur_ bestätigt sein. 

{{<code lang="cmd" title="Ausgabe OK" options="linenos=table, linenos=inline, linenostart=1">}}
 gpg: Korrekte Signatur von "Name <XXXX@yyyy.org>" [unbekannt]
 gpg: WARNUNG: Dieser Schlüssel trägt keine vertrauenswürdige Signatur!
 gpg:          Es gibt keinen Hinweis, daß die Signatur wirklich dem vorgeblichen Besitzer gehört.
 Haupt-Fingerabdruck  = AAAA BBBB CCCC DDDD FFFF  GGGG HHHH LLLL MMMM PPPP
{{</code>}}

Sollte folgende Ausgabe erscheinen, dann fehlt der öffentliche Schlüssel im Schlüsselbund. 

{{<code lang="cmd" title="Ausgabe mit fehlendem Schlüssel" options="linenos=table, linenos=inline, linenostart=1">}}
 gpg: Signatur vom Di 01 Jan 1970 00:00:00 CEST
 gpg:                mittels RSA-Schlüssel AAAABBBBCCCCDDDDFFFFGGGGHHHHLLLLMMMMPPPP
 gpg: Signatur kann nicht geprüft werden: Kein öffentlicher Schlüssel
{{</code>}}



## Schl&uuml;ssel des Benutzers auflisten

Alle GnuPG-Schlüssel eines Benutzers werden in einem Schlüsselbund im Home-Verzeichnis unter `~/.gnupg` gespeichert.

{{<code lang="fish">}}
 # öffentliche Schlüssel
 gpg --list-keys
 gpg -k
 gpg --list-keys   --keyid-format short
 gpg --fingerprint --keyid-format short
 
 # öffentliche Schlüssel aus anderem Schlüsselbund
 gpg --list-keys --no-default-keyring --keyring /etc/apt/trusted.gpg.d/datei.gpg
 
 # private Schlüssel
 gpg -K --fingerprint --keyid-format short
{{</code>}}

{{<code lang="cmd" title="Ausgabe Beispiel" options="linenos=table, linenos=inline, linenostart=1">}}
 pub   rsa4096/F4B1808F 2024-04-08 [SC] [verfällt: 2024-04-10]
       Schl.-Fingerabdruck = 9F3C C419 CB51 8FC0 7670  B79B 03E0 D5A5 F4B1 808F
 uid              [uneingeschränkt] MeinName (Kommentar) <MeineEmailAddresse@aaa.org>
 sub   rsa4096/33B5F09EB5F9AF02 2024-04-08 [E] [verfällt: 2024-04-10]
{{</code>}}

Die erste Zeile mit _pub_ (public oder auch _sec_ für private)  enthält die Verschlüsselungsart und die Schlüssellänge sowie die Schlüssel-ID _F4B18..._ im Kurzformat.
Wie man unschwer erkennen kann, bildet die _ID_ des Schlüssels teile des Fingerabdrucks.
Die Zeilen mit _sub_ enthalten die Unterschlüssel.

## Schl&uuml;ssel anderer auflisten

Neben dem eigenen Schlüsselbund existieren im System auch andere öffentliche Schlüssel, die bereits durch das Debian-Paketsystem installiert wurden. 
Z.B. in den Verzeichnissen: `/usr/share/keyrings/` oder `/etc/apt/trusted.../`.


{{<code lang="fish">}}
 # öffentliche Schlüssel aus anderem Schlüsselbund
 gpg --list-keys --no-default-keyring --keyring /<Path>/<file.gpg>

 # z.B. Inhalt von debian-keyring.gpg anzeigen
 gpg --no-default-keyring --keyring /usr/share/keyrings/debian-keyring.gpg --list-keys 2>/dev/null | grep -v verfallen

 # anzeigen aller im System installierten Pakete mit Schlüssel
 dpkg -l | grep -i keyring

 # auflisten eines Schlüsselpakets
 dpkg -L <PackageName> 
{{</code>}}
 

## Öffentlichen Schlüssel suchen und importieren

Einen öffentlichen Schlüssel erhält man vom Anbieter selbst (Webseite, Email) oder von einem Schlüsselserver.
Der Inhalt eines öffentlichen Schlüssels wird mit der Option `--with-fingerprint` angezeigt und mit `--import` in den eigenen Schlüsselbund integriert.


{{<code lang="fish">}}
 gpg --with-fingerprint <PublicKeyFile>
 gpg --with-fingerprint --keyid-format long <PublicKeyFile>

 gpg --import <PublicKeyFile>
{{</code>}}


## gpg - Optionen

{{<mytable class="captleft greyhead striped small smallfont fontcourier nowrap">}}
| Option | Beschreibung |
|:---|:---|
| \-\-dearmor | convert Sig-File from ASCII to Binary
| \-\-enarmor | convert Sig-File from Binary to ASCII
{{</mytable>}}

## Schlüsselserver


https://keyserver.ubuntu.com    
https://keys.openpgp.org  
https://keyserver.pgp.com    
http://pgp.mit.edu   
http://pgp.surfnet.nl





## Links

[GnuPG Artikel im Ubuntu-Wiki](https://wiki.ubuntuusers.de/GnuPG/)   
[Wikipediaartikel](https://de.wikipedia.org/wiki/GNU_Privacy_Guard)   
[Asymmetrische Verschlüsselung ](https://de.wikipedia.org/wiki/Asymmetrisches_Kryptosystem)   
[CodeTool](https://www.cryptool.org)


[gnupg]:	https://gnupg.org/signature_key.html
[gnupgkey]:	https://gnupg.org/signature_key.asc
