+++
tags = ["system", "kernel", "grub"]
zusammenfassung = "Konfiguration des Grub-Bootmanagers."
title = "Grub Bootmanager"
submenu = "false"
date = "2021-01-13T23:19:41+01:00"
type = "article"
+++


## Grub in der EFI-Systempartition installieren

Der Grub Bootloader 2 wird auf der EFI-Systempartition installiert. Diese Partition hat eine GUID-Partitionstabelle GPT. 
Festplatteninformation werden mit dem Befehl `lsblk` abgerufen.
Grub wird entsprechend auf dem Gerät `/dev/nvmeXXX` installiert. 

{{<code lang="fish">}}
 lsblk -o NAME,UUID,FSTYPE,SIZE,PTTYPE,PARTTYPENAME,MAJ:MIN,LABEL,MOUNTPOINT
 
 grub-install /dev/nvme0n1p1 --efi-directory=/boot/efi --target=x86_64-efi --recheck --debug
{{</code>}}

Sind unterschiedliche Linux-Distributionen auf einer Festplatte oder auf einem PC installiert, kann es vorkommen, dass sich ein Bootloader der entsprechenden
Distribution bei einem Update automatisch installiert. 
Um den Bootloader aus deiner vorrangig verwendeten Distribution zu verwenden, starte deine Distribution und reinstalliere Grub.
{{<code lang="fish">}}
 apt-get --reinstall install grub-common grub-efi-amd64 os-prober
{{</code>}}

## Schriftgr&ouml;&szlig;e im Bootmen&uuml; &auml;ndern

Auf heutigen Superrechnern mit ihren hochauflösenden Bildschirmen nervt letztendlich die kleine Schriftgröße. So auch im Bootmenu von `grub`.
Das kann geändert werden.

1. Grub Menufont erzeugen

>{{<code lang="fish">}}
 grub-mkfont --size 16 -o /boot/grub/fonts/<fontname>.pf2 /usr/share/fonts/../<fontname>.otb
{{</code>}}
   
2. Grub-Defaulteinstellungen ändern 
>{{<code lang="fish" title="Einstellungen in /etc/default/grub">}}
 # Schriftart Bootmenu einstellen
 GRUB_FONT="/boot/grub/fonts/<fontname>.pf2"
{{</code>}}

3. Config erstellen

>{{<code lang="fish">}}
 grub-mkconfig -o /boot/grub/grub.cfg
{{</code>}}


## Voreingestellten Kernel starten

In der Datei `/boot/grub/grubenv` ist der zu startende Standardkernel eingetragen.

{{<code lang="fish" title="Beispiel /boot/grub/grubenv">}}
 # Die Standardeinstellung startet den ersten eingetragenen Kernel 
 saved_entry=0

 # Startet den Kernel 5.4.0-59-generic aus dem Untermenu von Advanced (Beachte das Modifikationszeichen ">" = Untermenu)
 saved_entry=gnulinux-advanced-f59086ba-4f69-43ae-9bc5-c6be534f86e8>gnulinux-5.4.0-59-generic-advanced-f59086ba-4f69-43ae-9bc5-c6be534f86e8
{{</code>}}

Mit den folgenden Einstellungen in der Datei `/etc/default/grub` wird der im Bootmenu gewählte Kernel in die Datei `grubenv` eingetragen.

{{<code lang="fish" title="Einstellungen in /etc/default/grub">}}
 GRUB_DEFAULT=saved	# Der Bootmanager startet den in grubenv eingetragenen Kernel
 GRUB_SAVEDEFAULT=true	# mit dieser Option wird der im Bootmenu gewählte Kernel dauerhaft in der Datei /boot/grub/grubenv eingetragen
{{</code>}}

Danach `update-grub` ausführen.

Du kannst den Eintrag auch direkt aus der Datei `/boot/grub/grub.cfg` entnehmen. Ist aber sehr umständlich. 

{{<code lang="fish" title="Datei /boot/grub/grub.cfg">}}
 submenu 'Advanced options for Ubuntu' $menuentry_id_option 'gnulinux-advanced-f59086ba-4f69-43ae-9bc5-c6be534f86e8' {
         menuentry 'Ubuntu, with Linux 5.8.0-36-generic' --class ubuntu --class gnu-linux --class gnu --class os $menuentry_id_option 'gnulinux-5.8.0-36-generic-advanced-f59086ba-4f69-43ae-9bc5-c6be534f86e8' {
                recordfail
        savedefault
{{</code>}}


