+++
tags = ["ssh", "sftp", "Secure Shell"]
zusammenfassung = "SSH - Einrichtung und Anwendung."
title = "ssh - Secure Shell"
date = "2022-04-11T11:24:40+02:00"
type = "article"
+++

## Was ist SSH?

Mit Secure Shell [(ssh-wiki)][ssh-wiki] wird über ein lokales oder öffentliches Netzwerk auf ein PC zugegriffen. Der PC kann somit über einen entfernten Ort gewartet werden.


### Funktionsprinzip

Ein lokaler PC (Client) verbindet sich zu einem weit entfernten sog. Remote PC (Server) um Befehle auf dem Remote PC auszuführen. Durch dieses Prinzip kann der Remote PC aus der Ferne gewartet werden. Die Verbindung erfolgt verschlüsselt.

![](/images/ssh.png " #width=60%")

### IP-Adresse abfragen

Für eine Verbindung mit dem Remote PC (Server) wird dessen IP-Adresse benötigt.

{{<code lang="fish" title="IP-Adresse abfragen (lokal)">}}
 # Linux Bash
 ip -br address
 ip -br a
 ifconfig		

 # Windows CMD
 ipconfig	
 nslookup	 		# IP des lokalen PC
 nslookup  \\Netzlaufwerk	# IP des Netzlaufwerkes
 
{{</code>}}

Mit dem Programm [cURL][curl] kann die IP-Adresse von "außen" abgefragt werden.

{{<code lang="fish" title="IP-Adresse abfragen mit cURL">}}
 curl https://ifconfig.me
 curl https://ifconfig.co
 curl https://icanhazip.com
 curl https://ipecho.net/plain
 curl -w "n" -s https://api.ipify.org
{{</code>}}


Abfrage der öffentlichen IP-Adresse im Browser:
: https://www.wieistmeineip.de/
: https://www.dein-ip-check.de/
: https://www.heise.de/tools/

### Netzwerk-Scan

Für weitere Abfragen der IP-Adressen im lokalen Netz, wie z.B. des Routers, ist ein Netzwerkscanner sinnvoll.

{{<code lang="xorg" title="Netzwerkscan">}}
 ip    route
 ip    n
 arp  -n
 nmap -sP -oG - 192.168.188.0/24	# Eingrenzen auf Subnetz

 # als root ausführen
 arp-scan    -l	
 netdiscover				# beenden mit [Strg] + [C]
 netdiscover -r 192.168.188.0/24 	# Eingrenzen auf Subnetz 192.168.188.xxx
{{</code>}}

>__Hinweis:__ Auf den Seiten des [Elektronik-Kompendium][] werden [Netzwerktechniken][] sehr umfangreich erläutert.


### SSH Options

```fish{linenos=false}

 ssh -G host		# SSH-Konfiguration anzeigen

 ssh -Q help 		# Anzeigen aller möglichen Abfragen
 
 ssh -Q cipher		# Abfrage Support cipher
 ssh -Q cipher-auth
 ssh -Q mac
 ssh -Q kex
 ssh -Q key
 ssh -Q hostkeyalgorithms
 ssh -Q pubkeyacceptedkeytypes

 # oder mit nmap alle cipher-Methoden anzeigen
 nmap -p22 -n -sV --script ssh2-enum-algos localhost
   
```

## Aufbau einer lokalen SSH Verbindung und Test

Mit dem Programm `telnet` kann vom lokalen PC (Client) getestet werden, ob auf dem Remote PC ein SSH-Server aktiviert ist. Als Adresse ist die IP des Remote PC und der Port (meistens 22) einzugeben.


{{<code lang="fish" title="Client-PC">}}
 telnet 192.168.188.5 22
{{</code>}}   

{{<code lang="elixir" title="telnet - Verbindung erfolgreich">}}
 Trying 192.168.100.3...   
 Connected to 192.168.100.3.   
 Escape character is '^]'.   
 SSH-2.0-OpenSSH_3.8.1p1 Debian-8.sarge.4   
{{</code>}}


{{<code lang="elixir" title="telnet - nicht erfolgreich">}}
 telnet: Unable to connect to remote host: Connection refused
{{</code>}}

Der Abbruch erfolgt mit: <kbd>[Strg]+[C]</kbd>. Ist der Test nicht erfolgreich, dann ist vermutlich der SSH-Daemon (Server) auf dem Remote PC nicht gestartet oder nicht installiert oder wird durch eine Firewall blockiert. 
Auf Linuxsystem befindet sich ein SSH-Server, ein Client und alles weitere meist in den Paketen mit der Bezeichnung: `openssh`. 
Sind diese Pakete installiert, kann der SSH-Server gestartet werden.

{{<code lang="fish" title="Remote/Server-PC">}}
 systemctl start ssh
 
 # SSH-Server beim Bootvorgang starten 
 systemctl enable ssh
 
 # Check
 systemctl is-enabled ssh
 systemctl is-active  ssh
 systemctl status     ssh

{{</code>}}

Eine Verbindung zu einem Remote PC (Server) kann vom einem lokalen PC (Client) mit folgendem Befehl aufgebaut werden:

{{<code lang="fish" title="SSH Verbindung vom Client zum Server">}}
 ssh username@192.168.188.5
{{</code>}}

### Benutzerkonfiguration

Mit der Konfigurationsdatei `~/.ssh/config` besteht die Möglichkeit verschiedene SSH-Optionen zu speichern, die für eine Verbindung mit dem Remote-PC notwendig sind.
Insbesondere wenn die Verbindung mit vielen Optionen auf der Befehlszeile erfolgt, erleichtert eine benutzerdefinierte Konfigurationsdatei die Tastenanschläge.

{{<code lang="fish" title="Benutzerkonfigurationdatei: ~/.ssh/config">}}
 Host LinuxV5
        HostName xxx.xxx.xxx.xxx
        User ed
        Port 1234
        IdentityFile ~/.ssh/keyfile.priv
{{</code>}}

Mit dieser Konfigurationsdatei wird der Befehl: `ssh -i ~/.ssh/keyfile.priv -p 1234 ed@xxx.xxx.xxx.xxx` vereinfacht zu: `ssh LinuxV5`. Alternativ kann auch ein Alias definiert werden.
Der SSH-Client liest seine Optionen nach folgender Präzedenzanordnung:
: 1. Optionen von der Befehlszeile
: 2. Optionen aus der Benutzerkonfiguration `~/.ssh/config`
: 3. Systemweite Optionen aus `/etc/ssh/ssh_config`

Z.B. überschreibt der Aufruf `ssh -o "User=fred" LinuxV5` die entsprechende Option.

## SSH-Fingerprint

Ein Fingerprint ist eine Folge von Zahlen und Buchstaben, mit der die Echtheit durch einfaches manuelles Vergleichen überprüft werden kann.

Beim ersten Verbindungsaufbau wird ein Fingerprint des SSH-Servers auf der Clientmaschine ausgegeben. Die Ausgabe sieht z.B. so aus:

{{<code lang="elm" title="Client-PC">}}
 The authenticity of host '192.168.1.33 (192.168.1.33)' can't be established.
 RSA key fingerprint is 29:78:a1:2c:56:b8:88:d5:e7:cb:5d:dd:17:b9:bb:5b.
 Are you sure you want to continue connecting (yes/no)?
{{</code>}}

Nach dem Bestätigen mit <kbd>yes</kbd> wird der Fingerprint auf dem Client in der Datei `~/.ssh/known_hosts` gespeichert. 
Mit dem Fingerprint kann geprüft werden, ob tatsächlich der angesprochene Server auf der anderen Seite der Leitung ist. 
Den Fingerprint des SSH-Servers erfährt man auf dem Remote PC mit dem Systemprogramm `ssh-keygen`.

{{<code lang="fish" title="Remote/Server-PC">}}
 #RSA-Fingerprint             
 ssh-keygen -f /etc/ssh/ssh_host_rsa_key.pub   -l
 
 #ECDSA-Fingerprint
 ssh-keygen -f /etc/ssh/ssh_host_ecdsa_key.pub -l

 # weitere Optionen
 -E sha256	Ausgabeformat sha256 (default)
 -E md5		Ausgabeformat md5

 #Alle Server-Fingerprint's (Remote PC)
 for keyfile in /etc/ssh/*.pub; do ssh-keygen -l -f "${keyfile}"; done
  
 #Alle User-Fingerprint's (Host PC)
 for keyfile in ~/.ssh/id*.pub; do ssh-keygen -l -f "${keyfile}"; done
{{</code>}}

Wer auf sicher gehen möchte, lässt sich vom Administrator des Servers
die Ausgabe des Fingerprints mitgeben (evtl. ausdrucken) um eine manuelle Prüfung vor zunehmen.

## SSH einrichten f&uuml;r PublicKey Authentifizierung

Die allgemeine Vorgehensweise ist folgende:
1. Erstellen eines Schlüsselpaar (privater und öffentlicher Schlüssel) auf dem lokalen PC (Client).
2. Kopieren bzw. anhängen des öffentlichen Schlüssel in die Datei `~./.ssh/authorized_key` des Nutzers auf dem Remote PC (SSH-Server).
3. Anschalten der Public Key Authentifizierung auf dem Remote PC (SSH-Server) in der Datei `/etc/ssh/sshd_config`.
4. Nach einem erfolgreichen Test kann die Authentifizierungsmethode mit SSH-Passwort abgeschaltet werden. 

Um in einem lokalen Netzwerk von einem Client (PC1) auf einem Rechner (PC2 mit SSH-Server) ohne Passworteingaben zu zugreifen,
 kann ein Schlüsselpaar auf dem Client erzeugt werden.
        
{{<code lang="fish" title="Client-PC">}}
 # RSA Schlüsselpaar erzeugen (Standard)
 ssh-keygen -t rsa			

 # ED25519 Schlüsselpaar ist besser
 ssh-keygen -t ed25519 -a420 -f ~/.ssh/id_25519_Name
 ssh-keygen -t ed25519 -a100 -N "" -f ~/.ssh/keyfile_Name -C "Comment"

 # Öffentl. Schlüssel vom Client zum Remote-PC kopieren, und anhängen an ~/.ssh/authorized_key
 ssh-copy-id -i ~/.ssh/keyfile_Name username@192.168.188.5

 # Einloggen mit keyfile
 ssh -i .ssh/keyfile_Name username@192.168.188.5
{{</code>}}


{{<viewcsv url="static/csv/Optionen-ssh-keygen.csv" sep=":" caption="ssh-keygen" >}}

Im Verzeichnis `~/.ssh` des lokalen PC (Client) werden zwei Dateien angelegt. Eine Datei mit dem privaten Schlüssel und eine Datei mit dem öffentlichen Schlüssel `*.pub`. 
Der öffentliche Schlüssel des lokalen PC (Client) muss auf dem Remote PC (SSH-Server) an die Datei `~/.ssh/authorized_keys` angehängt werden.

Auf dem Remote PC (SSH-Server) sind in der Serverkonfigurationsdatei: `/etc/ssh/sshd_config` für die PublicKey Authentifizierung mindestens folgende Einstellungen vorzunehmen: 
: __PubkeyAuthentication&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;yes__
: __PasswordAuthentication&nbsp;&nbsp;no__
 
Im Prinzip erfolgt eine Verbindung mit PublicKey Authentifizierung so, dass der Server mit dem öffentlichen Schlüssel des Client einen Datenblock generiert und dem Client sendet.
Der Client entschlüsselt den Datenblock mit seinem privaten Schlüssel und teilt dem Server das Ergebnis mit. Damit ist der Client gegenüber dem Server identifiziert.


### Passphrase

Erfolgt der Zugriff über ein öffentliches Netzwerk (Internet), dann sollte der öffentliche Schlüssel noch mit einer __Passphrase__ abgesichert werden. 
Denn wenn jemand den öffentlichen Schlüssel zufällig erhält, hat er kein Zugriff ohne Passphrase.
   
Mit dem Befehl `ssh-keygen -y -P "" -f keyfile.priv` kann abgefragt werden, ob eine Passphrase vorliegt oder nicht. Wird der öffentliche Schlüssel ausgegeben, 
dann existiert keine Passphrase (Option: -P ""). Eine Ausgabe mit: `incorrect passphrase ...` zeigt an, dass eine Passphrase vorhanden ist. 


### SSH-Agent

Beim ersten Login wird die Passphrase abgefragt. Eine weitere Eingabe der Passphrase erübrigt sich durch die Nutzung des Authentifizierungsvermittlers `ssh-agent`. 
Für Tests können die aktuell hinterlegten Identitäten durch den Befehl `ssh-add -D` gelöscht werden. Entsprechend wird weiterhin die Passphrase verlangt.
Um zu überprüfen ob ein SSH-Agent auf dem System existiert, stehen folgende Mittel zur Verfügung:


```fish{linenos=false}

 echo $SSH_AUTH_SOCK	  # Umgebungsvariable existiert
 ssh-add -l		  # Liste alle bekannten Fingerabdrücke auf
 ps -ef | grep ssh-agent  # Prozess ist vorhanden
   
```

## Kopieren mit scp

Mit `scp` (Secure File Copy) können Dateien und ganze Verzeichnis kopiert werden.

{{<code lang="fish" title="Kopieren mi scp">}}
 scp Dateiname      username@192.168.188.5:./Unterverzeichnis   
 scp Verzeichnis -r username@192.168.188.5:./Unterverzeichnis

 # Beispiel mit PublicKey Authentifizierungsdatei und Port 5555
 scp  -i ~/.ssh/keyfile.priv -P 5555  Dateiname username@192.168.188.5:./Unterverzeichnis

{{</code>}}

## SSH-Verbindung aus einem &ouml;ffentlichen Netz (Internet)

Für eine Verbindung zu einem entfernten PC (Server, Remote) aus dem Internet müssen drei Bedingungen erfüllt sein.
1. Der SSH-Daemon (Server) muss am Remote-PC gestartet sein.
2. Auf dem Router muss der Port 22 (oder ein anderer Port) freigegeben werden. Im Weiteren muss der Port an den Remote-PC (SSH-Server) weitergeleitet werden.
3. Die öffentliche IP-Adresse muss bekannt sein.
4. Um die Sicherheit zu erhöhen sollte unbedingt die PublicKey Authentifizierung mittels Passphrase eingerichtet werden.

## SSH absichern

In der Datei `/etc/ssh/sshd_config` werden Einstellungen zum SSH-Server vorgenommen.

### Root-Login unterbinden

Um Root-Login auf dem SSH-Server zu unterbinden, muss in der Datei `/etc/ssh/sshd_config` der Schalter __PermitRootLogin__ auf __no__ gesetzt werden.
Außerdem ist ein neuer Benutzer anzulegen.

```fish{linenos=false}

 # User "ed" anlegen und der Gruppe sudo zuweisen
 useradd -m -s /bin/bash ed
 usermod -aG sudo ed
 passwd  ed

 # PermitRootLogin in Datei /etc/ssh/sshd_config
 sed -ri -e 's/\ *PermitRootLogin\ *yes/PermitRootLogin no/' -e 's/#\ *PermitRootLogin no/PermitRootLogin no/' /etc/ssh/sshd_config

 # SSh-Server neustart
 systemctl restart ssh 
   
```

### Authentifizierungen abschalten

Nicht benötigte Authentifizierungsmethoden abschalten.    
: __HostbasedAuthentication&nbsp;no__
: __KerberosAuthentication&nbsp;no__


```fish{linenos=false}

 sed -ri -e 's/\ *HostbasedAuthentication\ *yes/HostbasedAuthentication no/' -e 's/#\ *HostbasedAuthentication no/HostbasedAuthentication no/' /etc/ssh/sshd_config
 sed -ri -e 's/\ *KerberosAuthentication\ *yes/KerberosAuthentication no/' -e 's/#\ *KerberosAuthentication no/KerberosAuthentication no/' /etc/ssh/sshd_config
   
```

### Bestimmte Benutzer erlauben oder blockieren

Die Optionen `AllowUsers` und `DenyUsers` gestattet es Benutzer die Anmeldung zu erlauben oder zu blockieren. Ist keine dieser Optionen vorhanden, dann können sich erstmal alle anmelden.

```fish{linenos=false}
 
 AllowUsers UserName1 UserName2
 DenyUsers  UserName4 UserName5
   
```

### SSH abhärten

Lies mal diesen interessanten [Artikel][ssh-absichern-modern] zum absichern von OpenSSH in Ubuntu Jammy 22.04.


In der Datei `/etc/hosts.deny` kann durch die Zeile `sshd: ALL EXCEPT LOCAL` alle Anfragen von außen blockiert werden. 
Um einzelnen IP-Adressen den Zugang zu erlauben wird in der Datei `/etc/hosts.allow` die IP eingetragen. Z.B. `sshd: XX.YYY.XXX.ZZZ` oder `sshd: xx.xx.xxx.*`. 

## Fehlermeldungen, Probleme




### SSH-Verbindung ist gescheitert wg. Firewall

__Problem:__
: Die SSH-Verbindung kommt nicht zustande und endet mit der Meldung:
>{{<code lang="elixir">}}
 ssh: connect to host 192.168.188.8 port 22: Connection refused
{{</code>}}

__Erläuterung:__
: Ein möglicher Grund für eine erfolglose Verbindung zu einem SSH-Server kann eine Firewall auf dem Remote-PC (SSH-Server) sein.

__Lösung:__
: [UFW-Firewall][firewall.md] prüfen und ggf. einrichten.

### Signatur nicht korrekt

__Problem:__
: Nach dem Einlogen zu einem SSH-Server erscheint folgende Meldung:

>{{<code lang="bash">}}
 client_global_hostkeys_private_confirm: server gave bad signature for ECDSA key 1: incorrect signature
{{</code>}}

### Fingerprint 

__Problem:__
: Bei einem Verbindungsaufbau zu einem Server stimmt der Fingerprint nicht überein und es erscheint folgende Meldung:

>{{<code lang="bash">}}
 @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
 @    WARNING: REMOTE HOST IDENTIFICATION HAS CHANGED!     @
 @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
 IT IS POSSIBLE THAT SOMEONE IS DOING SOMETHING NASTY!
{{</code>}}

__Erläuterung:__
: Der Fingerprint des Server-PC (Remote, SSH-Server) in der Datei `/etc/ssh/*.pub` stimmt nicht mit dem Fingerprint des Client-PC in der Datei `~/.ssh/known_hosts` überein,
weil z.B. ein neues System auf dem Server aufgesetzt wurde.

__Lösung:__
: Die Zeile mit der Server-Adresse xx.xxx.xxx.xxx. in der Datei `~/.ssh/known_hosts` entfernen/löschen. 
>{{<code lang="fish">}}
 # Suche nach der Server-Adresse in der Datei know_host
 ssh-keygen -F 192.168.100.3

 # Entfernt die Server-Adresse aus der Datei know_host
 ssh-keygen -R 192.168.100.3
{{</code>}}

### Zugriffsrechte

__Problem:__
: Gelegentlich taucht folgende Meldung bei einer Datei mit öffentlichem Schlüssel auf (z.B. bei diesem Befehl: `ssh-keygen -y -f keyfile.pub`).

>{{<code lang="bash">}}
 @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
 @         WARNING: UNPROTECTED PRIVATE KEY FILE!          @
 @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
 Permissions ...  are too open. 
{{</code>}}

__Erläuterung:__
: Die Zugriffsrechte der Datei sind nicht optimal gesetzt.

__Lösung:__
: Zugriffrechte ändern.

>{{<code lang="fish">}}
 chmod 0600 keyfile.pub
 # oder
 chmod a-wrx,u+wr keyfile.pub
 # oder für alles unter ~/.ssh
 chmod -R go= ~/.ssh
{{</code>}}

## Weblinks

[ssh-wiki-cff][]   
[ssh-wiki][]   
[ssh-wiki-ubuntu][]   
[ssh-absichern][]   
[ssh-absichern-modern][]   
[Elektronik-Kompendium][]   
[Netzwerktechniken][]



[ssh-wiki-cff]:		http://ccf-it.de/tiki-5.0/tiki-index.php?page=SSH
[ssh-wiki]:		https://de.wikipedia.org/wiki/Secure_Shell
[ssh-wiki-ubuntu]:	https://wiki.ubuntuusers.de/SSH/
[ssh-absichern]:	https://www.rz.uni-wuerzburg.de/dienste/it-sicherheit/sshlinux/absichern-des-zugangs/
[ssh-absichern-modern]: https://sakis.tech/openssh-server-abhaerten-und-absichern-unter-linux/

[Elektronik-Kompendium]:https://www.elektronik-kompendium.de
[Netzwerktechniken]:	https://www.elektronik-kompendium.de/sites/net
[firewall.md]:		{{< relref "/edv/system/firewall" >}}
[curl]:			https://wiki.ubuntuusers.de/cURL/
