+++
tags = ["vnc", "vino", "ssh", "server", "gnome", "remmina"]
zusammenfassung = "Gnome's VNC Server Vino"
title = "VNC"
date = "2023-02-04T22:58:30+01:00"
type = "article"
+++

Das Virtual Network Computing [(VNC)][vnc] erlaubt es einen entfernten Rechner (Server) auf einem lokalen Rechner (Client) anzuzeigen und ggf. zu steuern.
Im Gegensatz zu anderer Fernwartungssoftware ist VNC plattformunabhängig.

### Befehlsübersicht


{{<code lang="fish">}}
 netstat -tulpen | grep -i vino		# Prüfe ob Vino gestartet ist
 pgrep   -a vino			# Prüfe mit ps
 netstat -nl     | grep -i 590		# Prüfe Port 590x 
 ip addr				# Lokale IP-Adresse ermitteln
 ifconfig				# Lokale IP-Adresse ermitteln
 
 systemctl start   vino-server --user	# VNC-Server starten als user
 /usr/lib/vino/vino-server --sm-disable	# VNC starten als root

 systemctl status  vino-server --user	# Status prüfen
 systemctl restart vino-server --user	# VNC-Server restart
 systemctl stop    vino-server --user	# VNC-Server stop
{{</code>}}





### Vino-Server

Vino wird mit dem gleichnamigen Packet installiert.
Optionen bzw. Einstellungen für den Vino-Server werden unter Gnome mit einem der folgenden Programme vorgenommen:

```fish{linenos=false}

 gsettings       (console)
 dconf           (console)
 dconf-editor    (gui)
   
```



##### Server-Optionen


Optionen auf der Konsole ausgegeben:

```fish{linenos=false}

 for i in $(gsettings list-keys org.gnome.Vino); do echo -e "$i:$(gsettings get org.gnome.Vino $i)" | awk -F ":" ' {printf "%30s   \t", $1; printf "%s \n", $2}' ; done
   
```

Für den Server stehen folgende Optionen bzw. Einstellungen zur Verfügung:

{{<mytable class="captleft greyhead striped small smallfont fontcourier">}}
| Option | Standardwert | Beschreibung |
|:---|:---:|:---|
| alternative&zwj;-&zwj;port | 5900 | |
| authentication&zwj;-&zwj;methods | ['vnc'] |
| disable-&zwj;background | true | Hintergrundbild abschalten. |
| disable&zwj;-&zwj;xdamage | false | XDamage - Erweiterung von Xorg abschalten bei Problemen mit Videotreiber.
| icon-visibility  | 'client' |
| lock&zwj;-&zwj;screen&zwj;-&zwj;on&zwj;-&zwj;disconnect | false |
| mailto | '' |
| network-interface | '' |
| notify-on-connect | true | Eine Meldung wird auf dem Desktop des Server angezeigt. |
| prompt&zwj;-&zwj;enabled | true | Der Benutzer muß die Verbindung zum Client mit einem Mausklick annehmen. |
| require-&zwj;encryption | true| Verschlüsselung an/abschalten. Für Testzwecke auf __false__ setzen und bei Benutzung des VNC-Client __xtightvncviewer__. Bei der Nutzung von __remmina__ auf __true__ setzen. |
| use-alternative-port | false |
| use-upnp | false |
| view-only| false |
| vnc-password | 'keyring' |

{{</mytable>}}



##### Einstellungen vornehmen mit dconf-editor (Gui) 

Die Einstellungen im `dconf-editor` sind unter folgendem Zweig zu finden: {{<menu "org/gnome/desktop/remote-access" >}}.
Sollte dieser Zweig nicht vorhanden sein, dann ist das Packet `vino` zu installieren.



##### Einstellungen mit gsettings (Konsole)


```fish{linenos=false}

 # Bildschirmfreigabe aktivieren ab Ubuntu Jammy 22.04
 gsettings set  org.gnome.desktop.remote-desktop.rdp enable true

 # Listet alle Schlüssel auf
 gsettings	list-keys	org.gnome.Vino

 # Schlüssel ändern
 gsettings set org.gnome.Vino authentication-methods "['vnc']"
   
```


### Bildschirmfreigabe in Ubuntu

{{<columns>}} 
Unter Umständen muss in Ubuntu die Bildschirmfreigabe aktiviert werden {{<menu "Einstellungen/Freigabe/Bildschirmfreigabe" >}}.
Aber, das ist abhängig welche Ubuntu Version installiert wurde. Bei älteren Ubuntuversion ist auch das Programm "Arbeitsflächenfreigabe", bzw. "Desktop sharing" zu installieren.
<--->
![Alternativer Text](/edv/system/Bildschirmfreigabe.jpg " {frame}  #width=90%")
{{</columns>}} 

#### Freigabe unter Ubuntu Focal 20.04


{{<columns>}} 
Unter der Bildschirmfreigabe kann ein VNC-Passwort gesetzt werden. Die Passwortlänge ist in _Ubuntu Focal 20.04_ auf maximal 8 Zeichen begrenzt. Im Prinzip reicht es jedoch den VNC-Server zu starten. 
```fish{linenos=false}

 # VNC-Server starten als user
 systemctl start   vino-server --user
   
```

Ein gesetztes VNC-Passwort wird in den Gnome-Desktop-Optionen des VNC-Server angezeigt.

```fish{linenos=false}

 gsettings get org.gnome.Vino authentication-methods
 ['vnc']
   
```

<--->
![Alternativer Text](/edv/system/Bildschirmfreigabe-Ubuntu-2004.jpg " {frame}  #width=90%")
{{</columns>}}

#### Freigabe unter Ubuntu Jammy 22.04

{{<columns>}} 
In _Ubuntu Jammy 22.04_ kann die Bildschirmfreigabe auf der Konsole erfolgen:  

```fish{linenos=false}

 gsettings set  org.gnome.desktop.remote-desktop.rdp enable true
   
```

Die Begrenzung der Passwortlänge auf 8 Zeichen wurde aufgegeben.

<--->

![Alternativer Text](/edv/system/Bildschirmfreigabe-Ubuntu-2204.jpg " {frame}  #width=90%")

{{</columns>}}


### VNC-Clients

Ein VNC-Client ist ein Programm, das es gestattet,  auf einem PC mit installiertem VNC-Server zuzugreifen bzw. dessen Inhalt anzuzeigen.
Es existiert eine Vielzahl an freien VNC-Clients z.B. _xtightvncviewer_ oder _Remmina_.

#### xtightvncviewer

```fish{linenos=false}

 xtightvncviewer -via <USER-Name>@<IP-Address> -depth 8 -bgr233 -compresslevel 5 -quality 0 localhost:0
   
```


Die Option `-via` baut eine Verbindung mit SSH-Tunnel auf. Entsprechend ist das SSH-Passwort einzugeben. 
Ein gesetztes VNC-Passwort zur Bildschirmfreigabe (`authentication-methods = ['vnc']`) ist ebenfalls einzugeben.
Mit der Umgebungsvariable `VNC_VIA_CMD` können weitere SSH-Optionen übergeben werden.
 
```fish{linenos=false}

 export VNC_VIA_CMD="/usr/bin/ssh -f -v -L %L:%H:%R %G sleep 20"
   
```

#### VNC mit Remmina

Benötigt werden die IP-Adresse, der Benutzername sowie der Legitimierungstyp [(SSH-Agent).][ssh-agent] 
Ist auf dem VNC-Server die Option `prompt-enabled` auf _TRUE_ gesetzt, dann erscheint eine Bildschirmnachricht auf dem VNC-Server und der Benutzer muss die Anmeldung mit einem Mausklick bestätigen.

{{<columns>}}

![Alternativer Text](/edv/system/remmina-vnc-1.png "Grundlegende Einstellungen {frame}  #width=90%")

<--->

![Alternativer Text](/edv/system/remmina-vnc-2.png "SSH-Tunnel {frame}  #width=90%")

{{</columns>}}


### VNC mit SSH tunneln

Konsole 1: ssh -v -L 5900:localhost:5900 name@192.168.1.33
Konsole 2: xvnc4viewer localhost:0

oder nimm dieses Programm. Damit kannste gleich die Farbtiefe einstellen (geht gut)

xtightvncviewer -via name@xxx.xxx.xxx.xxx -depth 8 localhost:0




[ssh-agent]: 	{{< relref "ssh#ssh-agent" >}}
[vnc]:		https://de.wikipedia.org/wiki/Virtual_Network_Computing
