+++
tags = ["windows", "word", "Makro", "Menuband"]
zusammenfassung = "Das Microsoft Office Programm zur Textverarbeitung."
title = "Word"
date = "2023-06-06T16:12:53+02:00"
type = "article"
+++

## OfficeIntegration {class=counter}

{{<columns>}}
Beim Start von Word erscheint ein Anmeldeformular mit der Aufforderung zur Eingabe von Logindaten. Das Anmeldeformular stammt aus der Datei `adxloader.dll`. Wenn die in der DLL hinterlegten Makros nicht notwendig sind, kann die _OfficeIntegration_ abgeschaltet werden im {{<menu "Entwicklertools/Gruppe: Add-Ins/COM Add-Ins" "Word-Menuband:">}}
<--->
![](/edv/windows/Word-Login.jpg " {frame} #width=75%" )
{{</columns>}}

## Eigenes Menuband in Word {class=counter}

Microsoft nutzt für seine Worddokumente das XML-Format. Öffne ein neues Worddokument und speicher es als `Dok1.docm`. Um die Struktur eines Worddokuments anzuzeigen, ist es notwendig, die Worddatei in eine ZIP-Datei mit der Erweiterung `*.zip` umzubenennen also `Dok1.docm.zip`. Die ZIP-Datei wird geöffnet und es erscheint folgende vereinfacht dargestellte Verzeichnisstruktur:

```Caddyfile {linenos=false}
   
 Dok1.docm.zip/
    ├── _rels
    │      └── .rels
    ├── docProps
    │      └── // und weiter Dateien
    ├── word
    │      └── // und weitere Dateien
    └── [Conten_Types]
   
```

Um ein eigenes Menuband zu realisieren, muss die Datei `.\customUI\customUI.xml` angelegt werden.

{{<code lang="xml" file="/content/edv/windows/customUI.xml" options="linenos=false" title="Datei: ./customUI/customUI.xml">}}

{{</code>}}

Im Weiteren muss die Datei `.\_rels\.rels` verändert werden. Dazu wird innerhalb des XML-Elements `<Relationships> ... </Relationships>` folgende Zeile eingefügt:


{{<code lang="xml" options="hl_lines=5,linenos=false" title="Datei: ./_rels/.rels">}}
 <Relationships>
	<Relationship ... />
	<Relationship ... />
 	<Relationship Id="rId4" Type="http://schemas.microsoft.com/office/2006/relationships/ui/extensibility" Target="customUI/customUI.xml" />
 </Relationships>
{{</code>}}

Ist das erledigt, kann die Zip-Datei geschlossen und wieder umbenannt werden in `Dok1.docm`.

### Schalter belegen {class=counter}

{{<columns>}}
Nun werden die im Menuband _MyMenu_ hinterlegten Schalter mit Funktionen belegt. Öffne die Worddatei und den darin enthaltenen _Visual Basic Editor_ im {{<menu "Entwicklertools/Gruppe: Code/Visual Basic" "Word-Menuband:">}}. Die Makros werden im Objekt _ThisDocument_ abgelegt. Das Objekt ist ein spezielles Klassenmodul für das aktuelle Worddokument.
Folgender beispielhafter Makrocode kann hinterlegt werden.

<--->

![](/edv/windows/Makroprojektexplorer.jpg "Projektexplorer {frame} #width=75%" )

{{</columns>}}


{{<code lang="VB.net" title="Makrocode">}}
 Private Const VERSION = "20201031"

 Sub MyMakro01(ByVal control As IRibbonControl)
    MsgBox _
        "Beschreibung: " & vbNewLine & _
        "Makro 01 erfolgreich gestartet." & vbNewLine & vbNewLine & _
        "Version:" & vbTab & VERSION & vbNewLine & vbNewLine & _
        "  ", _
        vbOKOnly + vbInformation, "Info"
 End Sub

 Sub MyMakro02(ByVal control As IRibbonControl)
    MsgBox "Uff... geschaft.", vbOKOnly + vbInformation, "Info"
 End Sub
{{</code>}}

### Fast fertig{class=counter}

Das Ganze wird als _Word Vorlage mit Makros (*.dotm)_ unter dem Namen `Dok1.dotm` gespeichert und Word beendet. Die nun vorhandene Datei `Dok1.dotm` mit dem Menuband _MyMenu_ kann für alle Worddokumente zur Verfügung gestellt werden, indem es als Vorlagedatei in das _STARTUP_ Verzeichnis: `C:\Users\<Benutzername>\AppData\Roaming\Microsoft\Word\STARTUP\` abgelegt wird. Gelegentlich kann es sein, dass das _STARTUP_ Verzeichnis ein anderes ist. Das _STARTUP_ Verzeichnis kann geändert werden in den {{<menu "Erweitert/Allgemein/Dateispeicherorte/Autostart" "Word-Optionen:">}}.



## Hilfsprogramm

Ein relative einfaches (standalone) Programm zum erstellen eines eigenen Menubandes ist der [Office RibbonX Editor.][RibbonXEditor]


## Weitere Links

... schau mal hier
: [Ribbons][]
: [Windows Symbole/Icons für Ribbons][Icons1]
: [XML Markup-Spezifikation für Ribbons][customUI]


[Ribbons]:	https://www.accessribbon.de/
[Icons1]:	https://bert-toolkit.com/imagemso-list.html
[customUI]:	https://learn.microsoft.com/en-us/openspecs/office_standards/ms-customui


[RibbonXEditor]:	https://github.com/fernandreu/office-ribbonx-editor



