+++
tags = ["gis", "gaa", "aks"]
zusammenfassung = "und der benötigten Software - PostgreSQL und PostGIS."
title = "Installation AKS"
date = "2023-03-29T11:15:40+02:00"
type = "article"
[zoom]
	1 = "45"
	2 = "70"
+++


Der Betrieb der Kaufpreissammlung AKS-Niedersachsen umfaßt die folgenden Komponenten:
* PostgreSQL - ein Datenbankmanager
* PostGIS - eine Erweiterung für PostgreSQL zur Speicherung und Verwaltung von Geodaten
* AKS-Niedersachsen


### PostgreSQL {class=counter2}

[PostgreSQL][postgresql.org][^1] ist ein freies, objektrelationales Datenbankmanagementsystem. Für Windows werden Installationsroutine bei [EDB zum Download][postgresql_download][^5] angeboten. 

Lade dir die Installation z.B. die [Version-15.5.1][postgresql_V1551_windows][^9] (oder [Version-15.3.3][postgresql_V1533_windows][^2]) für Windows herunter. Starte die Installationsroutine als Administrator. 
Vergebe ein Paßwort - einfach _postgres_.
Entferne bei der Auswahl der Komponenten den Haken bei _Stack Builder_ und _pgAdmin 4_. 
Mit dem _Stack Builder_ wird das dazugehörige PostGIS über die Installationsroutine aus dem Internet nachgeladen und gleichzeitig installiert.
Dieser Vorgang erübrigt sich, wenn PostGIS, wie in diesem Tutorial beschrieben, von "Hand" nachinstalliert wird. Die automatisierte Installation von PostGIS über den _Stack Builder_ kann zu Fehlermeldungen führen. Hintergrund ist die weiter unten genannte Datei `pg_hba.conf`.

![](/gaa/aks/01-Postgres-install.jpg "#width={{<param zoom.1>}}% {frame}" )

#### pgAdmin4 {class=counter2}

Das Administrationstool `pgadmin4` ist ein Frontend mit graphischem Benutzerinterface für PostgreSQL Datenbanken. 
Im Prinzip ist es im Installationspacket von PostgreSQL dabei. Eine aktuellere Version bietet die Projektseite von [pgAmin4][pgadmin4][^8].
Nach der Installation wird das Programm mit `pgAdmin4.exe` gestartet.


#### Dienst starten {class=counter2}

Bei PostgreSQL handelt es sich um eine Server-Client-Datenbank. Das heißt, die Datenbank liegt auf einem PC (Server) und andere PC's (Client's) können auf diese Datenbank zugreifen. Um abfragen der Client's an den Server zu erhalten, muss ein sog. Dienst gestartet werden. 
Beim Einrichten von PostgreSQL und insbesondere beim Start des Management-Tool `pgAdmin4.exe` wird automatisch der entsprechende Dienst gestartet. 
Sollte das nicht erfolgt sein, dann kann der Dienst von "Hand" gestartet werden. 
   
In Windows werden Dienste durch das Programm `services.msc` verwaltet. Nach dem Start des Programms mit Administratorrechten wird in der Spalte _Name_ der Dienst _postgresql-x64-15_ selektiert und gestartet. Der _Starttyp_ sollte auf _Automatisch_ gestellt werden.

![](/gaa/aks/dienst-starten.jpg "Dienst starten: postgresql-x64-15 #width={{<param zoom.1>}}% {frame}" ) 

Um den Dienst auf der Kommandokonsole von Windows zu prüfen, zu starten und zu stopen, mach folgendes:

{{<code lang="fish" title="cmd.exe">}}
 # 1. Vollständigen Dienstnamen ermitteln 
 sc query state=all | find "postgre"
 
 # 2. Informationen des Dienstes ausgeben (vollständiger Name erforderlich)
 sc query   postgresql-x64-15
 sc queryex postgresql-x64-15
 
 # 3. Status checken
 sc query   postgresql-x64-15 | find /I "state"

 # 4. Stop, Start nur als Administrator
 sc stop    postgresql-x64-15
 sc start   postgresql-x64-15
{{</code>}}


### PostGIS {class=counter2}

[PostGIS][postgis.net][^4] ist eine räumliche Datenbankerweiterung und baut auf PostgreSQL auf. 
Für das installierte PostgreSQL in der Version 15 muss auch die entsprechende PostGIS Version installiert werden.
Der [Direktlink][postgis.osgeo.download][^3] führt zum Download der entsprechenden PostGIS Version. 


#### Vorbereitung der Installation {class=counter2}

Vor der Installation von PostGIS muss die Datei `pg_hba.conf` geändert werden. 
Die Datei befindet sich im Installationsverzeichnis von PostgreSQL in: `c:\Program Files\PostgreSQL\<Versionsnummer>\data`. 
Die Zeilen unterhalb von `# IPv4 local connections:` wird vom Wert `scram-sha-256` auf den Wert `trust` geändert. 
Hintergrund ist, dass AKS über die lokale IP4-Adresse (127.0.0.1/32) eine Verbindung zur PostGIS Datenbank aufbaut und der lokalen IP an sich vertraut werden kann.


{{<code lang="apl" file="/gaa/aks/pg_hba.conf" title="File: pg_hba.conf">}}
{{</code>}}
   
Nach den Änderungen kann die Installation von PostGIS mit Administratorrechten erfolgen.
Als Komponente sollte _Create spatial database_ gewählt werden und als Paßwort ist das bei der Installation von PostgreSQL eingerichtete _postgres_ einzugeben.

{{<columns class="left">}}
![](/gaa/aks/02-Postgis-install.jpg "#width={{<param zoom.2>}}% {frame}" ) 
<--->
![](/gaa/aks/03-Postgis-install.jpg "#width={{<param zoom.2>}}% {frame}" ) 
{{</columns>}}

Alle darauf folgenden Meldungen und Informationen können mit "ja" oder "ok" bestätigt werden.


### Database einrichten {class=counter2}

Sind PostgreSQL und PostGIS installiert, kann die Datenbank eingerichtet werden. 
Dazu wird das Administrationstool von PostgreSQL in `pgAdmin4.exe` gestartet.
Beim Start wird nach dem zuvor vergebenen Paßwort _postgres_ gefragt.

![](/gaa/aks/pgadmin-00.jpg "Admin-Tool - Paßwort: postgres #width={{<param zoom.1>}}% {frame}" ) 

#### Verbindung fehlgeschlagen {class=counter2}

Nach der Eingabe des Paßwortes kann die Verbindung aus unterschiedlichsten Gründen fehlschlagen. 

{{<columns class="left">}}
Liegt ein Authentifizierungsproblem vor, dann könnte das Problem an der Datei `pg_hba.conf` liegen (siehe oben).
![](/gaa/aks/pgadmin-error-01.jpg "Authentifizierungsfehler #width={{<param zoom.2>}}% {frame}" ) 
<--->
Bei einem Timeout-Fehler ist vermutlich der PostgreSQL-Dienst im System nicht gestartet.
![](/gaa/aks/pgadmin-error-02.jpg "Timeoutfehler #width={{<param zoom.2>}}% {frame}" ) 
{{</columns>}}

#### Benutzer anlegen {class=counter2}
   
Im Administrationtool von PostgreSQL `pgAdmin4.exe` wird als erstes ein neuer Benutzer _aksuser_ angelegt. 
Mit der linken Maustaste wird der entsprechende Zweig {{<menu "Servers/PostgreSQL/Login Group Role..." "Object Explorer:">}} selektiert und mit
der rechten Maustaste öffnet sich das Untermenu {{<menu "Create/Login Group Role...">}}.

{{<columns>}}
![](/gaa/aks/pgadmin-01.jpg "#width={{<param zoom.2>}}% {frame}" ) 
<--->
![](/gaa/aks/pgadmin-02.jpg "#width={{<param zoom.2>}}% {frame}" ) 
{{</columns>}}

__Wichtig:__ Der Benutzer muß alle Berechtigungen bekommen {{<menu "Privileges" "Reiter:">}}.

![](/gaa/aks/pgadmin-06.jpg "#width={{<param zoom.1>}}% {frame}" ) 

#### Datenbank anlegen {class=counter2}

Als nächstes wird die Datenbank _akstest_ im Zweig {{<menu "Server/PostgreSQL/Database" "Object Explorer:">}} angelegt. 

{{<columns>}}
![](/gaa/aks/pgadmin-03.jpg "1. Create Database... #width={{<param zoom.2>}}% {frame}" ) 
<--->
![](/gaa/aks/pgadmin-04.jpg "2. Name der Datenbank - akstest #width={{<param zoom.2>}}% {frame}" ) 
<--->

![](/gaa/aks/pgadmin-05.jpg "3. Template: postgis_33_sample #width={{<param zoom.2>}}% {frame}" ) 
__Wichtig:__ Das Template _postgis_33_sample_ im {{<menu "Definition" "Reiter:">}} zu wählen.

{{</columns>}}

### Installation AKS {class=counter2}

Packe die vom Hersteller aktuell zur Verfügung gestellte Version des Programm (Zip-Datei) in einem Verzeichnis aus. Dazu wird ein Paßwort benötigt, das ebenfalls vom Hersteller zu erfahren ist. Nach dem auspacken stehen zwei Dateien bereit. Eine weitere Zip-Datei `aks<Version>nb.zip` und eine Installationsdatei `aks<Version>XXX_install.exe`.
Starte die Installationsdatei als Administrator. Soweit keine Fehlermeldungen auftauchen, können alle weiteren Meldungen mit OK oder Weiter bestätigt werden.

#### Fehlende Dateien kopieren {class=counter2}

Bevor die AKS-Datenbank angelegt werden kann, sind ein paar fehlende SQL-Dateien in das Verzeichnis `C:\Program Files (x86)\AKS\sqls` zu kopieren. Diese Dateien sind:
: `wallgem_pxr.sql`
: `wplzgeo.sql`
: `wsubkre.sql`

Die Dateien sind vom Hersteller zu beziehen oder von hier: [aks-fehlende-sqls.zip](/download/aks-fehlende-sqls.zip)[^7] ( [md5](/download/aks-fehlende-sqls.md5))


#### AKS-Datenbank Verbindung herstellen {class=counter2}

__WICHTIG:__ Nach eigener Erfahrung bitte __nicht__ als erstes die Datei `aks.exe` starten, sondern die Datei `dbeinrichten.exe` im Installationsverzeichnis von AKS `C:\Program Files (x86)\AKS`.

Mit dem Programm `dbeinrichten.exe` wird eine Verbindung zu einer existierenden PostgreSQL Datenbank hergestellt, eine neue Datenbank für AKS vorbereitet und mit Standardwerten aus PostGIS gefüllt. 
Der Start des Programms `dbeinrichten.exe` ist abhängig von der Existenz der Datei `aksniwis.properties`. 

{{<columns>}}
a) Die Datei `aksniwis.properties` existiert __nicht__. Es öffnet sich das Fenster zur _Anmeldung an das Datenbanksystem_.

![](/gaa/aks/db-einrichten-01.jpg "{frame}" )

<--->

b) Die Datei `aksniwis.properties` existiert bereits auf dem System, dann startet das Programm `dbeinrichten.exe` mit dem Fenster _AKS-Programmverwaltung_. Durch den Schalter _Die Datenbank-Verbindung einrichten_, gelangt man ebenfalls zur _Anmeldung an das Datenbanksystem_.

![](/gaa/aks/db-einrichten-03.jpg "{frame}" ) 

{{</columns>}}


Im Fenster _Anmeldung an das Datenbanksystem_ werden die oben dargestellten Werte eingetragen. Das Kennwortfeld ist laut AKS-Handbuch vorbelegt und kann leer bleiben. 
Für einen ersten Test wird der Schalter _Test DB-Verbindung_ aktiviert. 
Eine Meldung zeigt die erfolgreiche Verbindung an. Danach wird _Start_ aktiviert und das Fenster mit _Ende_ geschlossen.

![](/gaa/aks/db-einrichten-09.jpg "Verbindung erfolgreich #width={{<param zoom.1>}}% {frame}" )

Erscheint die o.g. Meldung nicht, dann liegt vermutlich ein Problem der Datei `C:\Program Files(x86)\aksniwis.properties` vor. Einfach alle Dateien mit diesem Namen im System löschen und das Programm `dbeinrichten.exe` neu starten. 

__Hinweis:__ Unter Umständen kann es vorkommen, dass das Fenster nicht mehr auf Mauseingaben reagiert. Der Grund dafür ist, dass sich ein kleineres Meldungsfenster hinter dem vordergründigen Fenster geöffnet hat und nun verdeckt wird. Durch die Tastenkombination `[Alt]+[Tabulatortaste]` kann das kleinere Meldungsfenster in den Vordergrund gebracht werden. Eine andere Möglichkeit ist es, das Fenster vorab auf eine andere Position zu schieben.

__Verbindungsfehler:__
Wenn die Verbindung fehlschlägt und mit der Fehlermeldung `... requested SCRAM-based authentication ...` abbricht, dann muss die Datei `pg_hba.conf` geändert werden (siehe oben).

![](/gaa/aks/db-einrichten-00error.jpg "#width={{<param zoom.1>}}% {frame}" )


#### AKS-Datenbank anlegen {class=counter2}

Nach der erfolgreichen Verbinung von AKS zum Datenbankmanager PostGIS, bzw. PostgreSQL, kann eine neue AKS-Datenbank erstellt werden.
Das Programm `dbeinrichten.exe` wird gestartet und der Schalter _Eine neue AKS-Datenbank anlegen_ getätigt. 

![](/gaa/aks/db-einrichten-07.jpg "#width={{<param zoom.1>}}% {frame}" ) 
   
Um das _Länderkennzeichen_ und die _Nummer des Bezirks_ zu ändern muss der Schalter _Entsperren_ getätigt werden. Das Länderkennzeichen kann dem [amtlichen Regionalschlüssel][gemeindeverzeichnis][^99] entnommen werden.

{{<mytable caption="Beispiel Regionalschlüssel" class="width50 captleft greyhead small smallfont fontcourier noborder">}}
| LK | Bezirk | Beschreibung |
| :---: | :---: | :--- |
| 03  | 1 | Niedersachsen, Region Braunschweig |
| 03  | 2 | Niedersachsen, Region Hannover |
| 06  | 4 | Hessen, Reg.-Bez. Darmstadt |
| 06  | 5 | Hessen, Reg.-Bez. Gießen |
| 09  | 1 | Bayern, Oberbayern |
| 09  | 2 | Bayern, Niederbayern |
| 09  | 3 | Bayern, Oberpfalz |
| 09  | 4 | Bayern, Oberfranken |
| 09  | 5 | Bayern, Mittelfranken |
{{</mytable>}}

Der Schalter _Tabelle für neue Datenbank anlegen_ generiert die PostGIS/PostgreSQL Datenbank für AKS. 
Das Protokoll steht unter: `C:/Users/<UserName>/AppData/Local/Temp/aks/tabellenanlegen_ed.prt` und sollte keine Fehlermeldung oder die Information über fehlende SQL-Dateien (siehe oben) aufweisen.

#### Geschäftsstellennummer ändern {class=counter2}

Ist die Datenbank angelegt, kann optional _die Geschäftsstellennummer geändert_ werden. Voreingestellt ist _100_. Nach Angaben des Herstellers ist die Geschäftsstellennummer in der Datenbank in den Feldern mit Kauffallkennzeichen, Auftragskennzeichen, Gebietsnummern und Selektionsanweisungen (SQL) eingebunden. Für das Ändern der Geschäftsstellennummer wird eine _Ausführungskennung_ benötigt, die vom Hersteller bezogen werden kann (Email v. 11.07.2023).

__Hinweis:__ Eine Änderung der Geschäftstellennummer bewirkt auch eine Änderung im {{<menu "Geschäftsstellendaten/Geschäftsstelle/Kenndaten/Reiter Einstellungen" "AKS-Hauptmenu:">}} in den Feldern _Nummer der Geschäftsstelle_, _Nummer der zugehörigen Behörde_ und _Gutachterausschusschlüssel (BW)_.

Die _Ausführungskennung_ wird ebenfalls benötigt im: {{<menu "Programmverwaltung/Verwaltung/System-Programme/Bereinigungs-Funktionen" "AKS-Hauptmenu: ">}}

### AKS Einrichten {class=counter2}

Das Programm wird aus dem Installationsverzeichnis `C:\Program Files(x86)\AKS\aks.exe` oder durch das Desktopsympol _AKS_ gestartet. 

#### Geschäftsstellendaten einrichten {class=counter2}


{{<columns>}}
Im {{<menu "Geschäftsstellendaten/Geschäftsstelle/Kenndaten" "AKS-Hauptmenu:">}} werden die Daten zur Geschäftstelle eingeben. Alternativ kann das Programm `C:\Program Files(x86)\AKS\geschaeftsstelle.exe` gestartet werden.
   
__Hinweis:__ Einige Felder werden durch den Schalter _Entsperren_ nicht entsperrt. 
Das ist insbesondere bei der Länderkennung der Fall (siehe oben). Die Taste `[F9]` oder die Tastenkombination  `[Alt Gr] + [w]` entsperrt die entsprechenden Felder.
   
Für den GAA im Landkreis Hof werden folgende Geschäftsstellendaten eingeben:
<--->
![](/gaa/aks/GaaGS-Einstellungen-01.jpg "Bezeichnung und Adresse {frame}" ) 
<--->
![](/gaa/aks/GaaGS-Einstellungen-02.jpg "Zuständigkeitsbereich {frame}" ) 
<--->
![](/gaa/aks/GaaGS-Einstellungen-03.jpg "Einstellungen {frame}" ) 
{{</columns>}}
   

#### Fehlende Verzeichnisspfade einstellen {class=counter2}


Im {{<menu "Verwaltung/Verwaltungsfunktionen/Lokale Einstellungen" "AKS-Hauptmenu - Programmverwaltung: ">}} werden insbesondere die Verzeichnisse für AKS eingestellt.
Alternativ kann das Progamm `aksadmin.exe` gestartet werden. 

Die Verzeichnisse für Web-Browser und PDF-Reader sind je nach Windows Version z.B. in:
: Browser:&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; `C:\Windows\SystemApps\Microsoft.MicrosoftEdge_8wekyb3d8bbwe\MicrosoftEdge.exe`
: Browser:&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; `C:\Program Files (x86)\Microsoft\Edge\Application\msedge.exe`
: PDF-Reader: `C:\Windows\SystemApps\Microsoft.MicrosoftEdge_8wekyb3d8bbwe\MicrosoftPdfReader.exe`
: PDF-Reader: `C:\Program Files (x86)\Adobe\Acrobat Reader DC\Reader\AcroRd32.exe`
: PDF-Reader: `C:/Program Files/Adobe/Acrobat DC/Acrobat/Acrobat.exe`


![](/gaa/aks/verzeichnisse-01.jpg "#width={{<param zoom.1>}}% {frame}" )

##### Fotoverzeichnis {class=counter2}

Das Fotoverzeichnis wird im {{<menu "Verwaltung/Verwaltungsfunktionen/Allgemeine Einstellungen" "AKS-Hauptmenu - Programmverwaltung: ">}} eingestellt.









[postgresql.org]:			https://www.postgresql.org/
[postgresql_V1521_windows]:		https://sbp.enterprisedb.com/getfile.jsp?fileid=1258323
[postgresql_V1531_windows]:		https://sbp.enterprisedb.com/getfile.jsp?fileid=1258478
[postgresql_V1532_windows]:		https://sbp.enterprisedb.com/getfile.jsp?fileid=1258514
[postgresql_V1533_windows]:		https://sbp.enterprisedb.com/getfile.jsp?fileid=1258631
[postgresql_V1551_windows]:		https://sbp.enterprisedb.com/getfile.jsp?fileid=1258790
[postgresql_download]:			https://www.enterprisedb.com/downloads/postgres-postgresql-downloads
[postgis.net]:				https://postgis.net/
[postgis.osgeo.download]:		https://download.osgeo.org/postgis/windows/pg15/
[osgeo.org]:				https://www.osgeo.org
[gemeindeverzeichnis]:			https://www.destatis.de/DE/Themen/Laender-Regionen/Regionales/Gemeindeverzeichnis/_inhalt.html
[pgadmin4]:				https://www.pgadmin.org


[^1]: https://www.postgresql.org/
[^2]: Download PostgreSQL 15.3.3 - https://sbp.enterprisedb.com/getfile.jsp?fileid=1258631
[^3]: https://download.osgeo.org/postgis/windows/pg15/
[^4]: https://postgis.net/
[^5]: https://www.enterprisedb.com/downloads/postgres-postgresql-downloads
[^6]: Download PostgreSQL 15.2.1 - https://sbp.enterprisedb.com/getfile.jsp?fileid=1258323
[^7]: https://www.vermessungsprogramme.de/download/aks-fehlende-sqls.zip
[^8]: https://www.pgadmin.org
[^9]: Download PostgreSQL 15.5.1 - https://sbp.enterprisedb.com/getfile.jsp?fileid=1258790
[^99]: https://www.destatis.de/DE/Themen/Laender-Regionen/Regionales/Gemeindeverzeichnis/_inhalt.html
