+++
tags = ["aks", "gis", "postgres"]
zusammenfassung = "... auf der Konsole einrichten."
title = "Postgresql"
date = "2023-08-09T15:52:10+02:00"
type = "article"
+++

#### Der Begriff - Rolle - 

Bei der Installation von PostgreSQL wurde die Rolle _postgres_ angelegt. PostgreSQL unterscheidet zwischen Benutzerrollen und Gruppenrollen. 
Rollen werden verwendet, um Berechtigungen für den Datenbankzugriff zu verwalten, wobei eine Benutzerrolle das Einloggen ermöglicht, eine Gruppenrolle dagegen nicht.
In Gruppenrollen werden Benutzerollen zusammengefasst um ihnen Berechtigungen zu erteilen.

#### Erste Schritte in Linux

Nach der Installation der entsprechenden Packete wird in Linuxsystemen neben der Rolle _postgres_ auch gleichzeitig ein Benutzer _postgres_ eingerichtet. 
Entsprechend muss man sich einloggen. 

```fish {linenos=false}
 
 # Linux Benutzer anzeigen 
 cat /etc/passwd | cut -d : -f 1

 # ggf. Server starten
 sudo systemctl start postgresql
 
 # Einloggen als Benutzer postgres 
 sudo -i -u postgres
 
 # PostgreSQL-Terminal starten
 psql
  
```
>__Ggf.__ tritt eine __Fehlermeldung__ auf (keine Verbindung mit Server), dann könnte ein Neustart des Servers helfen. Ansonsten, [siehe weiter unten.][LoginNetzwerk] 


Nach dem Start des interaktiven PostgreSQL-Terminal mit dem Befehl `psql` steht der Eingabeprompt `postgres=#` auf der Konsole zur Verfügung. 
Der Eingabeprompt zeigt immer die Datenbank mit der man gerade verbunden ist. In diesem Fall mit der Datenbank _postgres_.
Innerhalb des psql-Terminal können erstmal ein paar Informationen abgefragt werden.

{{<code lang="apl" title="psql Terminal">}}
 help 		# das Wichtigste 	
 \conninfo	# Verbindungseinstellung anzeigen
 \l		# Datenbanken auflisten
 \du 		# anzeigen aller Rollen bzw. Nutzer
 \dt		# Tabellen und Schemata auflisten
 \q		# beendet psql Terminal
 \c DBName	# Wechsel zu DBNAME
 \dx		# Alle Erweiterungen der DB anzeigen
{{</code>}}

#### Einloggen in ein privates Netzwerk

Innerhalb eines privaten Netzwerks mit eigens vergebenen [privaten IP-Adressen][privateIP] wird PostgreSQL auf einem Server betrieben. Die einzelnen Clients (PC) bauen eine Verbindung zum PostgreSQL-Server auf.
In der Datei `postgresql.conf` des Server wird die IP-Adresse und der Verschlüsselungsmechanismus eingetragen.

{{<code lang="fish" title="postgresql.conf">}}
 listen_addresses = '192.168.56.102'  # Server-Adresse
 password_encryption = md5
{{</code>}}

In der Datei `pg_hba.conf` werden ebenfalls die entsprechenden Einträge angepaßt. 
Diese Datei regelt folgende Punkte:
1. Welche Host/Gast, bzw. welches Netzwerk (IP-Addresse) sich anmelden darf.
2. Die Zugriffsrechte eines Host/Gast auf eine Datenbank.
3. Das Authentifizierungsverfahren der Anmeldung

{{<code lang="elm" title="pg_hba.conf">}}
 host 	DBName	Benutzer	192.168.56.0/24 	md5
{{</code>}}

Die Angabe der IP-Adresse erfolgt in der [CIDR-Notation.][cidr] Die folgende Tabelle zeigt ein paar Beispiele.

{{<mytable class="small smallfont fontcourier captleft vtop">}}
| CIDR-Notation | Anzahl der Adressen | Adressbereich | Beschreibung |
| :---:  | :---: | :---: | :---: |
| 192.168.56.1/32 | 1   | nur 192.168.56.1 | einzelner Host |
| 192.168.56.0/24 | 254 | 192.168.56.0 - 192.168.56.255 | kleines lokales Netzwerk |
| 192.168.0.0/16 | 65.534 | 192.168.0.0 - 192.168.255.255 | größeres Netzwerk |
{{</mytable>}}




 
Bei einer Verbindung über das Internet muss die [öffentliche IP-Adresse][ipadresse] des Client in der Datei eingetragen werden.

{{<code lang="elm" title="pg_hba.conf">}}
 host 	DBName	Benutzer	46.111.111.111		scram-sha-256	
{{</code>}}

Dann den PostreSQL-Server neustarten
 
{{<code lang="fish">}}
 systemctl restart postgresql
{{</code>}}

Innerhalb des privaten Netzwerkes kann sich der Client mit folgender Befehlszeile auf dem PostgreSQL-Server einloggen.

{{<code lang="fish">}}
 psql -d DBName -U Benutzer -h 192.168.56.102
{{</code>}}

Bei dieser Verbindung wird ein Passwort des Benutzers auf dem PostgreSQL-Server abgefragt und gefordert. Das Passwort für den Benutzer sollte vorher in `psql` angelegt werden mit dem SQL-Befehl: 

{{<code lang="sql">}}
 alter user Benutzer PASSWORD 'meinPW';
{{</code>}}

... oder direkt auf der Kommandoshell mit dem Befehl:

{{<code lang="fish">}}
 psql -d DBName -U Benutzer -c "alter user Benutzer PASSWORD 'meinPW';"
{{</code>}}


#### PostgreSql Terminal - psql

Das PostgreSQL Terminal `psql` ist für Linux und Windows verfügbar. Es erlaubt eine Verbindung zu einem PostgreSQL-Server und entsprechenden Datenbankoperationen und -abfragen.
Dafür steht die Kommandoption `-c` bzw. `--command=` zur Verfügung. Einige Abfragen sind:


{{<code lang="cpp">}}
 "show listen_addresses;"	// IP Adresse des Servers
 "show config_file;"  		// zeigt die Position postgresql.conf (Konfigurationsdatei Server)
 "show hba_file;"  		// zeigt die Position pg_hba.conf
 "show data_directory;"  	// zeigt die Position der Datenbank
 "show ssl;"			// ist SSL für die Datenübertragung an- oder abgeschaltet
 "show server_version;"		// na was wird das wohl sein
 "show all;"			// alle Konfigurationsparameter
{{</code>}}

#### Verschlüsselte Verbindung mit SSL

Guck'st du [hier.][ssl] Das sieht irgendwie viel versprechend aus. Ansonsten mal Google fragen mit den Begriffen: `postgresql ssl certificate windows`.




#### Benutzer und DB anlegen und löschen

Innerhalb des interaktive PostgreSQL-Terminal `psql` werden Benutzer und Datenbanken durch [SQL-Befehle][psqlanweisung]verwaltet. 
Aber auch auf der Shell-Konsole werden Programme zur Benutzer- und Datenbankverwaltung zur Verfügung gestellt.


{{%mytable class="width50 small noborder tableleft "%}}
| |  | 
|:--|:--|
|`createuser` |Benutzer anlegen|
|`dropuser`|Benutzer löschen|
|`createdb`|Datenbank anlegen| 
|`dropdb`|Datenbank löschen|
{{%/mytable%}}


#### Tipp zu Windows 

Im Gegensatz zu Linuxsystem gibt es in Windows keinen registierten Benutzer _postgres_. 
Sollten auf der DOS-Konsole _cmd.exe_ die deutschen Umlaute nicht richtig dargestellt werden, kann die Zeichensatz-Tabelle [codepage][] geändert werden.

```fish {linenos=false}
 
 net user	# Window registrierte Benutzer anzeigen 
   
```


#### Links


[hilfe01][]   
[hilfe02][]   
[hilfe03][]   
[postgis Datenbank erzeugen][hilfe04]   
[hilfe05][]   
[postgresql-buch.de](https://postgresql-buch.de/beispiele)



[hilfe01]: 		https://www.digitalocean.com/community/tutorials/how-to-install-postgresql-on-ubuntu-20-04-quickstart-de
[hilfe02]: 		http://support.ptc.com/help/thingworx_hc/thingworx_8_hc/de/index.html#page/ThingWorx/Help/Installation/Installation/install_and_configure_postgresql_Ubuntu.html
[hilfe03]: 		https://wiki.postgresql.org/wiki/FAQ/de#Wie_regle_ich_Zugriffe_von_anderen_Rechnern.3F
[hilfe04]: 		https://live.osgeo.org/de/quickstart/postgis_quickstart.html#client-server-architecture
[hilfe05]: 		http://postgresql.de/download/1Admin_v3.pdf
[privateIP]: 		https://de.wikipedia.org/wiki/Private_IP-Adresse
[psqlanweisung]:	{{< relref "postgresql-anweisungen" >}}
[LoginNetzwerk]:	{{< relref "#einloggen-in-ein-privates-netzwerk" >}}
[ipadresse]:		{{< relref "/edv/system/ssh#ip-adresse-abfragen" >}}
[ssl]:			https://methoddev.com/blog/postgresql-windows-encrypted-connection-ssl
[cidr]:			https://de.wikipedia.org/wiki/Classless_Inter-Domain_Routing
[codepage]:		{{< relref "/edv/windows/codepage" >}}
