+++
tags = ["grk", "fehler"]
zusammenfassung = "Problembehebung fehlender Registrierungsnummer in der Datenbank von GRK."
title = "Fehlende Registriernummer"
date = "2021-04-26T16:36:10+02:00"
type = "article"
+++
## Vorwort
Bei der Auswertung der Daten aus der Kaufpreissammlung für das bayrische Landesamt für Statistik kann es vorkommen, dass einige Datensätze unvollständig sind. Insbesondere fehlen Werte in der Spalte `Regnr`.
![Bild: fehlende_regnummer.jpg](/images/fehlende_regnummer.jpg)

### Lösung
#### 1. Ermittlung der laufenden Nummer in der Tabelle: Unbebaut

In der Tabelle `Unbebaut` wird mit Hilfe der Spalten `Datum` und `Fläumsatz` die laufende Nummer (`LaufendNummer`) ermittelt. 

{{<code lang="sql" title="Tabelle: Unbebaut, Spalte: LaufendNummer">}}
 odbc-connect.exe -d Datengrk.mdb --sql 
 "select LaufendNummer, Datum, Fläumsatz, URKNR, Vertrpreis, Bereipreis, URKNR, Gemarkung, Flurstück 
	from Unbebaut 
	where Datum = #2020-12-09# AND Fläumsatz=520"
{{</code>}}

{{<panel header="Ausgabe: 3 Datensätze wurden gefunden">}}
15199   2020-12-09 00:00:00     520.0   50/2020 Gattendorf      75      28.0    14560.0 14560.0   
15232   2020-12-09 00:00:00     520.0   50/2020 Gattendorf      75      28.0    14560.0 14560.0   
15234   2020-12-09 00:00:00     520.0   50/2020 Gattendorf      75      28.0    14560.0 14560.0   
{{</panel>}}

#### 2. Prüfen in der Tabelle Registriernummer
In der Tabelle `Registriernummer` werden nun die einzelnen Datensätze mit den jeweiligen laufenden Nummern abgefragt.

{{<code lang="sql" title="Tabelle: Registriernummer, Abfrage für 15199, 15232, 15234">}}
 odbc-connect.exe -d Datengrk.mdb --sql
 "select LaufendNummerUnbebaut, ErfassungDatum, Regnr, Jahrgang
	from Registriernummer 
	where 	LaufendNummerUnbebaut=15199
	OR 	LaufendNummerUnbebaut=15232
	OR 	LaufendNummerUnbebaut=15234"
{{</code>}}


{{<panel header="Ausgabe">}}
15199   2020-12-16 00:00:00     1599.0  2020.0   
15232   2021-01-05 00:00:00   
15234   2021-01-05 00:00:00   
{{</panel>}}

__Ergebnis:__ Nur in dem Datensatz mit der laufenden Nummer `15199` ist eine Registrierungsnummer vorhanden `1599`. Die anderen beiden Datensätze (`15232, 15234`) ohne Registrierungsnummer werden bei der Auswertung für die Statistik fehlerhaft angezeigt. Sie können in den Tabellen `Unbebaut` und `Registriernummer` gelöscht werden.


