#!/bin/bash

# cleanhtml.sh 
# Das Skript strukturiert eine Html-Datei um, indem es:
# 1. HTML-Elemente in eine neue Zeile versetzt
# 2. HTML-Elemente teilweise nach rechts verschiebt
# 3. Leerraum (whitespace) am Beginn einer Zeile löscht
# 4. Das Html-Element <span> </span> löscht, aber nicht der Inhalt.
# 5. Teilw. Eigenschaften innerhalb eines Elements löscht, wie z.B.:
#	style align valign charoff 

declare inputfile=$1;
declare outfile;
declare tmpfile;

# Prüft Eingabedatei
if [ -z $inputfile ] || [ ! -f $inputfile ]; then
	echo -e "\n\tKeine reguläre Datei.";
	exit;
fi

tmpfile=$(mktemp atemp.XXXX);

# Erzeugt Ausgabedatei wie Eingabedatei + Temporäre Zeichen
outfile=$(mktemp ${inputfile%.*}.out.XXX.${inputfile##*.})
#echo $outfile;

# Alle Zeilenumbrüch löschen
tr -d '\r\n' < $inputfile > $tmpfile

sed 	\
	-re 's/^[[:space:]]*</</g' \
	-re 's/<html/\n<html/g' \
	-re 's/<\/html/\n<\/html/g' \
	-re 's/<body/\n<body/g' \
	-re 's/<\/body/\n<\/body/g' \
	-re 's/<head/\n<head/g' \
	-re 's/<\/head/\n<\/head/g' \
	-re 's/<meta/\n\t<meta/g' \
	-re 's/<title/\n\t<title/g' \
	-re 's/<link/\n\t<link/g' \
	-re 's/<\/meta/\n\t<\/meta/g' \
	-re 's/<table/\n\n\n<table/g' \
	-re 's/<\/table/\n<\/table/g' \
	-re 's/<tbody/\n<tbody/g' \
	-re 's/<\/tbody/\n<\/tbody/g' \
	-re 's/<tr/\n\t<tr/g' \
	-re 's/<\/tr/\n\t<\/tr/g' \
	-re 's/<td/\n\t\t<td/g' \
	-re 's/<th /\n\t\t<th /g' \
	-re 's/<thead/\n<thead/g' \
	-re 's/<\/thead/\n<\/thead/g' \
	-re 's/<t([[:alnum:]]) [[:space:]]*>/<t\1>/' \
	-re 's/<colgroup/\n\t<colgroup/g' \
	-re 's/<div/\n\t<div/g' \
	-re 's/<\/div/\n\t<\/div/g' \
	-re 's/ style\=\"[[:alnum:][:space:]\:\.\;\-]*\"//g'   \
	-re 's/ align\=\"[[:alnum:][:space:]]*\"//g'   	\
	-re 's/ valign\=\"[[:alnum:][:space:]]*\"//g'   \
	-re 's/ charoff\=\"[[:alnum:][:space:]]*\"//g'   \
	-re 's/<\/?span[[:space:]]*>//g' \
	\
	$tmpfile > $outfile

rm $tmpfile
